package com.newrelic.agent.android;

import com.newrelic.agent.android.analytics.AnalyticAttributeStore;
import com.newrelic.agent.android.crash.CrashStore;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.payload.NullPayloadStore;
import com.newrelic.agent.android.payload.Payload;
import com.newrelic.agent.android.payload.PayloadStore;
import com.newrelic.agent.android.util.Constants;
import java.util.UUID;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

public class AgentConfiguration {
    public static final String DEFAULT_COLLECTOR_HOST = "mobile-collector.newrelic.com";
    public static final String DEFAULT_CRASH_COLLECTOR_HOST = "mobile-crash.newrelic.com";
    public static final String DEFAULT_REGION_COLLECTOR_HOST = "mobile-collector.%s.nr-data.net";
    public static final String DEFAULT_REGION_CRASH_COLLECTOR_HOST = "mobile-crash.%s.nr-data.net";
    public static final String HEX_COLLECTOR_PATH = "/mobile/f";
    public static final int HEX_COLLECTOR_TIMEOUT = 5000;
    public static final int NUM_IO_THREADS = 3;
    public static final int PAYLOAD_TTL = 172800000;
    public AnalyticAttributeStore analyticAttributeStore;
    public String appName;
    public ApplicationPlatform applicationPlatform = ApplicationPlatform.Native;
    public String applicationPlatformVersion = Agent.getVersion();
    public String applicationToken;
    public String collectorHost = DEFAULT_COLLECTOR_HOST;
    public String crashCollectorHost = DEFAULT_CRASH_COLLECTOR_HOST;
    public CrashStore crashStore;
    public String customApplicationVersion = null;
    public String customBuildId = null;
    public boolean enableAnalyticsEvents = true;
    public PayloadStore<Payload> payloadStore = new NullPayloadStore();
    public String region = null;
    public boolean reportCrashes = true;
    public boolean reportHandledExceptions = true;
    public String sessionID = provideSessionId();
    public boolean useLocationService;
    public boolean useSsl = true;

    public AnalyticAttributeStore getAnalyticAttributeStore() {
        return this.analyticAttributeStore;
    }

    public String getAppName() {
        return this.appName;
    }

    public String getAppTokenHeader() {
        return Constants.Network.APPLICATION_LICENSE_HEADER;
    }

    public String getAppVersionHeader() {
        return Constants.Network.APP_VERSION_HEADER;
    }

    public ApplicationPlatform getApplicationPlatform() {
        return this.applicationPlatform;
    }

    public String getApplicationPlatformVersion() {
        String str = this.applicationPlatformVersion;
        return (str == null || str.isEmpty()) ? Agent.getVersion() : this.applicationPlatformVersion;
    }

    public String getApplicationToken() {
        return this.applicationToken;
    }

    public String getCollectorHost() {
        return this.collectorHost;
    }

    public String getCrashCollectorHost() {
        return this.crashCollectorHost;
    }

    public CrashStore getCrashStore() {
        return this.crashStore;
    }

    public String getCustomApplicationVersion() {
        return this.customApplicationVersion;
    }

    public String getCustomBuildIdentifier() {
        return this.customBuildId;
    }

    public String getDefaultCollectorHost() {
        return DEFAULT_COLLECTOR_HOST;
    }

    public String getDefaultCrashCollectorHost() {
        return DEFAULT_CRASH_COLLECTOR_HOST;
    }

    public String getDeviceOsNameHeader() {
        return Constants.Network.DEVICE_OS_NAME_HEADER;
    }

    public boolean getEnableAnalyticsEvents() {
        return this.enableAnalyticsEvents;
    }

    public String getHexCollectorHost() {
        return getCollectorHost();
    }

    public String getHexCollectorPath() {
        return HEX_COLLECTOR_PATH;
    }

    public int getHexCollectorTimeout() {
        return 5000;
    }

    public int getIOThreadSize() {
        return 3;
    }

    public PayloadStore<Payload> getPayloadStore() {
        return this.payloadStore;
    }

    public int getPayloadTTL() {
        return PAYLOAD_TTL;
    }

    public String getRegionalCollectorFromLicenseKey(String str) {
        String parseRegionFromApplicationToken = parseRegionFromApplicationToken(str);
        if (parseRegionFromApplicationToken == null || "".equals(str)) {
            return DEFAULT_COLLECTOR_HOST;
        }
        return String.format(DEFAULT_REGION_COLLECTOR_HOST, new Object[]{parseRegionFromApplicationToken});
    }

    public boolean getReportCrashes() {
        return this.reportCrashes;
    }

    public boolean getReportHandledExceptions() {
        return this.reportHandledExceptions;
    }

    public String getSessionID() {
        return this.sessionID;
    }

    public String parseRegionFromApplicationToken(String str) {
        AgentLog agentLog = AgentLogManager.getAgentLog();
        if (str != null && !"".equals(str)) {
            Matcher matcher = Pattern.compile("^(.+?)x{1,2}.*").matcher(str);
            if (matcher.matches()) {
                try {
                    String group = matcher.group(1);
                    if (group != null) {
                        if (!"".equals(group)) {
                            return group;
                        }
                    }
                    agentLog.warning("Region prefix empty");
                } catch (Exception e) {
                    agentLog.error("getRegionalCollectorFromLicenseKey: " + e);
                }
            }
        }
        return null;
    }

    public String provideSessionId() {
        String uuid = UUID.randomUUID().toString();
        this.sessionID = uuid;
        return uuid;
    }

    public void setAnalyticAttributeStore(AnalyticAttributeStore analyticAttributeStore2) {
        this.analyticAttributeStore = analyticAttributeStore2;
    }

    public void setAppName(String str) {
        this.appName = str;
    }

    public void setApplicationPlatform(ApplicationPlatform applicationPlatform2) {
        this.applicationPlatform = applicationPlatform2;
    }

    public void setApplicationPlatformVersion(String str) {
        this.applicationPlatformVersion = str;
    }

    public void setApplicationToken(String str) {
        this.applicationToken = str;
        String parseRegionFromApplicationToken = parseRegionFromApplicationToken(str);
        this.region = parseRegionFromApplicationToken;
        if (parseRegionFromApplicationToken != null) {
            this.collectorHost = String.format(DEFAULT_REGION_COLLECTOR_HOST, new Object[]{parseRegionFromApplicationToken});
            this.crashCollectorHost = String.format(DEFAULT_REGION_CRASH_COLLECTOR_HOST, new Object[]{this.region});
        }
    }

    public void setCollectorHost(String str) {
        this.collectorHost = str;
    }

    public void setCrashCollectorHost(String str) {
        this.crashCollectorHost = str;
    }

    public void setCrashStore(CrashStore crashStore2) {
        this.crashStore = crashStore2;
    }

    public void setCustomApplicationVersion(String str) {
        this.customApplicationVersion = str;
    }

    public void setCustomBuildIdentifier(String str) {
        this.customBuildId = str;
    }

    public void setEnableAnalyticsEvents(boolean z) {
        this.enableAnalyticsEvents = z;
    }

    public void setPayloadStore(PayloadStore<Payload> payloadStore2) {
        this.payloadStore = payloadStore2;
    }

    public void setReportCrashes(boolean z) {
        this.reportCrashes = z;
    }

    public void setReportHandledExceptions(boolean z) {
        this.reportHandledExceptions = z;
    }

    public void setSessionID(String str) {
        this.sessionID = str;
    }

    public void setUseLocationService(boolean z) {
        this.useLocationService = z;
    }

    public void setUseSsl(boolean z) {
        this.useSsl = z;
    }

    public boolean useLocationService() {
        return this.useLocationService;
    }

    public boolean useSsl() {
        return this.useSsl;
    }
}
