package com.newrelic.agent.android;

import android.annotation.SuppressLint;
import android.app.ActivityManager;
import android.app.Application;
import android.content.Context;
import android.location.Address;
import android.location.Geocoder;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.os.Build;
import android.os.Bundle;
import android.os.Environment;
import android.os.Looper;
import android.os.StatFs;
import android.text.TextUtils;
import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.analytics.AnalyticsControllerImpl;
import com.newrelic.agent.android.analytics.AnalyticsEvent;
import com.newrelic.agent.android.analytics.EventManager;
import com.newrelic.agent.android.api.common.TransactionData;
import com.newrelic.agent.android.api.p223v1.ConnectionEvent;
import com.newrelic.agent.android.api.p223v1.ConnectionListener;
import com.newrelic.agent.android.api.p223v1.DeviceForm;
import com.newrelic.agent.android.api.p224v2.TraceMachineInterface;
import com.newrelic.agent.android.background.ApplicationStateEvent;
import com.newrelic.agent.android.background.ApplicationStateListener;
import com.newrelic.agent.android.background.ApplicationStateMonitor;
import com.newrelic.agent.android.connectivity.CatFacade;
import com.newrelic.agent.android.connectivity.UserActionFacade;
import com.newrelic.agent.android.connectivity.UserActionType;
import com.newrelic.agent.android.harvest.AgentHealth;
import com.newrelic.agent.android.harvest.ApplicationInformation;
import com.newrelic.agent.android.harvest.ConnectInformation;
import com.newrelic.agent.android.harvest.DeviceInformation;
import com.newrelic.agent.android.harvest.EnvironmentInformation;
import com.newrelic.agent.android.harvest.Harvest;
import com.newrelic.agent.android.harvest.HarvestData;
import com.newrelic.agent.android.instrumentation.MetricCategory;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.metric.MetricNames;
import com.newrelic.agent.android.metric.MetricUnit;
import com.newrelic.agent.android.payload.PayloadController;
import com.newrelic.agent.android.sample.MachineMeasurementConsumer;
import com.newrelic.agent.android.sample.Sampler;
import com.newrelic.agent.android.stats.StatsEngine;
import com.newrelic.agent.android.stores.SharedPrefsAnalyticAttributeStore;
import com.newrelic.agent.android.stores.SharedPrefsCrashStore;
import com.newrelic.agent.android.stores.SharedPrefsPayloadStore;
import com.newrelic.agent.android.tracing.TraceMachine;
import com.newrelic.agent.android.util.ActivityLifecycleBackgroundListener;
import com.newrelic.agent.android.util.AndroidEncoder;
import com.newrelic.agent.android.util.Connectivity;
import com.newrelic.agent.android.util.Encoder;
import com.newrelic.agent.android.util.PersistentUUID;
import com.newrelic.agent.android.util.Reachability;
import com.newrelic.agent.android.util.UiBackgroundListener;
import java.io.IOException;
import java.text.MessageFormat;
import java.util.Collection;
import java.util.Comparator;
import java.util.List;
import java.util.Locale;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;
import p085c.p086a.p087a.p088a.outline;

public class AndroidAgentImpl implements AgentImpl, ConnectionListener, ApplicationStateListener, TraceMachineInterface {
    public static final float LOCATION_ACCURACY_THRESHOLD = 500.0f;
    public static final CatFacade catFacade = CatFacade.getInstance();
    public static final Comparator<TransactionData> cmp = new Comparator<TransactionData>() {
        public int compare(TransactionData transactionData, TransactionData transactionData2) {
            if (transactionData.getTimestamp() > transactionData2.getTimestamp()) {
                return -1;
            }
            return transactionData.getTimestamp() < transactionData2.getTimestamp() ? 1 : 0;
        }
    };
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public final AgentConfiguration agentConfiguration;
    public ApplicationInformation applicationInformation;
    public final Context context;
    public DeviceInformation deviceInformation;
    public final Encoder encoder = new AndroidEncoder();
    public LocationListener locationListener;
    public final Lock lock = new ReentrantLock();
    public MachineMeasurementConsumer machineMeasurementConsumer;
    public SavedState savedState;

    public AndroidAgentImpl(Context context2, AgentConfiguration agentConfiguration2) throws AgentInitializationException {
        ActivityLifecycleBackgroundListener activityLifecycleBackgroundListener;
        this.context = appContext(context2);
        this.agentConfiguration = agentConfiguration2;
        this.savedState = new SavedState(this.context);
        if (!isDisabled()) {
            initApplicationInformation();
            if (agentConfiguration2.useLocationService() && this.context.getPackageManager().checkPermission("android.permission.ACCESS_FINE_LOCATION", getApplicationInformation().getPackageId()) == 0) {
                log.debug("Location stats enabled");
                addLocationListener();
            }
            TraceMachine.setTraceMachineInterface(this);
            agentConfiguration2.setCrashStore(new SharedPrefsCrashStore(context2));
            agentConfiguration2.setPayloadStore(new SharedPrefsPayloadStore(context2));
            agentConfiguration2.setAnalyticAttributeStore(new SharedPrefsAnalyticAttributeStore(context2));
            ApplicationStateMonitor.getInstance().addApplicationStateListener(this);
            if (Agent.getUnityInstrumentationFlag().equals("YES")) {
                ActivityLifecycleBackgroundListener activityLifecycleBackgroundListener2 = new ActivityLifecycleBackgroundListener();
                try {
                    activityLifecycleBackgroundListener = activityLifecycleBackgroundListener2;
                    if (context2.getApplicationContext() instanceof Application) {
                        ((Application) context2.getApplicationContext()).registerActivityLifecycleCallbacks(activityLifecycleBackgroundListener2);
                        activityLifecycleBackgroundListener = activityLifecycleBackgroundListener2;
                    }
                } catch (Exception unused) {
                    activityLifecycleBackgroundListener = activityLifecycleBackgroundListener2;
                }
            } else {
                activityLifecycleBackgroundListener = new UiBackgroundListener();
            }
            context2.registerComponentCallbacks(activityLifecycleBackgroundListener);
            setupSession();
            return;
        }
        throw new AgentInitializationException("This version of the agent has been disabled");
    }

    @SuppressLint({"MissingPermission"})
    private void addLocationListener() {
        LocationManager locationManager = (LocationManager) this.context.getSystemService("location");
        if (locationManager == null) {
            log.error("Unable to retrieve reference to LocationManager. Disabling location listener.");
            return;
        }
        C17072 r6 = new LocationListener() {
            public void onLocationChanged(Location location) {
                if (AndroidAgentImpl.this.isAccurate(location)) {
                    AndroidAgentImpl.this.setLocation(location);
                }
            }

            public void onProviderDisabled(String str) {
                if ("passive".equals(str)) {
                    AndroidAgentImpl.this.removeLocationListener();
                }
            }

            public void onProviderEnabled(String str) {
            }

            public void onStatusChanged(String str, int i, Bundle bundle) {
            }
        };
        this.locationListener = r6;
        locationManager.requestLocationUpdates("passive", 1000, 0.0f, r6);
    }

    public static Context appContext(Context context2) {
        return !(context2 instanceof Application) ? context2.getApplicationContext() : context2;
    }

    public static DeviceForm deviceForm(Context context2) {
        int i = context2.getResources().getConfiguration().screenLayout & 15;
        if (i == 1) {
            return DeviceForm.SMALL;
        }
        if (i == 2) {
            return DeviceForm.NORMAL;
        }
        if (i == 3) {
            return DeviceForm.LARGE;
        }
        if (i > 3) {
            return DeviceForm.XLARGE;
        }
        return DeviceForm.UNKNOWN;
    }

    private String getUUID() {
        String deviceId = this.savedState.getConnectInformation().getDeviceInformation().getDeviceId();
        if (!TextUtils.isEmpty(deviceId)) {
            return deviceId;
        }
        String persistentUUID = new PersistentUUID(this.context).getPersistentUUID();
        this.savedState.saveDeviceId(persistentUUID);
        return persistentUUID;
    }

    private String getUnhandledExceptionHandlerName() {
        try {
            return Thread.getDefaultUncaughtExceptionHandler().getClass().getName();
        } catch (Exception unused) {
            return "unknown";
        }
    }

    public static void init(Context context2, AgentConfiguration agentConfiguration2) {
        try {
            Agent.setImpl(new AndroidAgentImpl(context2, agentConfiguration2));
            Agent.start();
        } catch (AgentInitializationException e) {
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("Failed to initialize the agent: ");
            a.append(e.toString());
            agentLog.error(a.toString());
        }
    }

    /* access modifiers changed from: private */
    public boolean isAccurate(Location location) {
        return location != null && 500.0f >= location.getAccuracy();
    }

    private void pokeCanary() {
    }

    /* access modifiers changed from: private */
    @SuppressLint({"MissingPermission"})
    public void removeLocationListener() {
        if (this.locationListener != null) {
            LocationManager locationManager = (LocationManager) this.context.getSystemService("location");
            if (locationManager == null) {
                log.error("Unable to retrieve reference to LocationManager. Can't unregister location listener.");
                return;
            }
            synchronized (locationManager) {
                locationManager.removeUpdates(this.locationListener);
                this.locationListener = null;
            }
        }
    }

    @Deprecated
    public void addTransactionData(TransactionData transactionData) {
    }

    public void applicationBackgrounded(ApplicationStateEvent applicationStateEvent) {
        log.info("AndroidAgentImpl: application backgrounded");
        stop();
    }

    public void applicationForegrounded(ApplicationStateEvent applicationStateEvent) {
        log.info("AndroidAgentImpl: application foregrounded");
        start();
    }

    @Deprecated
    public void connected(ConnectionEvent connectionEvent) {
        log.error("AndroidAgentImpl: connected ");
    }

    public void disable() {
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("PERMANENTLY DISABLING AGENT v");
        a.append(Agent.getVersion());
        agentLog.warning(a.toString());
        try {
            this.savedState.saveDisabledVersion(Agent.getVersion());
            try {
                stop(false);
            } finally {
                Agent.setImpl(NullAgentImpl.instance);
            }
        } catch (Throwable th) {
            stop(false);
            throw th;
        } finally {
            Agent.setImpl(NullAgentImpl.instance);
        }
    }

    @Deprecated
    public void disconnected(ConnectionEvent connectionEvent) {
        this.savedState.clear();
    }

    public void finalizeSession() {
    }

    @Deprecated
    public List<TransactionData> getAndClearTransactionData() {
        return null;
    }

    public ApplicationInformation getApplicationInformation() {
        return this.applicationInformation;
    }

    public CatFacade getCatFacade() {
        return catFacade;
    }

    public String getCrossProcessId() {
        this.lock.lock();
        try {
            return this.savedState.getCrossProcessId();
        } finally {
            this.lock.unlock();
        }
    }

    public long getCurrentThreadId() {
        return Thread.currentThread().getId();
    }

    public String getCurrentThreadName() {
        return Thread.currentThread().getName();
    }

    public DeviceInformation getDeviceInformation() {
        DeviceInformation deviceInformation2 = this.deviceInformation;
        if (deviceInformation2 != null) {
            return deviceInformation2;
        }
        DeviceInformation deviceInformation3 = new DeviceInformation();
        deviceInformation3.setOsName(Connectivity.ANDROID);
        deviceInformation3.setOsVersion(Build.VERSION.RELEASE);
        deviceInformation3.setOsBuild(Build.VERSION.INCREMENTAL);
        deviceInformation3.setModel(Build.MODEL);
        deviceInformation3.setAgentName("AndroidAgent");
        deviceInformation3.setAgentVersion(Agent.getVersion());
        deviceInformation3.setManufacturer(Build.MANUFACTURER);
        deviceInformation3.setDeviceId(getUUID());
        deviceInformation3.setArchitecture(System.getProperty("os.arch"));
        deviceInformation3.setRunTime(System.getProperty("java.vm.version"));
        deviceInformation3.setSize(deviceForm(this.context).name().toLowerCase(Locale.getDefault()));
        deviceInformation3.setApplicationPlatform(this.agentConfiguration.getApplicationPlatform());
        deviceInformation3.setApplicationPlatformVersion(this.agentConfiguration.getApplicationPlatformVersion());
        this.deviceInformation = deviceInformation3;
        return deviceInformation3;
    }

    public Encoder getEncoder() {
        return this.encoder;
    }

    public EnvironmentInformation getEnvironmentInformation() {
        EnvironmentInformation environmentInformation = new EnvironmentInformation();
        ActivityManager activityManager = (ActivityManager) this.context.getSystemService("activity");
        long[] jArr = new long[2];
        try {
            StatFs statFs = new StatFs(Environment.getRootDirectory().getAbsolutePath());
            StatFs statFs2 = new StatFs(Environment.getExternalStorageDirectory().getAbsolutePath());
            jArr[0] = statFs.getAvailableBlocksLong() * statFs.getBlockSizeLong();
            jArr[1] = statFs2.getAvailableBlocksLong() * statFs.getBlockSizeLong();
            if (jArr[0] < 0) {
                jArr[0] = 0;
            }
            if (jArr[1] < 0) {
                jArr[1] = 0;
            }
        } catch (Exception e) {
            AgentHealth.noticeException(e);
            if (jArr[0] < 0) {
                jArr[0] = 0;
            }
            if (jArr[1] < 0) {
                jArr[1] = 0;
            }
        } catch (Throwable th) {
            if (jArr[0] < 0) {
                jArr[0] = 0;
            }
            if (jArr[1] < 0) {
                jArr[1] = 0;
            }
            environmentInformation.setDiskAvailable(jArr);
            throw th;
        }
        environmentInformation.setDiskAvailable(jArr);
        environmentInformation.setMemoryUsage(Sampler.sampleMemory(activityManager).getSampleValue().asLong().longValue());
        environmentInformation.setOrientation(this.context.getResources().getConfiguration().orientation);
        environmentInformation.setNetworkStatus(getNetworkCarrier());
        environmentInformation.setNetworkWanType(getNetworkWanType());
        return environmentInformation;
    }

    public String getNetworkCarrier() {
        return Connectivity.carrierNameFromContext(this.context);
    }

    public String getNetworkWanType() {
        return Connectivity.wanType(this.context);
    }

    public int getResponseBodyLimit() {
        this.lock.lock();
        try {
            return this.savedState.getHarvestConfiguration().getResponse_body_limit();
        } finally {
            this.lock.unlock();
        }
    }

    public SavedState getSavedState() {
        return this.savedState;
    }

    public long getSessionDurationMillis() {
        return Harvest.getMillisSinceStart();
    }

    public int getStackTraceLimit() {
        this.lock.lock();
        try {
            return this.savedState.getStackTraceLimit();
        } finally {
            this.lock.unlock();
        }
    }

    public boolean hasReachableNetworkConnection(String str) {
        return Reachability.hasReachableNetworkConnection(this.context, str);
    }

    /* JADX WARNING: Removed duplicated region for block: B:29:0x009d  */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public void initApplicationInformation() throws com.newrelic.agent.android.AgentInitializationException {
        /*
            r8 = this;
            com.newrelic.agent.android.harvest.ApplicationInformation r0 = r8.applicationInformation
            if (r0 == 0) goto L_0x000c
            com.newrelic.agent.android.logging.AgentLog r0 = log
            java.lang.String r1 = "attempted to reinitialize ApplicationInformation."
            r0.debug(r1)
            return
        L_0x000c:
            android.content.Context r0 = r8.context
            java.lang.String r0 = r0.getPackageName()
            android.content.Context r1 = r8.context
            android.content.pm.PackageManager r1 = r1.getPackageManager()
            r2 = 0
            android.content.pm.PackageInfo r3 = r1.getPackageInfo(r0, r2)     // Catch:{ NameNotFoundException -> 0x00d2 }
            com.newrelic.agent.android.AgentConfiguration r4 = r8.agentConfiguration
            java.lang.String r4 = r4.getCustomApplicationVersion()
            boolean r5 = android.text.TextUtils.isEmpty(r4)
            if (r5 == 0) goto L_0x0040
            if (r3 == 0) goto L_0x0038
            java.lang.String r4 = r3.versionName
            if (r4 == 0) goto L_0x0038
            int r4 = r4.length()
            if (r4 <= 0) goto L_0x0038
            java.lang.String r4 = r3.versionName
            goto L_0x0040
        L_0x0038:
            com.newrelic.agent.android.AgentInitializationException r0 = new com.newrelic.agent.android.AgentInitializationException
            java.lang.String r1 = "Your app doesn't appear to have a version defined. Ensure you have defined 'versionName' in your manifest."
            r0.<init>(r1)
            throw r0
        L_0x0040:
            com.newrelic.agent.android.logging.AgentLog r5 = log
            java.lang.StringBuilder r6 = new java.lang.StringBuilder
            r6.<init>()
            java.lang.String r7 = "Using application version "
            r6.append(r7)
            r6.append(r4)
            java.lang.String r6 = r6.toString()
            r5.debug(r6)
            android.content.pm.ApplicationInfo r2 = r1.getApplicationInfo(r0, r2)     // Catch:{ NameNotFoundException -> 0x0070, SecurityException -> 0x0065 }
            if (r2 == 0) goto L_0x007a
            java.lang.CharSequence r1 = r1.getApplicationLabel(r2)     // Catch:{ NameNotFoundException -> 0x0070, SecurityException -> 0x0065 }
            java.lang.String r1 = r1.toString()     // Catch:{ NameNotFoundException -> 0x0070, SecurityException -> 0x0065 }
            goto L_0x007b
        L_0x0065:
            r1 = move-exception
            com.newrelic.agent.android.logging.AgentLog r2 = log
            java.lang.String r1 = r1.toString()
            r2.warning(r1)
            goto L_0x007a
        L_0x0070:
            r1 = move-exception
            com.newrelic.agent.android.logging.AgentLog r2 = log
            java.lang.String r1 = r1.toString()
            r2.warning(r1)
        L_0x007a:
            r1 = r0
        L_0x007b:
            com.newrelic.agent.android.logging.AgentLog r2 = log
            java.lang.StringBuilder r5 = new java.lang.StringBuilder
            r5.<init>()
            java.lang.String r6 = "Using application name "
            r5.append(r6)
            r5.append(r1)
            java.lang.String r5 = r5.toString()
            r2.debug(r5)
            com.newrelic.agent.android.AgentConfiguration r2 = r8.agentConfiguration
            java.lang.String r2 = r2.getCustomBuildIdentifier()
            boolean r5 = android.text.TextUtils.isEmpty(r2)
            if (r5 == 0) goto L_0x00af
            if (r3 == 0) goto L_0x00a6
            int r2 = r3.versionCode
            java.lang.String r2 = java.lang.String.valueOf(r2)
            goto L_0x00af
        L_0x00a6:
            com.newrelic.agent.android.logging.AgentLog r2 = log
            java.lang.String r5 = "Your app doesn't appear to have a version code defined. Ensure you have defined 'versionCode' in your manifest."
            r2.warning(r5)
            java.lang.String r2 = ""
        L_0x00af:
            com.newrelic.agent.android.logging.AgentLog r5 = log
            java.lang.StringBuilder r6 = new java.lang.StringBuilder
            r6.<init>()
            java.lang.String r7 = "Using build "
            r6.append(r7)
            r6.append(r2)
            java.lang.String r6 = r6.toString()
            r5.debug(r6)
            com.newrelic.agent.android.harvest.ApplicationInformation r5 = new com.newrelic.agent.android.harvest.ApplicationInformation
            r5.<init>(r1, r4, r0, r2)
            r8.applicationInformation = r5
            int r0 = r3.versionCode
            r5.setVersionCode(r0)
            return
        L_0x00d2:
            r0 = move-exception
            com.newrelic.agent.android.AgentInitializationException r1 = new com.newrelic.agent.android.AgentInitializationException
            java.lang.String r2 = "Could not determine package version: "
            java.lang.StringBuilder r2 = p085c.p086a.p087a.p088a.outline.m2937a(r2)
            java.lang.String r0 = r0.getMessage()
            r2.append(r0)
            java.lang.String r0 = r2.toString()
            r1.<init>(r0)
            throw r1
        */
        throw new UnsupportedOperationException("Method not decompiled: com.newrelic.agent.android.AndroidAgentImpl.initApplicationInformation():void");
    }

    public void initialize() {
        setupSession();
        AnalyticsControllerImpl.initialize(this.agentConfiguration, this);
        Harvest.addHarvestListener(this.savedState);
        Harvest.initialize(this.agentConfiguration);
        Harvest.setHarvestConfiguration(this.savedState.getHarvestConfiguration());
        Harvest.setHarvestConnectInformation(this.savedState.getConnectInformation());
        Measurements.initialize();
        log.info(MessageFormat.format("New Relic Agent v{0}", new Object[]{Agent.getVersion()}));
        log.verbose(MessageFormat.format("Application token: {0}", new Object[]{this.agentConfiguration.getApplicationToken()}));
        MachineMeasurementConsumer machineMeasurementConsumer2 = new MachineMeasurementConsumer();
        this.machineMeasurementConsumer = machineMeasurementConsumer2;
        Measurements.addMeasurementConsumer(machineMeasurementConsumer2);
        StatsEngine statsEngine = StatsEngine.get();
        StringBuilder a = outline.m2937a("Supportability/AgentHealth/UncaughtExceptionHandler/");
        a.append(getUnhandledExceptionHandlerName());
        statsEngine.inc(a.toString());
        PayloadController.initialize(this.agentConfiguration);
        Sampler.init(this.context);
        if (isInstantApp()) {
            log.info("This appears to be an Instant App");
            AnalyticsControllerImpl.getInstance().addAttributeUnchecked(new AnalyticAttribute(AnalyticAttribute.INSTANT_APP_ATTRIBUTE, true), false);
        }
    }

    public boolean isDisabled() {
        return Agent.getVersion().equals(this.savedState.getDisabledVersion());
    }

    public boolean isInstantApp() {
        return InstantApps.isInstantApp(this.context);
    }

    public boolean isUIThread() {
        return Looper.myLooper() == Looper.getMainLooper();
    }

    @Deprecated
    public void mergeTransactionData(List<TransactionData> list) {
    }

    public void setLocation(String str, String str2) {
        if (str == null || str2 == null) {
            throw new IllegalArgumentException("Country code and administrative region are required.");
        }
    }

    public void setSavedState(SavedState savedState2) {
        this.savedState = savedState2;
    }

    public void setupSession() {
        TraceMachine.clearActivityHistory();
        this.agentConfiguration.provideSessionId();
    }

    public void start() {
        if (!isDisabled()) {
            initialize();
            Harvest.start();
            if (FeatureFlag.featureEnabled(FeatureFlag.DistributedTracing)) {
                UserActionFacade.getInstance().recordUserAction(UserActionType.AppLaunch);
                return;
            }
            return;
        }
        stop(false);
    }

    public void stop() {
        stop(true);
    }

    public boolean updateSavedConnectInformation() {
        ConnectInformation connectInformation = this.savedState.getConnectInformation();
        ConnectInformation connectInformation2 = new ConnectInformation(getApplicationInformation(), getDeviceInformation());
        if (connectInformation2.equals(connectInformation) && this.savedState.hasConnectionToken(this.agentConfiguration.getApplicationToken())) {
            return false;
        }
        if (connectInformation2.getApplicationInformation().isAppUpgrade(connectInformation.getApplicationInformation())) {
            StatsEngine.get().inc(MetricNames.MOBILE_APP_UPGRADE);
            AnalyticsControllerImpl.getInstance().addAttributeUnchecked(new AnalyticAttribute(AnalyticAttribute.APP_UPGRADE_ATTRIBUTE, connectInformation.getApplicationInformation().getAppVersion()), false);
        }
        this.savedState.clear();
        this.savedState.saveConnectInformation(connectInformation2);
        this.savedState.saveConnectionToken(this.agentConfiguration.getApplicationToken());
        return true;
    }

    public void setLocation(Location location) {
        Address address;
        if (location != null) {
            List<Address> list = null;
            try {
                list = new Geocoder(this.context).getFromLocation(location.getLatitude(), location.getLongitude(), 1);
            } catch (IOException e) {
                AgentLog agentLog = log;
                StringBuilder a = outline.m2937a("Unable to geocode location: ");
                a.append(e.toString());
                agentLog.error(a.toString());
            }
            if (list != null && list.size() != 0 && (address = list.get(0)) != null) {
                String countryCode = address.getCountryCode();
                String adminArea = address.getAdminArea();
                if (countryCode != null && adminArea != null) {
                    setLocation(countryCode, adminArea);
                    removeLocationListener();
                    return;
                }
                return;
            }
            return;
        }
        throw new IllegalArgumentException("Location must not be null.");
    }

    public void stop(boolean z) {
        if (FeatureFlag.featureEnabled(FeatureFlag.DistributedTracing)) {
            UserActionFacade.getInstance().recordUserAction(UserActionType.AppBackground);
        }
        finalizeSession();
        Sampler.shutdown();
        TraceMachine.haltTracing();
        EventManager eventManager = AnalyticsControllerImpl.getInstance().getEventManager();
        int eventsRecorded = eventManager.getEventsRecorded();
        int eventsEjected = eventManager.getEventsEjected();
        MetricCategory metricCategory = MetricCategory.NONE;
        double d = (double) eventsEjected;
        MetricUnit metricUnit = MetricUnit.OPERATIONS;
        Measurements.addCustomMetric("Supportability/Events/Recorded", "NONE", eventsRecorded, d, d, metricUnit, metricUnit);
        if (z) {
            if (isUIThread()) {
                StatsEngine.get().inc("Supportability/AgentHealth/HarvestOnMainThread");
            }
            Harvest.harvestNow(true);
            HarvestData harvestData = Harvest.getInstance().getHarvestData();
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("EventManager: recorded[");
            a.append(eventManager.getEventsRecorded());
            a.append("] ejected[");
            a.append(eventManager.getEventsEjected());
            a.append("]");
            agentLog.debug(a.toString());
            if (harvestData != null && harvestData.isValid()) {
                Collection<AnalyticsEvent> analyticsEvents = harvestData.getAnalyticsEvents();
                if (!analyticsEvents.isEmpty()) {
                    AgentLog agentLog2 = log;
                    StringBuilder a2 = outline.m2937a("Agent stopped with ");
                    a2.append(analyticsEvents.size());
                    a2.append(" events dropped from failed harvest.");
                    agentLog2.warning(a2.toString());
                }
                if (eventManager.size() > 0) {
                    AgentLog agentLog3 = log;
                    StringBuilder a3 = outline.m2937a("Agent stopped with ");
                    a3.append(eventManager.size());
                    a3.append(" events left in event pool.");
                    agentLog3.warning(a3.toString());
                }
            }
        }
        AnalyticsControllerImpl.shutdown();
        TraceMachine.clearActivityHistory();
        Harvest.shutdown();
        Measurements.shutdown();
        PayloadController.shutdown();
    }
}
