package com.newrelic.agent.android.agentdata;

import com.newrelic.agent.android.AgentConfiguration;
import com.newrelic.agent.android.harvest.Harvest;
import com.newrelic.agent.android.harvest.HarvestLifecycleAware;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.metric.MetricNames;
import com.newrelic.agent.android.payload.Payload;
import com.newrelic.agent.android.payload.PayloadController;
import com.newrelic.agent.android.payload.PayloadReporter;
import com.newrelic.agent.android.payload.PayloadSender;
import com.newrelic.agent.android.payload.PayloadStore;
import com.newrelic.agent.android.stats.StatsEngine;
import com.newrelic.com.google.flatbuffers.FlatBufferBuilder;
import java.io.ByteArrayOutputStream;
import java.nio.ByteBuffer;
import java.util.List;
import java.util.concurrent.Callable;
import java.util.concurrent.Future;
import java.util.concurrent.atomic.AtomicReference;
import p085c.p086a.p087a.p088a.outline;

public class AgentDataReporter extends PayloadReporter implements HarvestLifecycleAware {
    public static final AtomicReference<AgentDataReporter> instance = new AtomicReference<>((Object) null);
    public static boolean reportExceptions = false;
    public final PayloadStore<Payload> payloadStore;
    public final Callable reportCachedAgentDataCallable = new Callable() {
        public Object call() throws Exception {
            AgentDataReporter.this.reportCachedAgentData();
            return null;
        }
    };

    public AgentDataReporter(AgentConfiguration agentConfiguration) {
        super(agentConfiguration);
        this.payloadStore = agentConfiguration.getPayloadStore();
        this.isEnabled.set(agentConfiguration.getReportHandledExceptions());
    }

    public static AgentDataReporter getInstance() {
        return instance.get();
    }

    public static AgentDataReporter initialize(AgentConfiguration agentConfiguration) {
        instance.compareAndSet((Object) null, new AgentDataReporter(agentConfiguration));
        reportExceptions = agentConfiguration.getReportHandledExceptions();
        return instance.get();
    }

    public static boolean isInitialized() {
        return instance.get() != null;
    }

    private boolean isPayloadStale(Payload payload) {
        if (!payload.isStale((long) this.agentConfiguration.getPayloadTTL())) {
            return false;
        }
        this.payloadStore.delete(payload);
        AgentLog agentLog = PayloadReporter.log;
        StringBuilder a = outline.m2937a("Payload [");
        a.append(payload.getUuid());
        a.append("] has become stale, and has been removed");
        agentLog.info(a.toString());
        StatsEngine.get().inc(MetricNames.SUPPORTABILITY_PAYLOAD_REMOVED_STALE);
        return true;
    }

    public static boolean reportAgentData(byte[] bArr) {
        if (!isInitialized()) {
            PayloadReporter.log.error("AgentDataReporter not initialized");
        } else if (reportExceptions) {
            instance.get().storeAndReportAgentData(new Payload(bArr));
            return true;
        }
        return false;
    }

    public static void shutdown() {
        if (isInitialized()) {
            try {
                instance.get().stop();
            } finally {
                instance.set((Object) null);
            }
        }
    }

    private byte[] submitBatchedPayload(final List<Payload> list) {
        if (list.isEmpty()) {
            return null;
        }
        ByteArrayOutputStream byteArrayOutputStream = new ByteArrayOutputStream();
        for (Payload bytes : list) {
            try {
                byteArrayOutputStream.write(bytes.getBytes());
            } catch (Exception unused) {
            }
        }
        ByteBuffer slice = new FlatBufferBuilder(ByteBuffer.wrap(byteArrayOutputStream.toByteArray())).dataBuffer().slice();
        slice.get(new byte[slice.remaining()]);
        PayloadController.submitPayload(new AgentDataSender(slice.array(), instance.get().agentConfiguration), new PayloadSender.CompletionHandler() {
            public void onException(PayloadSender payloadSender, Exception exc) {
                AgentLog access$100 = PayloadReporter.log;
                access$100.error("AgentDataReporter.submitBatchedPayload(List<Payload>): " + exc);
            }

            public void onResponse(PayloadSender payloadSender) {
                if (payloadSender.isSuccessfulResponse() && AgentDataReporter.this.payloadStore != null) {
                    for (Payload delete : list) {
                        AgentDataReporter.this.payloadStore.delete(delete);
                    }
                }
            }
        });
        return null;
    }

    public void onHarvest() {
        PayloadController.submitCallable(this.reportCachedAgentDataCallable);
    }

    public void onHarvestBefore() {
    }

    public void onHarvestComplete() {
    }

    public void onHarvestConnected() {
    }

    public void onHarvestDisabled() {
    }

    public void onHarvestDisconnected() {
    }

    public void onHarvestError() {
    }

    public void onHarvestFinalize() {
    }

    public void onHarvestSendFailed() {
    }

    public void onHarvestStart() {
    }

    public void onHarvestStop() {
    }

    public void reportCachedAgentData() {
        if (isInitialized()) {
            PayloadStore<Payload> payloadStore2 = this.payloadStore;
            if (payloadStore2 != null) {
                for (Payload next : payloadStore2.fetchAll()) {
                    if (!isPayloadStale(next)) {
                        reportAgentData(next);
                    }
                }
                return;
            }
            return;
        }
        PayloadReporter.log.error("AgentDataReporter not initialized");
    }

    public void start() {
        if (!PayloadController.isInitialized()) {
            PayloadReporter.log.error("AgentDataReporter.start(): Must initialize PayloadController first.");
        } else if (isEnabled() && this.isStarted.compareAndSet(false, true)) {
            PayloadController.submitCallable(this.reportCachedAgentDataCallable);
            Harvest.addHarvestListener(this);
        }
    }

    public void stop() {
        Harvest.removeHarvestListener(this);
    }

    public Future storeAndReportAgentData(Payload payload) {
        if (this.payloadStore != null && payload.isPersisted() && this.payloadStore.store(payload)) {
            payload.setPersisted(false);
        }
        return reportAgentData(payload);
    }

    public Future reportAgentData(Payload payload) {
        return PayloadController.submitPayload(new AgentDataSender(payload, getAgentConfiguration()), new PayloadSender.CompletionHandler() {
            public void onException(PayloadSender payloadSender, Exception exc) {
                AgentLog access$000 = PayloadReporter.log;
                access$000.error("AgentDataReporter.reportAgentData(Payload): " + exc);
            }

            public void onResponse(PayloadSender payloadSender) {
                PayloadStore<Payload> payloadStore;
                if (payloadSender.isSuccessfulResponse() && (payloadStore = AgentDataReporter.this.payloadStore) != null) {
                    payloadStore.delete(payloadSender.getPayload());
                }
            }
        });
    }
}
