package com.newrelic.agent.android.analytics;

import com.newrelic.agent.android.harvest.HarvestConfiguration;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.List;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.atomic.AtomicInteger;
import java.util.concurrent.atomic.AtomicReference;
import p085c.p086a.p087a.p088a.outline;

public class EventManagerImpl implements EventManager {
    public static int DEFAULT_MAX_EVENT_BUFFER_SIZE = HarvestConfiguration.DEFAULT_MAX_TRANSACTION_COUNT;
    public static int DEFAULT_MAX_EVENT_BUFFER_TIME = HarvestConfiguration.DEFAULT_MAX_TRANSACTION_AGE;
    public static final String EVENT_TYPE_ALLOWABLE_CHARS = "^[\\p{L}\\p{Nd} _:.]+$";
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public AtomicReference<List<AnalyticsEvent>> events;
    public AtomicInteger eventsDropped;
    public AtomicInteger eventsEjected;
    public AtomicInteger eventsRecorded;
    public long firstEventTimestamp;
    public AtomicBoolean hardFlush;
    public AtomicBoolean initialized;
    public int maxBufferTimeInSec;
    public int maxEventPoolSize;

    static {
        EventManager.RESERVED_EVENT_TYPES.add(AnalyticAttribute.EVENT_TYPE_ATTRIBUTE_MOBILE);
        EventManager.RESERVED_EVENT_TYPES.add(AnalyticAttribute.EVENT_TYPE_ATTRIBUTE_MOBILE_REQUEST);
        EventManager.RESERVED_EVENT_TYPES.add(AnalyticAttribute.EVENT_TYPE_ATTRIBUTE_MOBILE_REQUEST_ERROR);
        EventManager.RESERVED_EVENT_TYPES.add(AnalyticAttribute.EVENT_TYPE_ATTRIBUTE_MOBILE_BREADCRUMB);
        EventManager.RESERVED_EVENT_TYPES.add(AnalyticAttribute.EVENT_TYPE_ATTRIBUTE_MOBILE_CRASH);
        EventManager.RESERVED_EVENT_TYPES.add(AnalyticAttribute.EVENT_TYPE_ATTRIBUTE_MOBILE_USER_ACTION);
    }

    public EventManagerImpl() {
        this(DEFAULT_MAX_EVENT_BUFFER_SIZE, DEFAULT_MAX_EVENT_BUFFER_TIME);
    }

    public boolean addEvent(AnalyticsEvent analyticsEvent) {
        if (!this.initialized.get()) {
            this.eventsDropped.incrementAndGet();
            return false;
        }
        synchronized (this.events.get()) {
            int incrementAndGet = this.eventsRecorded.incrementAndGet();
            int size = this.events.get().size();
            if (size == 0) {
                AgentLog agentLog = log;
                agentLog.verbose("EventManager: addEvent - Queue is currently empty, setting first event timestamp to " + System.currentTimeMillis());
                this.firstEventTimestamp = System.currentTimeMillis();
            }
            if (size >= this.maxEventPoolSize) {
                this.eventsEjected.incrementAndGet();
                int random = (int) (Math.random() * ((double) incrementAndGet));
                if (random >= this.maxEventPoolSize) {
                    return true;
                }
                this.events.get().remove(random);
            }
            boolean add = this.events.get().add(analyticsEvent);
            return add;
        }
    }

    public void empty() {
        if (this.events.get().size() > 0) {
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("EventManager: empty() call dropped [");
            a.append(this.events.get().size());
            a.append("] events");
            agentLog.warning(a.toString());
        }
        this.events.get().clear();
        this.firstEventTimestamp = 0;
    }

    public int getEventsDropped() {
        return this.eventsDropped.get();
    }

    public int getEventsEjected() {
        return this.eventsEjected.get();
    }

    public int getEventsRecorded() {
        return this.eventsRecorded.get();
    }

    public int getMaxEventBufferTime() {
        return this.maxBufferTimeInSec;
    }

    public int getMaxEventPoolSize() {
        return this.maxEventPoolSize;
    }

    public Collection<AnalyticsEvent> getQueuedEvents() {
        Collection<AnalyticsEvent> unmodifiableCollection;
        synchronized (this.events.get()) {
            unmodifiableCollection = Collections.unmodifiableCollection(this.events.get());
        }
        return unmodifiableCollection;
    }

    public Collection<AnalyticsEvent> getQueuedEventsSnapshot() {
        Collection<AnalyticsEvent> andSet;
        synchronized (this.events.get()) {
            andSet = this.events.getAndSet(Collections.synchronizedList(new ArrayList(this.maxEventPoolSize)));
        }
        return andSet;
    }

    public void initialize() {
        if (!this.initialized.compareAndSet(false, true)) {
            log.verbose("EventManager: Impl has already been initialized. Bypassing...");
            return;
        }
        this.firstEventTimestamp = 0;
        this.eventsRecorded.set(0);
        this.eventsEjected.set(0);
        empty();
    }

    public boolean isEventTypeReserved(String str) {
        boolean contains = EventManager.RESERVED_EVENT_TYPES.contains(str);
        if (contains) {
            AgentLog agentLog = log;
            agentLog.error("Event type name [" + str + "] is reserved and will be ignored.");
        }
        return contains;
    }

    public boolean isEventTypeValid(String str) {
        boolean z = str != null;
        if (z) {
            z = str.matches(EVENT_TYPE_ALLOWABLE_CHARS);
        }
        if (!z) {
            AgentLog agentLog = log;
            agentLog.error("Event type name [" + str + "] is invalid and will be ignored. Custom event types may only include alphanumeric, ' ', '.', ':' or '_' characters.");
        }
        return z;
    }

    public boolean isMaxEventBufferTimeExceeded() {
        if (this.firstEventTimestamp <= 0 || System.currentTimeMillis() - this.firstEventTimestamp <= ((long) (this.maxBufferTimeInSec * HarvestConfiguration.DEFAULT_MAX_TRANSACTION_COUNT))) {
            return false;
        }
        return true;
    }

    public boolean isMaxEventPoolSizeExceeded() {
        return this.events.get().size() > this.maxEventPoolSize;
    }

    public boolean isTransmitRequired() {
        if ((this.initialized.get() || this.events.get().size() <= 0) && !this.hardFlush.compareAndSet(true, false) && !isMaxEventBufferTimeExceeded()) {
            return false;
        }
        return true;
    }

    public void setMaxEventBufferTime(int i) {
        this.maxBufferTimeInSec = i;
    }

    public void setMaxEventPoolSize(int i) {
        this.maxEventPoolSize = i;
    }

    public void setTransmitRequired() {
        this.hardFlush.set(true);
    }

    public void shutdown() {
        this.initialized.set(false);
    }

    public int size() {
        return this.events.get().size();
    }

    public EventManagerImpl(int i, int i2) {
        this.initialized = new AtomicBoolean(false);
        this.eventsRecorded = new AtomicInteger(0);
        this.eventsEjected = new AtomicInteger(0);
        this.eventsDropped = new AtomicInteger(0);
        this.hardFlush = new AtomicBoolean(false);
        this.events = new AtomicReference<>(Collections.synchronizedList(new ArrayList(i)));
        this.maxBufferTimeInSec = i2;
        this.maxEventPoolSize = i;
        this.firstEventTimestamp = 0;
        this.eventsRecorded.set(0);
        this.eventsEjected.set(0);
        this.eventsDropped.set(0);
    }

    public void empty(Collection<AnalyticsEvent> collection) {
        this.events.get().removeAll(collection);
    }
}
