package com.newrelic.agent.android.crash;

import com.newrelic.agent.android.Agent;
import com.newrelic.agent.android.AgentImpl;
import com.newrelic.agent.android.NewRelicConfig;
import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.analytics.AnalyticsEvent;
import com.newrelic.agent.android.harvest.ActivityHistory;
import com.newrelic.agent.android.harvest.DataToken;
import com.newrelic.agent.android.harvest.Harvest;
import com.newrelic.agent.android.harvest.crash.ApplicationInfo;
import com.newrelic.agent.android.harvest.crash.DeviceInfo;
import com.newrelic.agent.android.harvest.crash.ExceptionInfo;
import com.newrelic.agent.android.harvest.crash.ThreadInfo;
import com.newrelic.agent.android.harvest.type.HarvestableObject;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.stats.StatsEngine;
import com.newrelic.agent.android.tracing.TraceMachine;
import com.newrelic.agent.android.util.Connectivity;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import com.newrelic.com.google.gson.JsonArray;
import com.newrelic.com.google.gson.JsonObject;
import com.newrelic.com.google.gson.JsonParser;
import com.newrelic.com.google.gson.JsonPrimitive;
import java.util.ArrayList;
import java.util.Collection;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.UUID;

public class Crash extends HarvestableObject {
    public static final int MAX_UPLOAD_COUNT = 3;
    public static final int PROTOCOL_VERSION = 1;
    public ActivityHistory activityHistory;
    public boolean analyticsEnabled;
    public final String appToken;
    public ApplicationInfo applicationInfo;
    public final String buildId;
    public DeviceInfo deviceInfo;
    public Collection<AnalyticsEvent> events;
    public ExceptionInfo exceptionInfo;
    public Set<AnalyticAttribute> sessionAttributes;
    public List<ThreadInfo> threads;
    public final long timestamp;
    public int uploadCount;
    public final UUID uuid;

    public Crash(UUID uuid2, String str, long j) {
        AgentImpl impl = Agent.getImpl();
        this.uuid = uuid2;
        this.buildId = str;
        this.timestamp = j;
        this.appToken = CrashReporter.getInstance().getAgentConfiguration().getApplicationToken();
        this.deviceInfo = new DeviceInfo(impl.getDeviceInformation(), impl.getEnvironmentInformation());
        this.applicationInfo = new ApplicationInfo(impl.getApplicationInformation());
        this.exceptionInfo = new ExceptionInfo();
        this.threads = new ArrayList();
        this.activityHistory = new ActivityHistory(new ArrayList());
        this.sessionAttributes = new HashSet();
        this.events = new HashSet();
        this.analyticsEnabled = true;
        this.uploadCount = 0;
    }

    public static Crash crashFromJsonString(String str) {
        JsonObject asJsonObject = new JsonParser().parse(str).getAsJsonObject();
        Crash crash = new Crash(UUID.fromString(asJsonObject.get(AnalyticAttribute.UUID_ATTRIBUTE).getAsString()), asJsonObject.get("buildId").getAsString(), asJsonObject.get(AnalyticAttribute.EVENT_TIMESTAMP_ATTRIBUTE).getAsLong());
        crash.deviceInfo = DeviceInfo.newFromJson(asJsonObject.get("deviceInfo").getAsJsonObject());
        crash.applicationInfo = ApplicationInfo.newFromJson(asJsonObject.get("appInfo").getAsJsonObject());
        crash.exceptionInfo = ExceptionInfo.newFromJson(asJsonObject.get("exception").getAsJsonObject());
        crash.threads = ThreadInfo.newListFromJson(asJsonObject.get("threads").getAsJsonArray());
        crash.activityHistory = ActivityHistory.newFromJson(asJsonObject.get("activityHistory").getAsJsonArray());
        crash.analyticsEnabled = asJsonObject.has("sessionAttributes") || asJsonObject.has("analyticsEvents");
        if (asJsonObject.has("sessionAttributes")) {
            crash.setSessionAttributes(AnalyticAttribute.newFromJson(asJsonObject.get("sessionAttributes").getAsJsonObject()));
        }
        if (asJsonObject.has("analyticsEvents")) {
            crash.setAnalyticsEvents(AnalyticsEvent.newFromJson(asJsonObject.get("analyticsEvents").getAsJsonArray()));
        }
        if (asJsonObject.has("uploadCount")) {
            crash.uploadCount = asJsonObject.get("uploadCount").getAsInt();
        }
        return crash;
    }

    public static String getBuildId() {
        return NewRelicConfig.BUILD_ID;
    }

    public static Throwable getRootCause(Throwable th) {
        if (th == null) {
            return new Throwable("Unknown cause");
        }
        try {
            Throwable cause = th.getCause();
            if (cause == null) {
                return th;
            }
            return getRootCause(cause);
        } catch (Exception unused) {
            return th;
        }
    }

    public static String getSafeBuildId() {
        String buildId2 = getBuildId();
        if (buildId2 == null || buildId2.isEmpty()) {
            buildId2 = Agent.getBuildId();
            StatsEngine.get().inc("Supportability/Crash/InvalidBuildId");
            if (buildId2 == null || buildId2.isEmpty()) {
                AgentLogManager.getAgentLog().error("Invalid (null or empty) build ID detected! Crash will be ignored by collector.");
            }
        }
        return buildId2;
    }

    public JsonObject asJsonObject() {
        JsonObject jsonObject = new JsonObject();
        jsonObject.add("protocolVersion", new JsonPrimitive((Number) 1));
        jsonObject.add(AnalyticAttribute.APPLICATION_PLATFORM_ATTRIBUTE, new JsonPrimitive(Connectivity.ANDROID));
        jsonObject.add(AnalyticAttribute.UUID_ATTRIBUTE, SafeJsonPrimitive.factory(this.uuid.toString()));
        jsonObject.add("buildId", SafeJsonPrimitive.factory(this.buildId));
        jsonObject.add(AnalyticAttribute.EVENT_TIMESTAMP_ATTRIBUTE, SafeJsonPrimitive.factory((Number) Long.valueOf(this.timestamp)));
        jsonObject.add("appToken", SafeJsonPrimitive.factory(this.appToken));
        jsonObject.add("deviceInfo", this.deviceInfo.asJsonObject());
        jsonObject.add("appInfo", this.applicationInfo.asJsonObject());
        jsonObject.add("exception", this.exceptionInfo.asJsonObject());
        jsonObject.add("threads", getThreadsAsJson());
        jsonObject.add("activityHistory", this.activityHistory.asJsonArrayWithoutDuration());
        JsonObject jsonObject2 = new JsonObject();
        Set<AnalyticAttribute> set = this.sessionAttributes;
        if (set != null) {
            for (AnalyticAttribute next : set) {
                jsonObject2.add(next.getName(), next.asJsonElement());
            }
        }
        jsonObject.add("sessionAttributes", jsonObject2);
        JsonArray jsonArray = new JsonArray();
        Collection<AnalyticsEvent> collection = this.events;
        if (collection != null) {
            for (AnalyticsEvent asJsonObject : collection) {
                jsonArray.add(asJsonObject.asJsonObject());
            }
        }
        jsonObject.add("analyticsEvents", jsonArray);
        DataToken dataToken = Harvest.getHarvestConfiguration().getDataToken();
        if (dataToken != null) {
            jsonObject.add("dataToken", dataToken.asJsonArray());
        }
        return jsonObject;
    }

    public ExceptionInfo getExceptionInfo() {
        return this.exceptionInfo;
    }

    public Set<AnalyticAttribute> getSessionAttributes() {
        return this.sessionAttributes;
    }

    public JsonArray getThreadsAsJson() {
        JsonArray jsonArray = new JsonArray();
        List<ThreadInfo> list = this.threads;
        if (list != null) {
            for (ThreadInfo asJsonObject : list) {
                jsonArray.add(asJsonObject.asJsonObject());
            }
        }
        return jsonArray;
    }

    public long getTimestamp() {
        return this.timestamp;
    }

    public int getUploadCount() {
        return this.uploadCount;
    }

    public UUID getUuid() {
        return this.uuid;
    }

    public void incrementUploadCount() {
        this.uploadCount++;
    }

    public boolean isStale() {
        return this.uploadCount >= 3;
    }

    public void setAnalyticsEvents(Collection<AnalyticsEvent> collection) {
        this.events = collection;
    }

    public void setSessionAttributes(Set<AnalyticAttribute> set) {
        this.sessionAttributes = set;
    }

    public Crash(Throwable th) {
        this(th, new HashSet(), new HashSet(), false);
    }

    public Crash(Throwable th, Set<AnalyticAttribute> set, Collection<AnalyticsEvent> collection, boolean z) {
        AgentImpl impl = Agent.getImpl();
        Throwable rootCause = getRootCause(th);
        this.uuid = UUID.randomUUID();
        this.buildId = getSafeBuildId();
        this.timestamp = System.currentTimeMillis();
        this.appToken = CrashReporter.getInstance().getAgentConfiguration().getApplicationToken();
        this.deviceInfo = new DeviceInfo(impl.getDeviceInformation(), impl.getEnvironmentInformation());
        this.applicationInfo = new ApplicationInfo(impl.getApplicationInformation());
        this.exceptionInfo = new ExceptionInfo(rootCause);
        this.threads = ThreadInfo.extractThreads(rootCause);
        this.activityHistory = TraceMachine.getActivityHistory();
        this.sessionAttributes = set;
        this.events = collection;
        this.analyticsEnabled = z;
        this.uploadCount = 0;
    }
}
