package com.newrelic.agent.android.crash;

import com.newrelic.agent.android.AgentConfiguration;
import com.newrelic.agent.android.harvest.Harvest;
import com.newrelic.agent.android.harvest.HarvestLifecycleAware;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.metric.MetricNames;
import com.newrelic.agent.android.payload.PayloadController;
import com.newrelic.agent.android.payload.PayloadReporter;
import com.newrelic.agent.android.payload.PayloadSender;
import com.newrelic.agent.android.stats.StatsEngine;
import java.util.concurrent.Callable;
import java.util.concurrent.Future;
import java.util.concurrent.atomic.AtomicReference;
import p085c.p086a.p087a.p088a.outline;

public class CrashReporter extends PayloadReporter implements HarvestLifecycleAware {
    public static AtomicReference<CrashReporter> instance = new AtomicReference<>((Object) null);
    public static boolean reportCrashes = false;
    public final CrashStore crashStore;
    public final UncaughtExceptionHandler uncaughtExceptionHandler = new UncaughtExceptionHandler(this);

    public CrashReporter(AgentConfiguration agentConfiguration) {
        super(agentConfiguration);
        this.crashStore = agentConfiguration.getCrashStore();
        this.isEnabled.set(agentConfiguration.getReportCrashes());
    }

    public static CrashReporter getInstance() {
        return instance.get();
    }

    public static UncaughtExceptionHandler getUncaughtExceptionHandler() {
        if (isInitialized()) {
            return instance.get().uncaughtExceptionHandler;
        }
        return null;
    }

    public static CrashReporter initialize(AgentConfiguration agentConfiguration) {
        instance.compareAndSet((Object) null, new CrashReporter(agentConfiguration));
        Harvest.addHarvestListener(instance.get());
        return instance.get();
    }

    public static boolean isInitialized() {
        return instance.get() != null;
    }

    public static void setReportCrashes(boolean z) {
        if (isInitialized()) {
            reportCrashes = z;
        }
    }

    public static void shutdown() {
        if (isInitialized()) {
            instance.get().stop();
            instance.set((Object) null);
        }
    }

    public void onHarvest() {
    }

    public void onHarvestBefore() {
    }

    public void onHarvestComplete() {
    }

    public void onHarvestConnected() {
        PayloadController.submitCallable(new Callable() {
            public Void call() {
                CrashReporter.this.reportSavedCrashes();
                CrashReporter.this.reportSupportabilityMetrics();
                return null;
            }
        });
    }

    public void onHarvestDisabled() {
    }

    public void onHarvestDisconnected() {
    }

    public void onHarvestError() {
    }

    public void onHarvestFinalize() {
    }

    public void onHarvestSendFailed() {
    }

    public void onHarvestStart() {
    }

    public void onHarvestStop() {
    }

    public Future reportCrash(final Crash crash) {
        boolean isValid = Harvest.getHarvestConfiguration().getDataToken().isValid();
        if (!reportCrashes) {
            return null;
        }
        if (!isValid) {
            PayloadReporter.log.warning("CrashReporter.reportCrash(Crash): agent has not successfully connected and cannot report crashes.");
            return null;
        } else if (crash != null) {
            return PayloadController.submitPayload(new CrashSender(crash, this.agentConfiguration), new PayloadSender.CompletionHandler() {
                public void onException(PayloadSender payloadSender, Exception exc) {
                    AgentLog access$000 = PayloadReporter.log;
                    access$000.error("Crash upload failed: " + exc);
                }

                public void onResponse(PayloadSender payloadSender) {
                    CrashStore crashStore;
                    if (payloadSender.isSuccessfulResponse() && (crashStore = CrashReporter.this.crashStore) != null) {
                        crashStore.delete(crash);
                    }
                }
            });
        } else {
            PayloadReporter.log.warning("CrashReporter.reportCrash(Crash): attempted to report null crash.");
            return null;
        }
    }

    public void reportSavedCrashes() {
        CrashStore crashStore2 = this.crashStore;
        if (crashStore2 != null) {
            for (Crash next : crashStore2.fetchAll()) {
                if (next.isStale()) {
                    this.crashStore.delete(next);
                    AgentLog agentLog = PayloadReporter.log;
                    StringBuilder a = outline.m2937a("Crash [");
                    a.append(next.getUuid().toString());
                    a.append("] has become stale, and has been removed");
                    agentLog.info(a.toString());
                    StatsEngine.get().inc(MetricNames.SUPPORTABILITY_CRASH_REMOVED_STALE);
                } else {
                    reportCrash(next);
                }
            }
        }
    }

    public void start() {
        if (!isInitialized()) {
            PayloadReporter.log.error("AgentDataReporter.start(): Must initialize PayloadController first.");
        } else if (isEnabled() && this.isStarted.compareAndSet(false, true)) {
            this.uncaughtExceptionHandler.installExceptionHandler();
            reportCrashes = this.agentConfiguration.getReportCrashes();
        }
    }

    public void stop() {
        if (getUncaughtExceptionHandler() != null) {
            getUncaughtExceptionHandler().resetExceptionHandler();
        }
    }

    public void storeAndReportCrash(Crash crash) {
        CrashStore crashStore2 = this.crashStore;
        if (crashStore2 == null) {
            PayloadReporter.log.warning("CrashReporter.storeAndReportCrash(Crash): attempted to store crash without a crash store.");
        } else if (crash == null) {
            PayloadReporter.log.warning("CrashReporter.storeAndReportCrash(Crash): attempted to store null crash.");
        } else if (!crashStore2.store(crash)) {
            PayloadReporter.log.warning("CrashReporter.storeAndReportCrash(Crash): failed to store passed crash.");
        }
        try {
            reportCrash(crash);
        } catch (Exception e) {
            AgentLog agentLog = PayloadReporter.log;
            agentLog.warning("CrashReporter.storeAndReportCrash(Crash): " + e);
        }
    }
}
