package com.newrelic.agent.android.crash;

import com.newrelic.agent.android.Agent;
import com.newrelic.agent.android.AgentConfiguration;
import com.newrelic.agent.android.FeatureFlag;
import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.analytics.AnalyticsControllerImpl;
import com.newrelic.agent.android.background.ApplicationStateMonitor;
import com.newrelic.agent.android.harvest.Harvest;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.payload.PayloadController;
import com.newrelic.agent.android.stats.StatsEngine;
import java.lang.Thread;
import java.util.concurrent.atomic.AtomicBoolean;
import p085c.p086a.p087a.p088a.outline;

public class UncaughtExceptionHandler implements Thread.UncaughtExceptionHandler {
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public static Thread.UncaughtExceptionHandler previousExceptionHandler = null;
    public final CrashReporter crashReporter;
    public final AtomicBoolean handledException = new AtomicBoolean(false);

    public UncaughtExceptionHandler(CrashReporter crashReporter2) {
        this.crashReporter = crashReporter2;
    }

    public void chainExceptionHandler(Thread.UncaughtExceptionHandler uncaughtExceptionHandler, Thread thread, Throwable th) {
        if (uncaughtExceptionHandler != null) {
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("Chaining crash reporting duties to ");
            a.append(uncaughtExceptionHandler.getClass().getSimpleName());
            agentLog.debug(a.toString());
            uncaughtExceptionHandler.uncaughtException(thread, th);
        }
    }

    public Thread.UncaughtExceptionHandler getPreviousExceptionHandler() {
        return previousExceptionHandler;
    }

    public void installExceptionHandler() {
        Thread.UncaughtExceptionHandler defaultUncaughtExceptionHandler = Thread.getDefaultUncaughtExceptionHandler();
        if (defaultUncaughtExceptionHandler == null) {
            log.debug("Installing New Relic crash handler.");
        } else if (defaultUncaughtExceptionHandler instanceof UncaughtExceptionHandler) {
            log.debug("New Relic crash handler already installed.");
            return;
        } else {
            Thread.UncaughtExceptionHandler uncaughtExceptionHandler = previousExceptionHandler;
            if (uncaughtExceptionHandler != null) {
                if (uncaughtExceptionHandler instanceof UncaughtExceptionHandler) {
                    AgentLog agentLog = log;
                    StringBuilder a = outline.m2937a("Previous uncaught exception handler[");
                    a.append(previousExceptionHandler.getClass().getName());
                    a.append("] exists, and it is us! Replace it.");
                    agentLog.warning(a.toString());
                } else {
                    AgentLog agentLog2 = log;
                    StringBuilder a2 = outline.m2937a("Previous uncaught exception handler[");
                    a2.append(previousExceptionHandler.getClass().getName());
                    a2.append("] exists. Assuming it delegates to [");
                    a2.append(UncaughtExceptionHandler.class.getName());
                    a2.append("]");
                    agentLog2.warning(a2.toString());
                    return;
                }
            }
            AgentLog agentLog3 = log;
            StringBuilder a3 = outline.m2937a("Installing New Relic crash handler and chaining to ");
            a3.append(defaultUncaughtExceptionHandler.getClass().getName());
            agentLog3.debug(a3.toString());
        }
        previousExceptionHandler = defaultUncaughtExceptionHandler;
        Thread.setDefaultUncaughtExceptionHandler(this);
    }

    public void resetExceptionHandler() {
        Thread.UncaughtExceptionHandler defaultUncaughtExceptionHandler;
        if (!(previousExceptionHandler == null || (defaultUncaughtExceptionHandler = Thread.getDefaultUncaughtExceptionHandler()) == null)) {
            if (defaultUncaughtExceptionHandler instanceof UncaughtExceptionHandler) {
                Thread.setDefaultUncaughtExceptionHandler(previousExceptionHandler);
                previousExceptionHandler = null;
            } else {
                AgentLog agentLog = log;
                StringBuilder a = outline.m2937a("Previous uncaught exception handler[");
                a.append(defaultUncaughtExceptionHandler.getClass().getName());
                a.append("] was set after agent start. Let it be...");
                agentLog.warning(a.toString());
            }
        }
        this.handledException.set(false);
    }

    public void uncaughtException(Thread thread, Throwable th) {
        if (Agent.getUnityInstrumentationFlag().equals("YES") || this.handledException.compareAndSet(false, true)) {
            try {
                AgentConfiguration agentConfiguration = this.crashReporter.getAgentConfiguration();
                if (this.crashReporter.isEnabled()) {
                    if (FeatureFlag.featureEnabled(FeatureFlag.CrashReporting)) {
                        AgentLog agentLog = log;
                        agentLog.debug("A crash has been detected in " + thread.getStackTrace()[0].getClassName() + " and will be reported ASAP.");
                        AgentLog agentLog2 = log;
                        StringBuilder sb = new StringBuilder();
                        sb.append("Analytics data is currently ");
                        sb.append(agentConfiguration.getEnableAnalyticsEvents() ? "enabled " : "disabled");
                        agentLog2.debug(sb.toString());
                        AnalyticsControllerImpl instance = AnalyticsControllerImpl.getInstance();
                        instance.setEnabled(true);
                        long millisSinceStart = Harvest.getMillisSinceStart();
                        if (millisSinceStart != 0) {
                            instance.setAttribute(AnalyticAttribute.SESSION_DURATION_ATTRIBUTE, (double) (((float) millisSinceStart) / 1000.0f), false);
                        }
                        this.crashReporter.storeAndReportCrash(new Crash(th, instance.getSessionAttributes(), instance.getEventManager().getQueuedEvents(), agentConfiguration.getEnableAnalyticsEvents()));
                        if (Agent.isInstantApp()) {
                            Harvest.shutdown();
                            ApplicationStateMonitor.getInstance().uiHidden();
                        }
                        Thread.UncaughtExceptionHandler uncaughtExceptionHandler = previousExceptionHandler;
                        PayloadController.shutdown();
                        if (!Agent.getUnityInstrumentationFlag().equals("YES")) {
                            chainExceptionHandler(uncaughtExceptionHandler, thread, th);
                            return;
                        }
                        return;
                    }
                }
                log.debug("A crash has been detected but crash reporting is disabled!");
            } finally {
                if (Agent.isInstantApp()) {
                    Harvest.shutdown();
                    ApplicationStateMonitor.getInstance().uiHidden();
                }
                Thread.UncaughtExceptionHandler uncaughtExceptionHandler2 = previousExceptionHandler;
                PayloadController.shutdown();
                if (!Agent.getUnityInstrumentationFlag().equals("YES")) {
                    chainExceptionHandler(uncaughtExceptionHandler2, thread, th);
                }
            }
        } else {
            StatsEngine.get().inc("Supportability/AgentHealth/Recursion/UncaughtExceptionHandler");
        }
    }
}
