package com.newrelic.agent.android.gestures;

import android.annotation.TargetApi;
import android.app.Activity;
import android.app.Fragment;
import android.view.MotionEvent;
import android.view.View;
import android.view.Window;
import com.newrelic.agent.android.FeatureFlag;
import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import java.util.HashMap;
import java.util.concurrent.atomic.AtomicReference;
import p085c.p086a.p087a.p088a.outline;

public class GestureObserver {
    public static AtomicReference<GestureObserver> instance = new AtomicReference<>((Object) null);
    public static final AgentLog log = AgentLogManager.getAgentLog();

    public static GestureObserver getInstance() {
        if (instance.compareAndSet((Object) null, new GestureObserver())) {
            log.debug("GestureObserver: instance created");
        }
        return instance.get();
    }

    public static boolean isSubClassOf(Object obj, Class cls) {
        return cls.isAssignableFrom(obj.getClass());
    }

    public void onActivityBackPressed(Object obj) {
        if (FeatureFlag.featureEnabled(FeatureFlag.GestureInstrumentation) && isSubClassOf(obj, Activity.class)) {
            Activity activity = (Activity) obj;
            HashMap hashMap = new HashMap();
            hashMap.put(AnalyticAttribute.GESTURE_BACK_PRESSED_ATTRIBUTE, activity.getLocalClassName());
            GestureReporter.recordOnClick(activity.getCurrentFocus(), hashMap);
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("[Gesture] onBackPressed on activity [");
            a.append(activity.getLocalClassName());
            a.append("]");
            agentLog.debug(a.toString());
        }
    }

    @TargetApi(11)
    public void onActivityOrFragmentStarted(Object obj) {
        if (isSubClassOf(obj, Fragment.class)) {
            onFragmentStarted((Fragment) obj);
        } else if (isSubClassOf(obj, androidx.fragment.app.Fragment.class)) {
            onFragmentStarted((androidx.fragment.app.Fragment) obj);
        } else if (isSubClassOf(obj, Activity.class)) {
            onActivityStarted((Activity) obj);
        } else {
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("[Gesture] Received a class we didn't expect [");
            a.append(obj.getClass().getName());
            a.append("]");
            agentLog.debug(a.toString());
        }
    }

    @TargetApi(11)
    public void onActivityOrFragmentStopped(Object obj) {
        if (isSubClassOf(obj, Fragment.class)) {
            onFragmentStopped((Fragment) obj);
        } else if (isSubClassOf(obj, androidx.fragment.app.Fragment.class)) {
            onFragmentStopped((androidx.fragment.app.Fragment) obj);
        } else if (isSubClassOf(obj, Activity.class)) {
            onActivityStopped((Activity) obj);
        } else {
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("[Gesture] Received a class we didn't expect [");
            a.append(obj.getClass().getName());
            a.append("]");
            agentLog.debug(a.toString());
        }
    }

    public boolean onActivityOrFragmentTouched(MotionEvent motionEvent, Object obj) {
        GestureReporter gestureReporter;
        if (!FeatureFlag.featureEnabled(FeatureFlag.GestureInstrumentation) || !isSubClassOf(obj, Activity.class) || (gestureReporter = GestureReporter.getGestureReporter((Activity) obj)) == null) {
            return false;
        }
        gestureReporter.detector.f2504a.mo3120a(motionEvent);
        return false;
    }

    public void onActivityStarted(Activity activity) {
        if (FeatureFlag.featureEnabled(FeatureFlag.GestureInstrumentation)) {
            pushContext(activity);
        }
    }

    public void onActivityStopped(Activity activity) {
        if (FeatureFlag.featureEnabled(FeatureFlag.GestureInstrumentation)) {
            popContext(activity);
        }
    }

    public void onFragmentStarted(androidx.fragment.app.Fragment fragment) {
        if (FeatureFlag.featureEnabled(FeatureFlag.GestureInstrumentation)) {
            pushContext(fragment);
        }
    }

    public void onFragmentStopped(androidx.fragment.app.Fragment fragment) {
        if (FeatureFlag.featureEnabled(FeatureFlag.GestureInstrumentation)) {
            popContext(fragment);
        }
    }

    public void popContext(Activity activity) {
        GestureReporter invalidate = GestureReporter.invalidate(activity);
        if (invalidate != null) {
            invalidate.shutdown();
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("[Gesture] Activity stopped [");
            a.append(activity.getLocalClassName());
            a.append(":");
            a.append(Integer.valueOf(activity.hashCode()));
            a.append("]");
            agentLog.debug(a.toString());
        }
    }

    public void pushContext(Activity activity) {
        View rootView;
        Window window = activity.getWindow();
        if (window != null && window.getDecorView() != null && (rootView = window.getDecorView().getRootView()) != null && isSubClassOf(rootView, View.class)) {
            String localClassName = activity.getLocalClassName();
            if (GestureReporter.getGestureReporter(activity) == null) {
                GestureReporter.provideGestureReporter(activity, rootView);
                AgentLog agentLog = log;
                agentLog.debug("[Gesture] Activity started [" + localClassName + ":" + Integer.valueOf(activity.hashCode()) + "]");
            }
        }
    }

    @TargetApi(11)
    public void onFragmentStarted(Fragment fragment) {
        if (FeatureFlag.featureEnabled(FeatureFlag.GestureInstrumentation)) {
            pushContext(fragment);
        }
    }

    @TargetApi(11)
    public void onFragmentStopped(Fragment fragment) {
        if (FeatureFlag.featureEnabled(FeatureFlag.GestureInstrumentation)) {
            popContext(fragment);
        }
    }

    private void popContext(Fragment fragment) {
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("[Gesture] Fragment stopped [");
        a.append(fragment.getClass().getSimpleName());
        a.append(":");
        a.append(Integer.valueOf(fragment.hashCode()));
        a.append("]");
        agentLog.debug(a.toString());
    }

    private void popContext(androidx.fragment.app.Fragment fragment) {
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("[Gesture] Fragment stopped [");
        a.append(fragment.getClass().getSimpleName());
        a.append(":");
        a.append(Integer.valueOf(fragment.hashCode()));
        a.append("]");
        agentLog.debug(a.toString());
    }

    @TargetApi(11)
    public void pushContext(androidx.fragment.app.Fragment fragment) {
        View view = fragment.getView();
        if (view != null && isSubClassOf(view, View.class)) {
            String simpleName = fragment.getClass().getSimpleName();
            GestureReporter gestureReporter = GestureReporter.getGestureReporter(fragment.getActivity());
            if (gestureReporter == null) {
                GestureReporter.provideGestureReporter(fragment.getActivity(), view);
                AgentLog agentLog = log;
                agentLog.debug("[Gesture] Fragment started [" + simpleName + ":" + Integer.valueOf(fragment.hashCode()) + "]");
                return;
            }
            gestureReporter.addView(view);
        }
    }

    @TargetApi(11)
    public void pushContext(Fragment fragment) {
        View view = fragment.getView();
        if (view != null && isSubClassOf(view, View.class)) {
            String simpleName = fragment.getClass().getSimpleName();
            GestureReporter gestureReporter = GestureReporter.getGestureReporter(fragment.getActivity());
            if (gestureReporter == null) {
                GestureReporter.provideGestureReporter(fragment.getActivity(), view);
                AgentLog agentLog = log;
                agentLog.debug("[Gesture] Fragment started [" + simpleName + ":" + Integer.valueOf(fragment.hashCode()) + "]");
                return;
            }
            gestureReporter.addView(view);
        }
    }
}
