package com.newrelic.agent.android.gestures;

import android.annotation.TargetApi;
import android.app.ActionBar;
import android.app.Activity;
import android.content.res.Resources;
import android.graphics.Rect;
import android.text.TextUtils;
import android.view.GestureDetector;
import android.view.MotionEvent;
import android.view.View;
import android.view.ViewGroup;
import android.view.ViewStub;
import android.widget.AdapterView;
import android.widget.ImageView;
import android.widget.TextView;
import com.newrelic.agent.android.Agent;
import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.connectivity.UserActionFacade;
import com.newrelic.agent.android.connectivity.UserActionType;
import com.newrelic.agent.android.instrumentation.ViewInstrumentation;
import com.newrelic.agent.android.instrumentation.ViewListeners;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import java.util.Arrays;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Locale;
import java.util.Map;
import java.util.Set;
import java.util.UUID;
import java.util.concurrent.ExecutorService;
import java.util.concurrent.Executors;
import java.util.concurrent.RejectedExecutionException;
import java.util.concurrent.atomic.AtomicReference;
import p008b.p033h.p045m.GestureDetectorCompat;
import p085c.p086a.p087a.p088a.outline;

@TargetApi(11)
public class GestureReporter extends GestureDetector.SimpleOnGestureListener implements View.OnTouchListener {
    public static final AtomicReference<GestureReporter> currentGestureReporter = new AtomicReference<>((Object) null);
    public static final Map<Integer, GestureReporter> gestureReporterMap = new HashMap();
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public static Set<Class> supportedClasses = new HashSet(Arrays.asList(new Class[]{TextView.class, ImageView.class, ActionBar.class, AdapterView.class, ViewStub.class}));
    public final HashMap<Integer, View> controlCache = new HashMap<>();
    public final GestureDetectorCompat detector;
    public final ExecutorService executor = Executors.newSingleThreadExecutor();
    public String gestureId;

    public GestureReporter(Activity activity, View view) {
        this.detector = new GestureDetectorCompat(activity, this);
        this.gestureId = generateGestureId(view);
        addView(view);
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("[Gesture] Attached to activity [");
        a.append(activity.getLocalClassName());
        a.append("]");
        agentLog.info(a.toString());
    }

    private void attachChildTouchListeners(Set<View> set) {
        for (View next : set) {
            if (shouldTrackControl(next)) {
                this.controlCache.put(Integer.valueOf(next.hashCode()), next);
                ViewInstrumentation.setOnTouchListener(next, this);
                AgentLog agentLog = log;
                StringBuilder a = outline.m2937a("[Gesture] Will monitor touch events on view [");
                a.append(next.toString());
                a.append("]");
                agentLog.debug(a.toString());
            }
        }
    }

    public static Set<View> gatherChildViews(View view) {
        HashSet hashSet = new HashSet();
        if (!GestureObserver.isSubClassOf(view, ViewGroup.class)) {
            hashSet.add(view);
            return hashSet;
        }
        ViewGroup viewGroup = (ViewGroup) view;
        int min = Math.min(64, viewGroup.getChildCount());
        if (min == 0) {
            hashSet.add(view);
        } else {
            for (int i = 0; i < min; i++) {
                hashSet.addAll(gatherChildViews(viewGroup.getChildAt(i)));
            }
        }
        return hashSet;
    }

    public static GestureReporter getGestureReporter() {
        return currentGestureReporter.get();
    }

    public static GestureReporter invalidate(Activity activity) {
        GestureReporter remove = gestureReporterMap.remove(Integer.valueOf(activity.hashCode()));
        if (remove != null) {
            remove.shutdown();
        }
        currentGestureReporter.compareAndSet(remove, (Object) null);
        return remove;
    }

    public static GestureReporter provideGestureReporter(Activity activity, View view) {
        if (!gestureReporterMap.containsKey(Integer.valueOf(activity.hashCode()))) {
            currentGestureReporter.set(new GestureReporter(activity, view));
            gestureReporterMap.put(Integer.valueOf(activity.hashCode()), currentGestureReporter.get());
        }
        return gestureReporterMap.get(Integer.valueOf(activity.hashCode()));
    }

    public static void recordOnClick(final View view, final Map<String, Object> map) {
        final GestureReporter gestureReporter = getGestureReporter();
        if (gestureReporter != null) {
            gestureReporter.mo7633bg(new Runnable() {
                public void run() {
                    AgentLog access$000 = GestureReporter.log;
                    StringBuilder a = outline.m2937a("[Gesture] onClick [");
                    a.append(view.getClass().getSimpleName());
                    a.append("]");
                    access$000.audit(a.toString());
                    Map<String, Object> createGestureViewAttributes = gestureReporter.createGestureViewAttributes(view);
                    Map map = map;
                    if (map != null) {
                        createGestureViewAttributes.putAll(map);
                    }
                    UserActionFacade.getInstance().recordUserAction(UserActionType.Tap, createGestureViewAttributes);
                }
            });
        }
    }

    public static void recordOnLongClick(final View view, final Map<String, Object> map) {
        final GestureReporter gestureReporter = getGestureReporter();
        if (gestureReporter != null) {
            gestureReporter.mo7633bg(new Runnable() {
                public void run() {
                    AgentLog access$000 = GestureReporter.log;
                    StringBuilder a = outline.m2937a("[Gesture] onLongClick [");
                    a.append(view.getClass().getSimpleName());
                    a.append("]");
                    access$000.audit(a.toString());
                    Map<String, Object> createGestureViewAttributes = gestureReporter.createGestureViewAttributes(view);
                    Map map = map;
                    if (map != null) {
                        createGestureViewAttributes.putAll(map);
                    }
                    UserActionFacade.getInstance().recordUserAction(UserActionType.DoubleTap, createGestureViewAttributes);
                }
            });
        }
    }

    public static void recordOnTouch(View view, MotionEvent motionEvent, Map<String, Object> map) {
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("[Gesture] onTouch [");
        a.append(view.getClass().getSimpleName());
        a.append("] MotionEvent[");
        a.append(motionEvent.toString());
        a.append("]");
        agentLog.audit(a.toString());
    }

    private boolean resourceHasPackage(int i) {
        return (i >>> 24) != 0;
    }

    public Set<View> addView(View view) {
        Set<View> gatherChildViews = gatherChildViews(view);
        attachChildTouchListeners(gatherChildViews);
        ViewInstrumentation.setOnTouchListener(view, this);
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("[Gesture] Attached to view [");
        a.append(view.toString());
        a.append("]");
        agentLog.debug(a.toString());
        return gatherChildViews;
    }

    /* renamed from: bg */
    public void mo7633bg(Runnable runnable) {
        try {
            this.executor.submit(runnable);
        } catch (RejectedExecutionException e) {
            AgentLog agentLog = log;
            agentLog.warning("GestureReporter: " + e);
        }
    }

    public Map<String, Object> createGestureControlAttributes(ViewListeners.ListenerElement listenerElement) {
        HashMap hashMap = new HashMap();
        if (listenerElement != null) {
            hashMap.put(AnalyticAttribute.GESTURE_TARGET_OBJECT_ATTRIBUTE, listenerElement.targetObject);
            hashMap.put(AnalyticAttribute.GESTURE_METHOD_EXECUTED_ATTRIBUTE, listenerElement.methodExecuted);
        }
        return hashMap;
    }

    public Map<String, Object> createGestureMotionEventAttributes(MotionEvent motionEvent) {
        HashMap hashMap = new HashMap();
        hashMap.put(AnalyticAttribute.GESTURE_COORDINATES_ATTRIBUTE, String.format("{%d,%d}", new Object[]{Integer.valueOf((int) motionEvent.getRawX()), Integer.valueOf((int) motionEvent.getRawY())}));
        View findViewByMotionEvent = findViewByMotionEvent(motionEvent);
        if (findViewByMotionEvent != null) {
            hashMap.putAll(createGestureViewAttributes(findViewByMotionEvent));
        }
        return hashMap;
    }

    public Map<String, Object> createGestureViewAttributes(View view) {
        HashMap hashMap = new HashMap();
        hashMap.put(AnalyticAttribute.GESTURE_ORIENTATION_ATTRIBUTE, Agent.getImpl().getEnvironmentInformation().getOrientation() == 1 ? "Portrait" : "Landscape");
        if (view != null) {
            Rect rect = new Rect();
            this.gestureId = generateGestureId(view);
            view.getGlobalVisibleRect(rect);
            hashMap.put(AnalyticAttribute.GESTURE_CONTROL_ID_ATTRIBUTE, this.gestureId);
            hashMap.put(AnalyticAttribute.GESTURE_CONTROL_CLASS_ATTRIBUTE, view.getClass().getName());
            hashMap.put(AnalyticAttribute.GESTURE_CONTROL_RECT_ATTRIBUTE, String.format(Locale.getDefault(), "{{%d,%d},{%d,%d}}", new Object[]{Integer.valueOf(rect.left), Integer.valueOf(rect.top), Integer.valueOf(rect.width() + rect.left), Integer.valueOf(rect.height() + rect.top)}));
            if (view.getContentDescription() != null) {
                hashMap.put(AnalyticAttribute.GESTURE_CONTENT_DESCRIPTION_ATTRIBUTE, view.getContentDescription());
            }
            ViewListeners.ListenerElement listenerElement = ViewListeners.getListenerElement(view.hashCode());
            if (listenerElement != null) {
                hashMap.putAll(createGestureControlAttributes(listenerElement));
            }
            if (GestureObserver.isSubClassOf(view, TextView.class)) {
                try {
                    String charSequence = ((TextView) view).getText().toString();
                    if (!TextUtils.isEmpty(charSequence)) {
                        hashMap.put(AnalyticAttribute.GESTURE_LABEL_ATTRIBUTE, charSequence);
                    }
                } catch (Exception unused) {
                }
            }
        }
        return hashMap;
    }

    public View findViewByMotionEvent(MotionEvent motionEvent) {
        Rect rect = new Rect();
        int rawX = (int) motionEvent.getRawX();
        int rawY = (int) motionEvent.getRawY();
        for (View next : this.controlCache.values()) {
            next.getGlobalVisibleRect(rect);
            if (rect.contains(rawX, rawY)) {
                return next;
            }
        }
        return null;
    }

    public String generateGestureId(View view) {
        String str;
        Integer.valueOf(view.getId()).toString();
        int id = view.getId();
        if (id == -1) {
            return UUID.randomUUID().toString();
        }
        StringBuilder sb = new StringBuilder(1024);
        sb.append(view.getClass().getName());
        sb.append('{');
        Resources resources = view.getResources();
        if (resourceHasPackage(id) && resources != null) {
            int i = -16777216 & id;
            if (i == 16777216) {
                str = "android";
            } else if (i != 2130706432) {
                try {
                    str = resources.getResourcePackageName(id);
                } catch (Exception unused) {
                }
            } else {
                str = "app";
            }
            String resourceTypeName = resources.getResourceTypeName(id);
            String resourceEntryName = resources.getResourceEntryName(id);
            sb.append(str);
            sb.append(":");
            sb.append(resourceTypeName);
            sb.append("/");
            sb.append(resourceEntryName);
        }
        sb.append("}");
        return sb.toString();
    }

    public boolean onDoubleTap(final MotionEvent motionEvent) {
        mo7633bg(new Runnable() {
            public void run() {
                AgentLog access$000 = GestureReporter.log;
                StringBuilder a = outline.m2937a("[Gesture] onDoubleTap: MotionEvent[");
                a.append(motionEvent.toString());
                a.append("]");
                access$000.audit(a.toString());
                UserActionFacade.getInstance().recordUserAction(UserActionType.DoubleTap, GestureReporter.this.createGestureMotionEventAttributes(motionEvent));
            }
        });
        return false;
    }

    public boolean onDown(MotionEvent motionEvent) {
        return true;
    }

    public boolean onFling(MotionEvent motionEvent, MotionEvent motionEvent2, float f, float f2) {
        final MotionEvent motionEvent3 = motionEvent;
        final MotionEvent motionEvent4 = motionEvent2;
        final float f3 = f;
        final float f4 = f2;
        mo7633bg(new Runnable() {
            public void run() {
                AgentLog access$000 = GestureReporter.log;
                StringBuilder a = outline.m2937a("[Gesture] onFling: MotionEvent1[");
                a.append(motionEvent3.toString());
                a.append("] MotionEvent2[");
                a.append(motionEvent4.toString());
                a.append("] velX[");
                a.append(f3);
                a.append("] velY[");
                a.append(f4);
                a.append("]");
                access$000.audit(a.toString());
                UserActionFacade.getInstance().recordUserAction(UserActionType.Swipe, GestureReporter.this.createGestureMotionEventAttributes(motionEvent3));
            }
        });
        return false;
    }

    public boolean onSingleTapConfirmed(final MotionEvent motionEvent) {
        mo7633bg(new Runnable() {
            public void run() {
                AgentLog access$000 = GestureReporter.log;
                StringBuilder a = outline.m2937a("[Gesture] onSingleTapConfirmed: MotionEvent[");
                a.append(motionEvent.toString());
                a.append("]");
                access$000.audit(a.toString());
                UserActionFacade.getInstance().recordUserAction(UserActionType.Tap, GestureReporter.this.createGestureMotionEventAttributes(motionEvent));
            }
        });
        return false;
    }

    public boolean onTouch(View view, MotionEvent motionEvent) {
        this.detector.f2504a.mo3120a(motionEvent);
        return false;
    }

    public boolean shouldTrackControl(View view) {
        try {
            for (Class isSubClassOf : supportedClasses) {
                if (GestureObserver.isSubClassOf(view, isSubClassOf)) {
                    return true;
                }
            }
            return false;
        } catch (Exception unused) {
            return false;
        }
    }

    public void shutdown() {
        try {
            this.executor.shutdown();
            this.controlCache.clear();
        } catch (Exception unused) {
        }
    }

    public static GestureReporter getGestureReporter(Activity activity) {
        return gestureReporterMap.get(Integer.valueOf(activity.hashCode()));
    }
}
