package com.newrelic.agent.android.sample;

import android.app.ActivityManager;
import android.content.Context;
import android.os.Build;
import android.os.Debug;
import android.os.Process;
import com.newrelic.agent.android.harvest.AgentHealth;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.metric.Metric;
import com.newrelic.agent.android.stats.TicToc;
import com.newrelic.agent.android.tracing.ActivityTrace;
import com.newrelic.agent.android.tracing.Sample;
import com.newrelic.agent.android.tracing.TraceLifecycleAware;
import com.newrelic.agent.android.tracing.TraceMachine;
import com.newrelic.agent.android.util.NamedThreadFactory;
import java.io.IOException;
import java.io.RandomAccessFile;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Collections;
import java.util.EnumMap;
import java.util.HashMap;
import java.util.Map;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ScheduledFuture;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicBoolean;
import java.util.concurrent.locks.ReentrantLock;
import p085c.p086a.p087a.p088a.outline;

public class Sampler implements TraceLifecycleAware, Runnable {
    public static final int KB_IN_MB = 1024;
    public static final int[] PID = {Process.myPid()};
    public static final long SAMPLE_FREQ_MS = 100;
    public static final long SAMPLE_FREQ_MS_MAX = 250;
    public static boolean cpuSamplingDisabled = false;
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public static Sampler sampler;
    public static final ReentrantLock samplerLock = new ReentrantLock();
    public final ActivityManager activityManager;
    public RandomAccessFile appStatFile;
    public final AtomicBoolean isRunning = new AtomicBoolean(false);
    public Long lastAppCpuTime;
    public Long lastCpuTime;
    public RandomAccessFile procStatFile;
    public long sampleFreqMs = 100;
    public ScheduledFuture sampleFuture;
    public Metric samplerServiceMetric;
    public final EnumMap<Sample.SampleType, Collection<Sample>> samples = new EnumMap<>(Sample.SampleType.class);
    public final ScheduledExecutorService scheduler = Executors.newSingleThreadScheduledExecutor(new NamedThreadFactory("Sampler"));

    public Sampler(Context context) {
        this.activityManager = (ActivityManager) context.getSystemService("activity");
        this.samples.put(Sample.SampleType.MEMORY, new ArrayList());
        this.samples.put(Sample.SampleType.CPU, new ArrayList());
    }

    /* JADX INFO: finally extract failed */
    public static Map<Sample.SampleType, Collection<Sample>> copySamples() {
        samplerLock.lock();
        try {
            if (sampler == null) {
                samplerLock.unlock();
                HashMap hashMap = new HashMap();
                samplerLock.unlock();
                return hashMap;
            }
            EnumMap enumMap = new EnumMap(sampler.samples);
            for (Sample.SampleType next : sampler.samples.keySet()) {
                enumMap.put(next, new ArrayList(sampler.samples.get(next)));
            }
            samplerLock.unlock();
            return Collections.unmodifiableMap(enumMap);
        } catch (Throwable th) {
            samplerLock.unlock();
            throw th;
        }
    }

    private Collection<Sample> getSampleCollection(Sample.SampleType sampleType) {
        return this.samples.get(sampleType);
    }

    public static void init(Context context) {
        samplerLock.lock();
        try {
            if (sampler == null) {
                Sampler provideSampler = provideSampler(context);
                sampler = provideSampler;
                provideSampler.sampleFreqMs = 100;
                provideSampler.samplerServiceMetric = new Metric("samplerServiceTime");
                TraceMachine.addTraceListener(sampler);
                if (Build.VERSION.SDK_INT >= 24) {
                    cpuSamplingDisabled = true;
                    log.debug("CPU sampling not supported in Android 8 and above.");
                }
                log.debug("Sampler initialized");
            }
        } catch (Exception e) {
            AgentLog agentLog = log;
            agentLog.error("Sampler init failed: " + e.getMessage());
            shutdown();
        } catch (Throwable th) {
            samplerLock.unlock();
            throw th;
        }
        samplerLock.unlock();
    }

    public static boolean isRunning() {
        ScheduledFuture scheduledFuture;
        Sampler sampler2 = sampler;
        if (sampler2 == null || (scheduledFuture = sampler2.sampleFuture) == null) {
            return false;
        }
        return !scheduledFuture.isDone();
    }

    public static Sampler provideSampler(Context context) {
        return new Sampler(context);
    }

    private void resetCpuSampler() {
        this.lastCpuTime = null;
        this.lastAppCpuTime = null;
        RandomAccessFile randomAccessFile = this.appStatFile;
        if (randomAccessFile != null && this.procStatFile != null) {
            try {
                randomAccessFile.close();
                this.procStatFile.close();
                this.appStatFile = null;
                this.procStatFile = null;
            } catch (IOException e) {
                AgentLog agentLog = log;
                StringBuilder a = outline.m2937a("Exception hit while resetting CPU sampler: ");
                a.append(e.getMessage());
                agentLog.debug(a.toString());
                AgentHealth.noticeException((Exception) e);
            }
        }
    }

    public static Sample sampleCpuInstance() {
        Sampler sampler2 = sampler;
        if (sampler2 == null) {
            return null;
        }
        return sampler2.sampleCpu();
    }

    public static Sample sampleMemory() {
        Sampler sampler2 = sampler;
        if (sampler2 == null) {
            return null;
        }
        return sampleMemory(sampler2.activityManager);
    }

    public static void shutdown() {
        samplerLock.lock();
        try {
            if (sampler != null) {
                TraceMachine.removeTraceListener(sampler);
                stopNow();
                sampler = null;
                log.debug("Sampler shutdown");
            }
        } finally {
            samplerLock.unlock();
        }
    }

    public static void start() {
        samplerLock.lock();
        try {
            if (sampler != null) {
                sampler.schedule();
                log.debug("Sampler started");
            }
        } finally {
            samplerLock.unlock();
        }
    }

    public static void stop() {
        samplerLock.lock();
        try {
            if (sampler != null) {
                sampler.stop(false);
                log.debug("Sampler stopped");
            }
        } finally {
            samplerLock.unlock();
        }
    }

    public static void stopNow() {
        samplerLock.lock();
        try {
            if (sampler != null) {
                sampler.stop(true);
                log.debug("Sampler hard stopped");
            }
        } finally {
            samplerLock.unlock();
        }
    }

    public void clear() {
        for (Collection<Sample> clear : this.samples.values()) {
            clear.clear();
        }
    }

    public void monitorSamplerServiceTime(double d) {
        this.samplerServiceMetric.sample(d);
        if (Double.valueOf(this.samplerServiceMetric.getTotal() / ((double) this.samplerServiceMetric.getCount())).doubleValue() > ((double) this.sampleFreqMs)) {
            log.debug("Sampler: sample service time has been exceeded. Increase by 10%");
            this.sampleFreqMs = Math.min((long) (((float) this.sampleFreqMs) * 1.1f), 250);
            ScheduledFuture scheduledFuture = this.sampleFuture;
            if (scheduledFuture != null) {
                scheduledFuture.cancel(true);
            }
            this.sampleFuture = this.scheduler.scheduleWithFixedDelay(this, 0, this.sampleFreqMs, TimeUnit.MILLISECONDS);
            log.debug(String.format("Sampler scheduler restarted; sampling will now occur every %d ms.", new Object[]{Long.valueOf(this.sampleFreqMs)}));
            this.samplerServiceMetric.clear();
        }
    }

    public void onEnterMethod() {
        if (!this.isRunning.get()) {
            start();
        }
    }

    public void onExitMethod() {
    }

    public void onTraceComplete(final ActivityTrace activityTrace) {
        this.scheduler.execute(new Runnable() {
            public void run() {
                try {
                    Sampler.this.stop(true);
                    activityTrace.setVitals(Sampler.copySamples());
                    Sampler.this.clear();
                } catch (RuntimeException e) {
                    Sampler.log.error(e.toString());
                }
            }
        });
    }

    public void onTraceRename(ActivityTrace activityTrace) {
    }

    public void onTraceStart(ActivityTrace activityTrace) {
        start();
    }

    public void run() {
        try {
            if (this.isRunning.get()) {
                sample();
            }
        } catch (Exception e) {
            log.error("Caught exception while running the sampler", e);
            AgentHealth.noticeException(e);
        }
    }

    public void sample() {
        TicToc ticToc = new TicToc();
        samplerLock.lock();
        try {
            ticToc.tic();
            Sample sampleMemory = sampleMemory();
            if (sampleMemory != null) {
                getSampleCollection(Sample.SampleType.MEMORY).add(sampleMemory);
            }
            Sample sampleCpu = sampleCpu();
            if (sampleCpu != null) {
                getSampleCollection(Sample.SampleType.CPU).add(sampleCpu);
            }
        } catch (Exception e) {
            AgentLog agentLog = log;
            agentLog.error("Sampling failed: " + e.getMessage());
            AgentHealth.noticeException(e);
        } catch (Throwable th) {
            samplerLock.unlock();
            throw th;
        }
        samplerLock.unlock();
        monitorSamplerServiceTime((double) ticToc.toc());
    }

    /* JADX WARNING: Removed duplicated region for block: B:15:0x00b0 A[Catch:{ Exception -> 0x00eb }] */
    /* JADX WARNING: Removed duplicated region for block: B:17:0x00bd A[Catch:{ Exception -> 0x00eb }] */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public com.newrelic.agent.android.tracing.Sample sampleCpu() {
        /*
            r10 = this;
            java.lang.String r0 = "r"
            java.lang.String r1 = " "
            boolean r2 = cpuSamplingDisabled
            r3 = 0
            if (r2 == 0) goto L_0x000a
            return r3
        L_0x000a:
            java.io.RandomAccessFile r2 = r10.procStatFile     // Catch:{ Exception -> 0x00eb }
            if (r2 == 0) goto L_0x0020
            java.io.RandomAccessFile r2 = r10.appStatFile     // Catch:{ Exception -> 0x00eb }
            if (r2 != 0) goto L_0x0013
            goto L_0x0020
        L_0x0013:
            java.io.RandomAccessFile r0 = r10.procStatFile     // Catch:{ Exception -> 0x00eb }
            r4 = 0
            r0.seek(r4)     // Catch:{ Exception -> 0x00eb }
            java.io.RandomAccessFile r0 = r10.appStatFile     // Catch:{ Exception -> 0x00eb }
            r0.seek(r4)     // Catch:{ Exception -> 0x00eb }
            goto L_0x004b
        L_0x0020:
            java.io.RandomAccessFile r2 = new java.io.RandomAccessFile     // Catch:{ Exception -> 0x00eb }
            java.lang.StringBuilder r4 = new java.lang.StringBuilder     // Catch:{ Exception -> 0x00eb }
            r4.<init>()     // Catch:{ Exception -> 0x00eb }
            java.lang.String r5 = "/proc/"
            r4.append(r5)     // Catch:{ Exception -> 0x00eb }
            int[] r5 = PID     // Catch:{ Exception -> 0x00eb }
            r6 = 0
            r5 = r5[r6]     // Catch:{ Exception -> 0x00eb }
            r4.append(r5)     // Catch:{ Exception -> 0x00eb }
            java.lang.String r5 = "/stat"
            r4.append(r5)     // Catch:{ Exception -> 0x00eb }
            java.lang.String r4 = r4.toString()     // Catch:{ Exception -> 0x00eb }
            r2.<init>(r4, r0)     // Catch:{ Exception -> 0x00eb }
            r10.appStatFile = r2     // Catch:{ Exception -> 0x00eb }
            java.io.RandomAccessFile r2 = new java.io.RandomAccessFile     // Catch:{ Exception -> 0x00eb }
            java.lang.String r4 = "/proc/stat"
            r2.<init>(r4, r0)     // Catch:{ Exception -> 0x00eb }
            r10.procStatFile = r2     // Catch:{ Exception -> 0x00eb }
        L_0x004b:
            java.io.RandomAccessFile r0 = r10.procStatFile     // Catch:{ Exception -> 0x00eb }
            java.lang.String r0 = r0.readLine()     // Catch:{ Exception -> 0x00eb }
            java.io.RandomAccessFile r2 = r10.appStatFile     // Catch:{ Exception -> 0x00eb }
            java.lang.String r2 = r2.readLine()     // Catch:{ Exception -> 0x00eb }
            java.lang.String[] r0 = r0.split(r1)     // Catch:{ Exception -> 0x00eb }
            java.lang.String[] r1 = r2.split(r1)     // Catch:{ Exception -> 0x00eb }
            r2 = 2
            r2 = r0[r2]     // Catch:{ Exception -> 0x00eb }
            long r4 = java.lang.Long.parseLong(r2)     // Catch:{ Exception -> 0x00eb }
            r2 = 3
            r2 = r0[r2]     // Catch:{ Exception -> 0x00eb }
            long r6 = java.lang.Long.parseLong(r2)     // Catch:{ Exception -> 0x00eb }
            long r4 = r4 + r6
            r2 = 4
            r2 = r0[r2]     // Catch:{ Exception -> 0x00eb }
            long r6 = java.lang.Long.parseLong(r2)     // Catch:{ Exception -> 0x00eb }
            long r4 = r4 + r6
            r2 = 5
            r2 = r0[r2]     // Catch:{ Exception -> 0x00eb }
            long r6 = java.lang.Long.parseLong(r2)     // Catch:{ Exception -> 0x00eb }
            long r4 = r4 + r6
            r2 = 6
            r2 = r0[r2]     // Catch:{ Exception -> 0x00eb }
            long r6 = java.lang.Long.parseLong(r2)     // Catch:{ Exception -> 0x00eb }
            long r4 = r4 + r6
            r2 = 7
            r2 = r0[r2]     // Catch:{ Exception -> 0x00eb }
            long r6 = java.lang.Long.parseLong(r2)     // Catch:{ Exception -> 0x00eb }
            long r4 = r4 + r6
            r2 = 8
            r0 = r0[r2]     // Catch:{ Exception -> 0x00eb }
            long r6 = java.lang.Long.parseLong(r0)     // Catch:{ Exception -> 0x00eb }
            long r4 = r4 + r6
            r0 = 13
            r0 = r1[r0]     // Catch:{ Exception -> 0x00eb }
            long r6 = java.lang.Long.parseLong(r0)     // Catch:{ Exception -> 0x00eb }
            r0 = 14
            r0 = r1[r0]     // Catch:{ Exception -> 0x00eb }
            long r0 = java.lang.Long.parseLong(r0)     // Catch:{ Exception -> 0x00eb }
            long r6 = r6 + r0
            java.lang.Long r0 = r10.lastCpuTime     // Catch:{ Exception -> 0x00eb }
            if (r0 != 0) goto L_0x00bd
            java.lang.Long r0 = r10.lastAppCpuTime     // Catch:{ Exception -> 0x00eb }
            if (r0 != 0) goto L_0x00bd
            java.lang.Long r0 = java.lang.Long.valueOf(r4)     // Catch:{ Exception -> 0x00eb }
            r10.lastCpuTime = r0     // Catch:{ Exception -> 0x00eb }
            java.lang.Long r0 = java.lang.Long.valueOf(r6)     // Catch:{ Exception -> 0x00eb }
            r10.lastAppCpuTime = r0     // Catch:{ Exception -> 0x00eb }
            return r3
        L_0x00bd:
            com.newrelic.agent.android.tracing.Sample r0 = new com.newrelic.agent.android.tracing.Sample     // Catch:{ Exception -> 0x00eb }
            com.newrelic.agent.android.tracing.Sample$SampleType r1 = com.newrelic.agent.android.tracing.Sample.SampleType.CPU     // Catch:{ Exception -> 0x00eb }
            r0.<init>((com.newrelic.agent.android.tracing.Sample.SampleType) r1)     // Catch:{ Exception -> 0x00eb }
            java.lang.Long r1 = r10.lastAppCpuTime     // Catch:{ Exception -> 0x00eb }
            long r1 = r1.longValue()     // Catch:{ Exception -> 0x00eb }
            long r1 = r6 - r1
            double r1 = (double) r1     // Catch:{ Exception -> 0x00eb }
            java.lang.Long r8 = r10.lastCpuTime     // Catch:{ Exception -> 0x00eb }
            long r8 = r8.longValue()     // Catch:{ Exception -> 0x00eb }
            long r8 = r4 - r8
            double r8 = (double) r8     // Catch:{ Exception -> 0x00eb }
            double r1 = r1 / r8
            r8 = 4636737291354636288(0x4059000000000000, double:100.0)
            double r1 = r1 * r8
            r0.setSampleValue((double) r1)     // Catch:{ Exception -> 0x00eb }
            java.lang.Long r1 = java.lang.Long.valueOf(r4)     // Catch:{ Exception -> 0x00eb }
            r10.lastCpuTime = r1     // Catch:{ Exception -> 0x00eb }
            java.lang.Long r1 = java.lang.Long.valueOf(r6)     // Catch:{ Exception -> 0x00eb }
            r10.lastAppCpuTime = r1     // Catch:{ Exception -> 0x00eb }
            return r0
        L_0x00eb:
            r0 = move-exception
            r1 = 1
            cpuSamplingDisabled = r1
            com.newrelic.agent.android.logging.AgentLog r1 = log
            java.lang.String r2 = "Exception hit while CPU sampling: "
            java.lang.StringBuilder r2 = p085c.p086a.p087a.p088a.outline.m2937a(r2)
            java.lang.String r4 = r0.getMessage()
            r2.append(r4)
            java.lang.String r2 = r2.toString()
            r1.debug(r2)
            com.newrelic.agent.android.harvest.AgentHealth.noticeException((java.lang.Exception) r0)
            return r3
        */
        throw new UnsupportedOperationException("Method not decompiled: com.newrelic.agent.android.sample.Sampler.sampleCpu():com.newrelic.agent.android.tracing.Sample");
    }

    public void schedule() {
        samplerLock.lock();
        try {
            if (!this.isRunning.get()) {
                clear();
                this.sampleFuture = this.scheduler.scheduleWithFixedDelay(this, 0, this.sampleFreqMs, TimeUnit.MILLISECONDS);
                this.isRunning.set(true);
                log.debug(String.format("Sampler scheduler started; sampling will occur every %d ms.", new Object[]{Long.valueOf(this.sampleFreqMs)}));
            }
        } catch (Exception e) {
            AgentLog agentLog = log;
            agentLog.error("Sampler scheduling failed: " + e.getMessage());
            AgentHealth.noticeException(e);
        } catch (Throwable th) {
            samplerLock.unlock();
            throw th;
        }
        samplerLock.unlock();
    }

    public static Sample sampleMemory(ActivityManager activityManager2) {
        int totalPss;
        try {
            Debug.MemoryInfo[] processMemoryInfo = activityManager2.getProcessMemoryInfo(PID);
            if (processMemoryInfo.length <= 0 || (totalPss = processMemoryInfo[0].getTotalPss()) < 0) {
                return null;
            }
            Sample sample = new Sample(Sample.SampleType.MEMORY);
            sample.setSampleValue(((double) totalPss) / 1024.0d);
            return sample;
        } catch (Exception e) {
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("Sample memory failed: ");
            a.append(e.getMessage());
            agentLog.error(a.toString());
            AgentHealth.noticeException(e);
            return null;
        }
    }

    public void stop(boolean z) {
        samplerLock.lock();
        try {
            if (this.isRunning.get()) {
                this.isRunning.set(false);
                if (this.sampleFuture != null) {
                    this.sampleFuture.cancel(z);
                }
                resetCpuSampler();
                log.debug("Sampler canceled");
            }
        } catch (Exception e) {
            AgentLog agentLog = log;
            agentLog.error("Sampler stop failed: " + e.getMessage());
            AgentHealth.noticeException(e);
        } catch (Throwable th) {
            samplerLock.unlock();
            throw th;
        }
        samplerLock.unlock();
    }
}
