package com.newrelic.agent.android.harvest;

import com.newrelic.agent.android.AgentConfiguration;
import com.newrelic.agent.android.activity.config.ActivityTraceConfiguration;
import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.analytics.AnalyticsControllerImpl;
import com.newrelic.agent.android.analytics.SessionEvent;
import com.newrelic.agent.android.harvest.type.Harvestable;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.metric.Metric;
import com.newrelic.agent.android.metric.MetricNames;
import com.newrelic.agent.android.stats.StatsEngine;
import com.newrelic.agent.android.tracing.ActivityTrace;
import com.newrelic.agent.android.tracing.Trace;
import java.util.ArrayList;
import java.util.Collection;
import java.util.Iterator;
import java.util.concurrent.TimeUnit;
import p085c.p086a.p087a.p088a.outline;

public class Harvest {
    public static final boolean DISABLE_ACTIVITY_TRACE_LIMITS_FOR_DEBUGGING = false;
    public static final long INVALID_SESSION_DURATION = 0;
    public static final HarvestableCache activityTraceCache = new HarvestableCache();
    public static Harvest instance = new Harvest();
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public static final Collection<HarvestLifecycleAware> unregisteredLifecycleListeners = new ArrayList();
    public HarvestConfiguration configuration = HarvestConfiguration.getDefaultHarvestConfiguration();
    public HarvestConnection harvestConnection;
    public HarvestData harvestData;
    public HarvestDataValidator harvestDataValidator;
    public HarvestTimer harvestTimer;
    public Harvester harvester;

    public static void addActivityTrace(ActivityTrace activityTrace) {
        if (!isDisabled()) {
            if (!isInitialized()) {
                activityTraceCache.add(activityTrace);
                return;
            }
            Trace trace = activityTrace.rootTrace;
            if (trace == null) {
                log.error("Activity trace is lacking a root trace!");
                return;
            }
            long j = trace.childExclusiveTime;
            if (j == 0) {
                AgentLog agentLog = log;
                StringBuilder a = outline.m2937a("Total trace exclusive time is zero. Ignoring trace ");
                a.append(activityTrace.rootTrace.displayName);
                agentLog.error(a.toString());
                return;
            }
            if (((double) j) / ((double) trace.getDurationAsMilliseconds()) < instance.getConfiguration().getActivity_trace_min_utilization()) {
                StatsEngine.get().inc("Supportability/AgentHealth/IgnoredTraces");
                AgentLog agentLog2 = log;
                StringBuilder a2 = outline.m2937a("Exclusive trace time is too low (");
                a2.append(activityTrace.rootTrace.childExclusiveTime);
                a2.append("/");
                a2.append(activityTrace.rootTrace.getDurationAsMilliseconds());
                a2.append("). Ignoring trace ");
                a2.append(activityTrace.rootTrace.displayName);
                agentLog2.debug(a2.toString());
                return;
            }
            ActivityTraces activityTraces = instance.getHarvestData().getActivityTraces();
            ActivityTraceConfiguration activityTraceConfiguration = instance.getActivityTraceConfiguration();
            instance.getHarvester().expireActivityTraces();
            if (activityTraces.count() >= activityTraceConfiguration.getMaxTotalTraceCount()) {
                AgentLog agentLog3 = log;
                StringBuilder a3 = outline.m2937a("Activity trace limit of ");
                a3.append(activityTraceConfiguration.getMaxTotalTraceCount());
                a3.append(" exceeded. Ignoring trace: ");
                a3.append(activityTrace.toJsonString());
                agentLog3.debug(a3.toString());
                return;
            }
            AgentLog agentLog4 = log;
            StringBuilder a4 = outline.m2937a("Adding activity trace: ");
            a4.append(activityTrace.toJsonString());
            agentLog4.debug(a4.toString());
            activityTraces.add(activityTrace);
        }
    }

    public static void addAgentHealthException(AgentHealthException agentHealthException) {
        if (!isDisabled() && isInitialized()) {
            instance.getHarvestData().getAgentHealth().addException(agentHealthException);
        }
    }

    public static void addHarvestListener(HarvestLifecycleAware harvestLifecycleAware) {
        if (harvestLifecycleAware == null) {
            log.error("Harvest: Argument to addHarvestListener cannot be null.");
        } else if (isInitialized()) {
            instance.getHarvester().addHarvestListener(harvestLifecycleAware);
        } else if (!isUnregisteredListener(harvestLifecycleAware)) {
            addUnregisteredListener(harvestLifecycleAware);
        }
    }

    public static void addHttpErrorTrace(HttpError httpError) {
        if (instance.shouldCollectNetworkErrors() && !isDisabled()) {
            HttpErrors httpErrors = instance.getHarvestData().getHttpErrors();
            instance.getHarvester().expireHttpErrors();
            int error_limit = instance.getConfiguration().getError_limit();
            if (httpErrors.count() >= error_limit) {
                StatsEngine.get().inc("Supportability/AgentHealth/ErrorsDropped");
                AgentLog agentLog = log;
                agentLog.debug("Maximum number of HTTP errors (" + error_limit + ") reached. HTTP Error dropped.");
                return;
            }
            httpErrors.addHttpError(httpError);
            AgentLog agentLog2 = log;
            StringBuilder a = outline.m2937a("Harvest: ");
            a.append(instance);
            a.append(" now contains ");
            a.append(httpErrors.count());
            a.append(" errors.");
            agentLog2.verbose(a.toString());
        }
    }

    public static void addHttpTransaction(HttpTransaction httpTransaction) {
        if (!isDisabled()) {
            HttpTransactions httpTransactions = instance.getHarvestData().getHttpTransactions();
            instance.getHarvester().expireHttpTransactions();
            int report_max_transaction_count = instance.getConfiguration().getReport_max_transaction_count();
            if (httpTransactions.count() >= report_max_transaction_count) {
                StatsEngine.get().inc("Supportability/AgentHealth/TransactionsDropped");
                AgentLog agentLog = log;
                agentLog.debug("Maximum number of transactions (" + report_max_transaction_count + ") reached. HTTP Transaction dropped.");
                return;
            }
            httpTransactions.add(httpTransaction);
            AnalyticsControllerImpl.getInstance().createNetworkRequestEvents(httpTransaction);
        }
    }

    public static void addMetric(Metric metric) {
        if (!isDisabled() && isInitialized()) {
            instance.getHarvestData().getMetrics().addMetric(metric);
        }
    }

    public static void addUnregisteredListener(HarvestLifecycleAware harvestLifecycleAware) {
        if (harvestLifecycleAware != null) {
            synchronized (unregisteredLifecycleListeners) {
                unregisteredLifecycleListeners.add(harvestLifecycleAware);
            }
        }
    }

    private void flushActivityTraceCache() {
        Iterator<Harvestable> it = activityTraceCache.flush().iterator();
        while (it.hasNext()) {
            addActivityTrace((ActivityTrace) it.next());
        }
    }

    private void flushHarvestableCaches() {
        try {
            flushActivityTraceCache();
        } catch (Exception e) {
            e.printStackTrace();
        }
    }

    public static int getActivityTraceCacheSize() {
        return activityTraceCache.getSize();
    }

    public static HarvestConfiguration getHarvestConfiguration() {
        if (!isInitialized()) {
            return HarvestConfiguration.getDefaultHarvestConfiguration();
        }
        return instance.getConfiguration();
    }

    public static Harvest getInstance() {
        return instance;
    }

    public static long getMillisSinceStart() {
        Harvest instance2 = getInstance();
        if (instance2 == null || instance2.getHarvestTimer() == null) {
            return 0;
        }
        long timeSinceStart = instance2.getHarvestTimer().timeSinceStart();
        if (timeSinceStart < 0) {
            return 0;
        }
        return timeSinceStart;
    }

    public static void harvestNow(boolean z) {
        if (isInitialized()) {
            if (z) {
                instance.finalizeSession();
                AnalyticsControllerImpl.getInstance().getEventManager().setTransmitRequired();
            }
            instance.getHarvestTimer().tickNow();
        }
    }

    public static void initialize(AgentConfiguration agentConfiguration) {
        instance.initializeHarvester(agentConfiguration);
        registerUnregisteredListeners();
        addHarvestListener(StatsEngine.get());
    }

    public static boolean isDisabled() {
        if (!isInitialized()) {
            return false;
        }
        return instance.getHarvester().isDisabled();
    }

    public static boolean isInitialized() {
        Harvest harvest = instance;
        return (harvest == null || harvest.getHarvester() == null) ? false : true;
    }

    public static boolean isUnregisteredListener(HarvestLifecycleAware harvestLifecycleAware) {
        if (harvestLifecycleAware == null) {
            return false;
        }
        return unregisteredLifecycleListeners.contains(harvestLifecycleAware);
    }

    public static void registerUnregisteredListeners() {
        for (HarvestLifecycleAware addHarvestListener : unregisteredLifecycleListeners) {
            addHarvestListener(addHarvestListener);
        }
        unregisteredLifecycleListeners.clear();
    }

    public static void removeHarvestListener(HarvestLifecycleAware harvestLifecycleAware) {
        if (harvestLifecycleAware == null) {
            log.error("Harvest: Argument to removeHarvestListener cannot be null.");
        } else if (isInitialized()) {
            instance.getHarvester().removeHarvestListener(harvestLifecycleAware);
        } else if (isUnregisteredListener(harvestLifecycleAware)) {
            removeUnregisteredListener(harvestLifecycleAware);
        }
    }

    public static void removeUnregisteredListener(HarvestLifecycleAware harvestLifecycleAware) {
        if (harvestLifecycleAware != null) {
            synchronized (unregisteredLifecycleListeners) {
                unregisteredLifecycleListeners.remove(harvestLifecycleAware);
            }
        }
    }

    public static void setHarvestConfiguration(HarvestConfiguration harvestConfiguration) {
        if (!isInitialized()) {
            log.error("Cannot configure Harvester before initialization.");
            new Exception().printStackTrace();
            return;
        }
        AgentLog agentLog = log;
        agentLog.debug("Harvest Configuration: " + harvestConfiguration);
        instance.setConfiguration(harvestConfiguration);
    }

    public static void setHarvestConnectInformation(ConnectInformation connectInformation) {
        if (!isInitialized()) {
            log.error("Cannot configure Harvester before initialization.");
            new Exception().printStackTrace();
            return;
        }
        AgentLog agentLog = log;
        agentLog.debug("Setting Harvest connect information: " + connectInformation);
        instance.setConnectInformation(connectInformation);
    }

    public static void setInstance(Harvest harvest) {
        if (harvest == null) {
            log.error("Attempt to set Harvest instance to null value!");
        } else {
            instance = harvest;
        }
    }

    public static boolean shouldCollectActivityTraces() {
        ActivityTraceConfiguration activityTraceConfiguration;
        if (isDisabled()) {
            return false;
        }
        if (isInitialized() && (activityTraceConfiguration = instance.getActivityTraceConfiguration()) != null && activityTraceConfiguration.getMaxTotalTraceCount() <= 0) {
            return false;
        }
        return true;
    }

    public static void shutdown() {
        if (isInitialized()) {
            stop();
            instance.shutdownHarvester();
        }
    }

    public static void start() {
        instance.getHarvestTimer().start();
    }

    public static void stop() {
        instance.getHarvestTimer().stop();
    }

    public void createHarvester() {
        this.harvestConnection = new HarvestConnection();
        this.harvestData = new HarvestData();
        Harvester harvester2 = new Harvester();
        this.harvester = harvester2;
        harvester2.setHarvestConnection(this.harvestConnection);
        this.harvester.setHarvestData(this.harvestData);
        this.harvestTimer = new HarvestTimer(this.harvester);
        HarvestDataValidator harvestDataValidator2 = new HarvestDataValidator();
        this.harvestDataValidator = harvestDataValidator2;
        addHarvestListener(harvestDataValidator2);
    }

    public void finalizeSession() {
        long millisSinceStart = getMillisSinceStart();
        if (millisSinceStart == 0) {
            log.error("Session duration is invalid!");
            StatsEngine.get().inc(MetricNames.SUPPORTABILITY_SESSION_INVALID_DURATION);
        }
        float f = ((float) millisSinceStart) / 1000.0f;
        StatsEngine.get().sample("Session/Duration", f);
        AgentLog agentLog = log;
        agentLog.debug("Harvest: Generating sessionDuration attribute with value " + f);
        AnalyticsControllerImpl instance2 = AnalyticsControllerImpl.getInstance();
        instance2.setAttribute(AnalyticAttribute.SESSION_DURATION_ATTRIBUTE, (double) f, false);
        log.debug("Harvest: Generating session event.");
        instance2.addEvent(new SessionEvent());
    }

    public ActivityTraceConfiguration getActivityTraceConfiguration() {
        return this.configuration.getAt_capture();
    }

    public HarvestConfiguration getConfiguration() {
        return this.configuration;
    }

    public HarvestConnection getHarvestConnection() {
        return this.harvestConnection;
    }

    public HarvestData getHarvestData() {
        return this.harvestData;
    }

    public HarvestTimer getHarvestTimer() {
        return this.harvestTimer;
    }

    public Harvester getHarvester() {
        return this.harvester;
    }

    public void initializeHarvester(AgentConfiguration agentConfiguration) {
        createHarvester();
        this.harvester.setAgentConfiguration(agentConfiguration);
        this.harvester.setConfiguration(instance.getConfiguration());
        flushHarvestableCaches();
    }

    public void setConfiguration(HarvestConfiguration harvestConfiguration) {
        this.configuration.reconfigure(harvestConfiguration);
        this.harvestTimer.setPeriod(TimeUnit.MILLISECONDS.convert((long) this.configuration.getData_report_period(), TimeUnit.SECONDS));
        this.harvestConnection.setServerTimestamp(this.configuration.getServer_timestamp());
        this.harvestData.setDataToken(this.configuration.getDataToken());
        this.harvester.setConfiguration(this.configuration);
    }

    public void setConnectInformation(ConnectInformation connectInformation) {
        this.harvestConnection.setConnectInformation(connectInformation);
        this.harvestData.setDeviceInformation(connectInformation.getDeviceInformation());
    }

    public void setHarvestConnection(HarvestConnection harvestConnection2) {
        this.harvestConnection = harvestConnection2;
    }

    public boolean shouldCollectNetworkErrors() {
        return this.configuration.isCollect_network_errors();
    }

    public void shutdownHarvester() {
        this.harvestTimer.shutdown();
        this.harvestTimer = null;
        this.harvester = null;
        this.harvestConnection = null;
        this.harvestData = null;
    }
}
