package com.newrelic.agent.android.harvest;

import com.newrelic.agent.android.background.ApplicationStateMonitor;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.stats.TicToc;
import com.newrelic.agent.android.util.NamedThreadFactory;
import java.util.concurrent.Executors;
import java.util.concurrent.ScheduledExecutorService;
import java.util.concurrent.ScheduledFuture;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;
import p085c.p086a.p087a.p088a.outline;

public class HarvestTimer implements Runnable {
    public static final long DEFAULT_HARVEST_PERIOD = 60000;
    public static final long HARVEST_PERIOD_LEEWAY = 1000;
    public static final long NEVER_TICKED = -1;
    public final Harvester harvester;
    public long lastTickTime;
    public Lock lock = new ReentrantLock();
    public final AgentLog log = AgentLogManager.getAgentLog();
    public long period = 60000;
    public final ScheduledExecutorService scheduler = Executors.newSingleThreadScheduledExecutor(new NamedThreadFactory("Harvester"));
    public long startTimeMs;
    public ScheduledFuture tickFuture = null;

    public HarvestTimer(Harvester harvester2) {
        this.harvester = harvester2;
        this.startTimeMs = 0;
    }

    private long now() {
        return System.currentTimeMillis();
    }

    private void tickIfReady() {
        long timeSinceLastTick = timeSinceLastTick();
        if (1000 + timeSinceLastTick >= this.period || timeSinceLastTick == -1) {
            AgentLog agentLog = this.log;
            agentLog.debug("HarvestTimer: time since last tick: " + timeSinceLastTick);
            long now = now();
            try {
                tick();
            } catch (Exception e) {
                AgentLog agentLog2 = this.log;
                StringBuilder a = outline.m2937a("HarvestTimer: Exception in timer tick: ");
                a.append(e.getMessage());
                agentLog2.error(a.toString());
                e.printStackTrace();
                AgentHealth.noticeException(e);
            }
            this.lastTickTime = now;
            AgentLog agentLog3 = this.log;
            StringBuilder a2 = outline.m2937a("Set last tick time to: ");
            a2.append(this.lastTickTime);
            agentLog3.debug(a2.toString());
            return;
        }
        AgentLog agentLog4 = this.log;
        agentLog4.debug("HarvestTimer: Tick is too soon (" + timeSinceLastTick + " delta) Last tick time: " + this.lastTickTime + " . Skipping.");
    }

    public void cancelPendingTasks() {
        try {
            this.lock.lock();
            if (this.tickFuture != null) {
                this.tickFuture.cancel(true);
                this.tickFuture = null;
            }
        } finally {
            this.lock.unlock();
        }
    }

    public boolean isRunning() {
        return this.tickFuture != null;
    }

    public void run() {
        try {
            this.lock.lock();
            tickIfReady();
        } catch (Exception e) {
            AgentLog agentLog = this.log;
            agentLog.error("HarvestTimer: Exception in timer tick: " + e.getMessage());
            e.printStackTrace();
            AgentHealth.noticeException(e);
        } catch (Throwable th) {
            this.lock.unlock();
            throw th;
        }
        this.lock.unlock();
    }

    public void setPeriod(long j) {
        this.period = j;
    }

    public void shutdown() {
        cancelPendingTasks();
        this.scheduler.shutdownNow();
    }

    public void start() {
        if (ApplicationStateMonitor.isAppInBackground()) {
            this.log.warning("HarvestTimer: Attempting to start while app is in background");
        } else if (isRunning()) {
            this.log.warning("HarvestTimer: Attempting to start while already running");
        } else if (this.period <= 0) {
            this.log.error("HarvestTimer: Refusing to start with a period of 0 ms");
        } else {
            AgentLog agentLog = this.log;
            StringBuilder a = outline.m2937a("HarvestTimer: Starting with a period of ");
            a.append(this.period);
            a.append("ms");
            agentLog.debug(a.toString());
            this.startTimeMs = System.currentTimeMillis();
            this.tickFuture = this.scheduler.scheduleAtFixedRate(this, 0, this.period, TimeUnit.MILLISECONDS);
            this.harvester.start();
        }
    }

    public void stop() {
        if (!isRunning()) {
            this.log.warning("HarvestTimer: Attempting to stop when not running");
            return;
        }
        cancelPendingTasks();
        this.log.debug("HarvestTimer: Stopped.");
        this.startTimeMs = 0;
        this.harvester.stop();
    }

    public void tick() {
        this.log.debug("Harvest: tick");
        TicToc ticToc = new TicToc();
        ticToc.tic();
        try {
            if (ApplicationStateMonitor.isAppInBackground()) {
                this.log.error("HarvestTimer: Attempting to harvest while app is in background");
            } else {
                this.harvester.execute();
                this.log.debug("Harvest: executed");
            }
        } catch (Exception e) {
            AgentLog agentLog = this.log;
            StringBuilder a = outline.m2937a("HarvestTimer: Exception in harvest execute: ");
            a.append(e.getMessage());
            agentLog.error(a.toString());
            e.printStackTrace();
            AgentHealth.noticeException(e);
        }
        if (this.harvester.isDisabled()) {
            stop();
        }
        long cVar = ticToc.toc();
        AgentLog agentLog2 = this.log;
        agentLog2.debug("HarvestTimer tick took " + cVar + "ms");
    }

    public void tickNow() {
        try {
            this.scheduler.schedule(new Runnable() {
                public void run() {
                    this.tick();
                }
            }, 0, TimeUnit.SECONDS).get();
        } catch (Exception e) {
            AgentLog agentLog = this.log;
            StringBuilder a = outline.m2937a("Exception waiting for tickNow to finish: ");
            a.append(e.getMessage());
            agentLog.error(a.toString());
            e.printStackTrace();
            AgentHealth.noticeException(e);
        }
    }

    public long timeSinceLastTick() {
        if (this.lastTickTime == 0) {
            return -1;
        }
        return now() - this.lastTickTime;
    }

    public long timeSinceStart() {
        if (this.startTimeMs == 0) {
            return 0;
        }
        return now() - this.startTimeMs;
    }
}
