package com.newrelic.agent.android.instrumentation;

import com.newrelic.agent.android.FeatureFlag;
import com.newrelic.agent.android.Measurements;
import com.newrelic.agent.android.TaskQueue;
import com.newrelic.agent.android.api.common.TransactionData;
import com.newrelic.agent.android.instrumentation.p225io.CountingInputStream;
import com.newrelic.agent.android.instrumentation.p225io.CountingOutputStream;
import com.newrelic.agent.android.instrumentation.p225io.StreamCompleteEvent;
import com.newrelic.agent.android.instrumentation.p225io.StreamCompleteListener;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.measurement.http.HttpTransactionMeasurement;
import com.newrelic.agent.android.util.Constants;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;
import java.net.HttpURLConnection;
import java.net.ProtocolException;
import java.net.URL;
import java.security.Permission;
import java.security.Principal;
import java.security.cert.Certificate;
import java.util.List;
import java.util.Map;
import java.util.TreeMap;
import javax.net.ssl.HostnameVerifier;
import javax.net.ssl.HttpsURLConnection;
import javax.net.ssl.SSLPeerUnverifiedException;
import javax.net.ssl.SSLSocketFactory;
import p085c.p086a.p087a.p088a.outline;

public class HttpsURLConnectionExtension extends HttpsURLConnection {
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public CountingInputStream errorStream = null;
    public HttpsURLConnection impl;
    public TransactionState transactionState;

    public HttpsURLConnectionExtension(HttpsURLConnection httpsURLConnection) {
        super(httpsURLConnection.getURL());
        this.impl = httpsURLConnection;
        TransactionStateUtil.setCrossProcessHeader(httpsURLConnection);
        if (FeatureFlag.featureEnabled(FeatureFlag.DistributedTracing)) {
            TransactionStateUtil.setCatPayload(getTransactionState());
            try {
                this.impl.addRequestProperty(Constants.Network.CONNECTIVITY_TRACE_HEADER, this.transactionState.getCatPayload().asBase64Json());
            } catch (NullPointerException e) {
                log.error("Distributed trace payload is null", e);
            } catch (IllegalStateException e2) {
                log.error("Connection already opened, unable to add Connectivity header", e2);
            }
        }
    }

    /* access modifiers changed from: private */
    public void addTransactionAndErrorData(TransactionState transactionState2) {
        String str;
        String contentType;
        TransactionData end = transactionState2.end();
        if (end != null) {
            if (transactionState2.isErrorOrFailure()) {
                try {
                    InputStream errorStream2 = getErrorStream();
                    if (errorStream2 != null && (errorStream2 instanceof CountingInputStream)) {
                        str = ((CountingInputStream) errorStream2).getBufferAsString();
                        TreeMap treeMap = new TreeMap();
                        contentType = this.impl.getContentType();
                        if (contentType != null && !"".equals(contentType)) {
                            treeMap.put(Constants.Transactions.CONTENT_TYPE, contentType);
                        }
                        treeMap.put(Constants.Transactions.CONTENT_LENGTH, transactionState2.getBytesReceived() + "");
                        end.setResponseBody(str);
                        end.setParams(treeMap);
                        Measurements.addHttpError(end);
                    }
                } catch (Exception e) {
                    AgentLog agentLog = log;
                    StringBuilder a = outline.m2937a("HttpsURLConnectionExtension.addTransactionAndErrorData: ");
                    a.append(e.toString());
                    agentLog.error(a.toString());
                }
                str = "";
                TreeMap treeMap2 = new TreeMap();
                contentType = this.impl.getContentType();
                treeMap2.put(Constants.Transactions.CONTENT_TYPE, contentType);
                treeMap2.put(Constants.Transactions.CONTENT_LENGTH, transactionState2.getBytesReceived() + "");
                end.setResponseBody(str);
                end.setParams(treeMap2);
                Measurements.addHttpError(end);
            }
            TaskQueue.queue(new HttpTransactionMeasurement(end));
        }
    }

    private void checkResponse() {
        if (!getTransactionState().isComplete()) {
            TransactionStateUtil.inspectAndInstrumentResponse(getTransactionState(), this.impl);
        }
    }

    /* access modifiers changed from: private */
    public void error(Exception exc) {
        TransactionState transactionState2 = getTransactionState();
        TransactionStateUtil.setErrorCodeFromException(transactionState2, exc);
        if (!transactionState2.isComplete()) {
            TransactionStateUtil.inspectAndInstrumentResponse(transactionState2, this.impl);
            TransactionData end = transactionState2.end();
            if (end != null) {
                String exc2 = exc.toString();
                try {
                    InputStream errorStream2 = getErrorStream();
                    if (errorStream2 != null && (errorStream2 instanceof CountingInputStream)) {
                        exc2 = ((CountingInputStream) errorStream2).getBufferAsString();
                    }
                } catch (Exception e) {
                    AgentLog agentLog = log;
                    StringBuilder a = outline.m2937a("HttpsURLConnectionExtension.error: ");
                    a.append(e.toString());
                    agentLog.error(a.toString());
                }
                end.setResponseBody(exc2);
                TaskQueue.queue(new HttpTransactionMeasurement(end));
            }
        }
    }

    private TransactionState getTransactionState() {
        if (this.transactionState == null) {
            TransactionState transactionState2 = new TransactionState();
            this.transactionState = transactionState2;
            TransactionStateUtil.inspectAndInstrument(transactionState2, (HttpURLConnection) this.impl);
        }
        return this.transactionState;
    }

    public void addRequestProperty(String str, String str2) {
        this.impl.addRequestProperty(str, str2);
    }

    public void connect() throws IOException {
        getTransactionState();
        try {
            this.impl.connect();
        } catch (IOException e) {
            error(e);
            throw e;
        }
    }

    public void disconnect() {
        TransactionState transactionState2 = this.transactionState;
        if (transactionState2 != null && !transactionState2.isComplete()) {
            addTransactionAndErrorData(this.transactionState);
        }
        this.impl.disconnect();
    }

    public boolean getAllowUserInteraction() {
        return this.impl.getAllowUserInteraction();
    }

    public String getCipherSuite() {
        return this.impl.getCipherSuite();
    }

    public int getConnectTimeout() {
        return this.impl.getConnectTimeout();
    }

    public Object getContent() throws IOException {
        getTransactionState();
        try {
            Object content = this.impl.getContent();
            int contentLength = this.impl.getContentLength();
            if (contentLength >= 0) {
                TransactionState transactionState2 = getTransactionState();
                if (!transactionState2.isComplete()) {
                    transactionState2.setBytesReceived((long) contentLength);
                    addTransactionAndErrorData(transactionState2);
                }
            }
            return content;
        } catch (IOException e) {
            error(e);
            throw e;
        }
    }

    public String getContentEncoding() {
        getTransactionState();
        String contentEncoding = this.impl.getContentEncoding();
        checkResponse();
        return contentEncoding;
    }

    public int getContentLength() {
        getTransactionState();
        int contentLength = this.impl.getContentLength();
        checkResponse();
        return contentLength;
    }

    public String getContentType() {
        getTransactionState();
        String contentType = this.impl.getContentType();
        checkResponse();
        return contentType;
    }

    public long getDate() {
        getTransactionState();
        long date = this.impl.getDate();
        checkResponse();
        return date;
    }

    public boolean getDefaultUseCaches() {
        return this.impl.getDefaultUseCaches();
    }

    public boolean getDoInput() {
        return this.impl.getDoInput();
    }

    public boolean getDoOutput() {
        return this.impl.getDoOutput();
    }

    public InputStream getErrorStream() {
        getTransactionState();
        try {
            if (this.errorStream == null || this.errorStream.available() == 0) {
                if (this.impl.getErrorStream() != null) {
                    this.errorStream = new CountingInputStream(this.impl.getErrorStream(), true);
                } else {
                    log.debug("HttpsURLConnectionExtension: error stream implementation is null");
                    return this.impl.getErrorStream();
                }
            }
            return this.errorStream;
        } catch (Exception e) {
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("HttpsURLConnectionExtension: ");
            a.append(e.toString());
            agentLog.error(a.toString());
            return this.impl.getErrorStream();
        }
    }

    public long getExpiration() {
        getTransactionState();
        long expiration = this.impl.getExpiration();
        checkResponse();
        return expiration;
    }

    public String getHeaderField(int i) {
        getTransactionState();
        String headerField = this.impl.getHeaderField(i);
        checkResponse();
        return headerField;
    }

    public long getHeaderFieldDate(String str, long j) {
        getTransactionState();
        long headerFieldDate = this.impl.getHeaderFieldDate(str, j);
        checkResponse();
        return headerFieldDate;
    }

    public int getHeaderFieldInt(String str, int i) {
        getTransactionState();
        int headerFieldInt = this.impl.getHeaderFieldInt(str, i);
        checkResponse();
        return headerFieldInt;
    }

    public String getHeaderFieldKey(int i) {
        getTransactionState();
        String headerFieldKey = this.impl.getHeaderFieldKey(i);
        checkResponse();
        return headerFieldKey;
    }

    public Map<String, List<String>> getHeaderFields() {
        getTransactionState();
        Map<String, List<String>> headerFields = this.impl.getHeaderFields();
        checkResponse();
        return headerFields;
    }

    public HostnameVerifier getHostnameVerifier() {
        return this.impl.getHostnameVerifier();
    }

    public long getIfModifiedSince() {
        getTransactionState();
        long ifModifiedSince = this.impl.getIfModifiedSince();
        checkResponse();
        return ifModifiedSince;
    }

    public InputStream getInputStream() throws IOException {
        final TransactionState transactionState2 = getTransactionState();
        try {
            CountingInputStream countingInputStream = new CountingInputStream(this.impl.getInputStream());
            TransactionStateUtil.inspectAndInstrumentResponse(transactionState2, this.impl);
            countingInputStream.addStreamCompleteListener(new StreamCompleteListener() {
                public void streamComplete(StreamCompleteEvent streamCompleteEvent) {
                    if (!transactionState2.isComplete()) {
                        try {
                            transactionState2.setStatusCode(HttpsURLConnectionExtension.this.impl.getResponseCode());
                        } catch (IOException unused) {
                            AgentLog access$200 = HttpsURLConnectionExtension.log;
                            access$200.error("HttpsURLConnectionExtension.getInputStream.streamComplete: " + streamCompleteEvent);
                        }
                        long contentLength = (long) HttpsURLConnectionExtension.this.impl.getContentLength();
                        long bytes = streamCompleteEvent.getBytes();
                        if (contentLength < 0) {
                            contentLength = bytes;
                        }
                        transactionState2.setBytesReceived(contentLength);
                        HttpsURLConnectionExtension.this.addTransactionAndErrorData(transactionState2);
                    }
                }

                public void streamError(StreamCompleteEvent streamCompleteEvent) {
                    if (!transactionState2.isComplete()) {
                        transactionState2.setBytesReceived(streamCompleteEvent.getBytes());
                    }
                    HttpsURLConnectionExtension.this.error(streamCompleteEvent.getException());
                }
            });
            return countingInputStream;
        } catch (IOException e) {
            error(e);
            throw e;
        }
    }

    public boolean getInstanceFollowRedirects() {
        return this.impl.getInstanceFollowRedirects();
    }

    public long getLastModified() {
        getTransactionState();
        long lastModified = this.impl.getLastModified();
        checkResponse();
        return lastModified;
    }

    public Certificate[] getLocalCertificates() {
        return this.impl.getLocalCertificates();
    }

    public Principal getLocalPrincipal() {
        return this.impl.getLocalPrincipal();
    }

    public OutputStream getOutputStream() throws IOException {
        final TransactionState transactionState2 = getTransactionState();
        try {
            CountingOutputStream countingOutputStream = new CountingOutputStream(this.impl.getOutputStream());
            countingOutputStream.addStreamCompleteListener(new StreamCompleteListener() {
                public void streamComplete(StreamCompleteEvent streamCompleteEvent) {
                    if (!transactionState2.isComplete()) {
                        try {
                            transactionState2.setStatusCode(HttpsURLConnectionExtension.this.impl.getResponseCode());
                        } catch (IOException unused) {
                            AgentLog access$200 = HttpsURLConnectionExtension.log;
                            access$200.error("HttpsURLConnectionExtension.getOutputStream.streamComplete: " + streamCompleteEvent);
                        }
                        String requestProperty = HttpsURLConnectionExtension.this.impl.getRequestProperty(Constants.Network.CONTENT_LENGTH_HEADER);
                        long bytes = streamCompleteEvent.getBytes();
                        if (requestProperty != null) {
                            try {
                                bytes = Long.parseLong(requestProperty);
                            } catch (NumberFormatException unused2) {
                            }
                        }
                        transactionState2.setBytesSent(bytes);
                        HttpsURLConnectionExtension.this.addTransactionAndErrorData(transactionState2);
                    }
                }

                public void streamError(StreamCompleteEvent streamCompleteEvent) {
                    if (!transactionState2.isComplete()) {
                        transactionState2.setBytesSent(streamCompleteEvent.getBytes());
                    }
                    HttpsURLConnectionExtension.this.error(streamCompleteEvent.getException());
                }
            });
            return countingOutputStream;
        } catch (IOException e) {
            error(e);
            throw e;
        }
    }

    public Principal getPeerPrincipal() throws SSLPeerUnverifiedException {
        return this.impl.getPeerPrincipal();
    }

    public Permission getPermission() throws IOException {
        return this.impl.getPermission();
    }

    public int getReadTimeout() {
        return this.impl.getReadTimeout();
    }

    public String getRequestMethod() {
        return this.impl.getRequestMethod();
    }

    public Map<String, List<String>> getRequestProperties() {
        return this.impl.getRequestProperties();
    }

    public String getRequestProperty(String str) {
        return this.impl.getRequestProperty(str);
    }

    public int getResponseCode() throws IOException {
        getTransactionState();
        try {
            int responseCode = this.impl.getResponseCode();
            checkResponse();
            return responseCode;
        } catch (IOException e) {
            error(e);
            throw e;
        }
    }

    public String getResponseMessage() throws IOException {
        getTransactionState();
        try {
            String responseMessage = this.impl.getResponseMessage();
            checkResponse();
            return responseMessage;
        } catch (IOException e) {
            error(e);
            throw e;
        }
    }

    public SSLSocketFactory getSSLSocketFactory() {
        return this.impl.getSSLSocketFactory();
    }

    public Certificate[] getServerCertificates() throws SSLPeerUnverifiedException {
        try {
            return this.impl.getServerCertificates();
        } catch (SSLPeerUnverifiedException e) {
            error(e);
            throw e;
        }
    }

    public URL getURL() {
        return this.impl.getURL();
    }

    public boolean getUseCaches() {
        return this.impl.getUseCaches();
    }

    public void setAllowUserInteraction(boolean z) {
        this.impl.setAllowUserInteraction(z);
    }

    public void setChunkedStreamingMode(int i) {
        this.impl.setChunkedStreamingMode(i);
    }

    public void setConnectTimeout(int i) {
        this.impl.setConnectTimeout(i);
    }

    public void setDefaultUseCaches(boolean z) {
        this.impl.setDefaultUseCaches(z);
    }

    public void setDoInput(boolean z) {
        this.impl.setDoInput(z);
    }

    public void setDoOutput(boolean z) {
        this.impl.setDoOutput(z);
    }

    public void setFixedLengthStreamingMode(int i) {
        this.impl.setFixedLengthStreamingMode(i);
    }

    public void setHostnameVerifier(HostnameVerifier hostnameVerifier) {
        this.impl.setHostnameVerifier(hostnameVerifier);
    }

    public void setIfModifiedSince(long j) {
        this.impl.setIfModifiedSince(j);
    }

    public void setInstanceFollowRedirects(boolean z) {
        this.impl.setInstanceFollowRedirects(z);
    }

    public void setReadTimeout(int i) {
        this.impl.setReadTimeout(i);
    }

    public void setRequestMethod(String str) throws ProtocolException {
        try {
            this.impl.setRequestMethod(str);
        } catch (ProtocolException e) {
            error(e);
            throw e;
        }
    }

    public void setRequestProperty(String str, String str2) {
        this.impl.setRequestProperty(str, str2);
    }

    public void setSSLSocketFactory(SSLSocketFactory sSLSocketFactory) {
        this.impl.setSSLSocketFactory(sSLSocketFactory);
    }

    public void setUseCaches(boolean z) {
        this.impl.setUseCaches(z);
    }

    public String toString() {
        return this.impl.toString();
    }

    public boolean usingProxy() {
        return this.impl.usingProxy();
    }

    public String getHeaderField(String str) {
        getTransactionState();
        String headerField = this.impl.getHeaderField(str);
        checkResponse();
        return headerField;
    }

    public Object getContent(Class[] clsArr) throws IOException {
        getTransactionState();
        try {
            Object content = this.impl.getContent(clsArr);
            checkResponse();
            return content;
        } catch (IOException e) {
            error(e);
            throw e;
        }
    }
}
