package com.newrelic.agent.android.instrumentation;

import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.api.common.TransactionData;
import com.newrelic.agent.android.connectivity.CatPayload;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.measurement.producer.HttpErrorMeasurementProducer;
import com.newrelic.agent.android.metric.MetricNames;
import com.newrelic.agent.android.stats.StatsEngine;
import com.newrelic.agent.android.tracing.TraceMachine;
import com.newrelic.agent.android.util.Util;
import java.net.MalformedURLException;
import java.net.URL;
import p085c.p086a.p087a.p088a.outline;

public final class TransactionState {
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public String appData;
    public long bytesReceived;
    public long bytesSent;
    public String carrier;
    public CatPayload catPayload;
    public String contentType;
    public long endTime;
    public int errorCode;
    public String httpMethod;
    public long startTime;
    public State state;
    public int statusCode;
    public TransactionData transactionData;
    public String url;
    public String wanType;

    public enum State {
        READY,
        SENT,
        COMPLETE
    }

    public TransactionState() {
        this.statusCode = 0;
        this.errorCode = 0;
        this.bytesSent = 0;
        this.bytesReceived = 0;
        this.startTime = 0;
        this.endTime = 0;
        this.carrier = "unknown";
        this.wanType = "unknown";
        this.state = State.READY;
        this.startTime = System.currentTimeMillis();
        TraceMachine.enterNetworkSegment("External/unknownhost");
    }

    public static boolean isRequestError(int i) {
        return ((long) i) >= 400;
    }

    public static boolean isRequestFailure(int i) {
        return i != 0;
    }

    public TransactionData end() {
        if (!isComplete()) {
            this.state = State.COMPLETE;
            this.endTime = System.currentTimeMillis();
            TraceMachine.exitMethod();
        }
        return toTransactionData();
    }

    public long getBytesReceived() {
        return this.bytesReceived;
    }

    public CatPayload getCatPayload() {
        return this.catPayload;
    }

    public String getContentType() {
        return this.contentType;
    }

    public int getErrorCode() {
        return this.errorCode;
    }

    public String getHttpMethod() {
        return this.httpMethod;
    }

    public int getStatusCode() {
        return this.statusCode;
    }

    public String getUrl() {
        return this.url;
    }

    public boolean isComplete() {
        return this.state == State.COMPLETE;
    }

    public boolean isErrorOrFailure() {
        return isRequestError() || isRequestFailure();
    }

    public boolean isRequestError() {
        return isRequestError(this.statusCode);
    }

    public boolean isRequestFailure() {
        return isRequestFailure(this.errorCode);
    }

    public boolean isSent() {
        State state2 = this.state;
        return state2 == State.SENT || state2 == State.COMPLETE;
    }

    public void setAppData(String str) {
        if (!isComplete()) {
            this.appData = str;
            TraceMachine.setCurrentTraceParam("encoded_app_data", str);
            return;
        }
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("setAppData(...) called on TransactionState in ");
        a.append(this.state.toString());
        a.append(" state");
        agentLog.warning(a.toString());
    }

    public void setBytesReceived(long j) {
        if (!isComplete()) {
            this.bytesReceived = j;
            TraceMachine.setCurrentTraceParam("bytes_received", Long.valueOf(j));
            return;
        }
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("setBytesReceived(...) called on TransactionState in ");
        a.append(this.state.toString());
        a.append(" state");
        agentLog.warning(a.toString());
    }

    public void setBytesSent(long j) {
        if (!isComplete()) {
            this.bytesSent = j;
            TraceMachine.setCurrentTraceParam("bytes_sent", Long.valueOf(j));
            this.state = State.SENT;
            return;
        }
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("setBytesSent(...) called on TransactionState in ");
        a.append(this.state.toString());
        a.append(" state");
        agentLog.warning(a.toString());
    }

    public void setCarrier(String str) {
        if (!isSent()) {
            this.carrier = str;
            TraceMachine.setCurrentTraceParam(AnalyticAttribute.CARRIER_ATTRIBUTE, str);
            return;
        }
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("setCarrier(...) called on TransactionState in ");
        a.append(this.state.toString());
        a.append(" state");
        agentLog.warning(a.toString());
    }

    public void setCatPayload(CatPayload catPayload2) {
        if (!isSent()) {
            this.catPayload = catPayload2;
            return;
        }
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("setCatPayload(...) called on TransactionState in ");
        a.append(this.state.toString());
        a.append(" state");
        agentLog.warning(a.toString());
    }

    public void setContentType(String str) {
        this.contentType = str;
    }

    public void setErrorCode(int i) {
        if (!isComplete()) {
            this.errorCode = i;
            TraceMachine.setCurrentTraceParam("error_code", Integer.valueOf(i));
            return;
        }
        TransactionData transactionData2 = this.transactionData;
        if (transactionData2 != null) {
            transactionData2.setErrorCode(i);
        }
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("setErrorCode(...) called on TransactionState in ");
        a.append(this.state.toString());
        a.append(" state");
        agentLog.warning(a.toString());
    }

    public void setHttpMethod(String str) {
        if (!isSent()) {
            this.httpMethod = str;
            TraceMachine.setCurrentTraceParam(HttpErrorMeasurementProducer.HTTP_METHOD_PARAMS_KEY, str);
            return;
        }
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("setHttpMethod(...) called on TransactionState in ");
        a.append(this.state.toString());
        a.append(" state");
        agentLog.warning(a.toString());
    }

    public State setState(State state2) {
        this.state = state2;
        return state2;
    }

    public void setStatusCode(int i) {
        if (!isComplete()) {
            this.statusCode = i;
            TraceMachine.setCurrentTraceParam("status_code", Integer.valueOf(i));
            return;
        }
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("setStatusCode(...) called on TransactionState in ");
        a.append(this.state.toString());
        a.append(" state");
        agentLog.warning(a.toString());
    }

    public void setUrl(String str) {
        String sanitizeUrl = Util.sanitizeUrl(str);
        if (sanitizeUrl != null) {
            if (!isSent()) {
                this.url = sanitizeUrl;
                try {
                    TraceMachine.setCurrentDisplayName("External/" + new URL(sanitizeUrl).getHost());
                } catch (MalformedURLException unused) {
                    AgentLog agentLog = log;
                    agentLog.error("unable to parse host name from " + sanitizeUrl);
                }
                TraceMachine.setCurrentTraceParam("uri", sanitizeUrl);
                return;
            }
            AgentLog agentLog2 = log;
            StringBuilder a = outline.m2937a("setUrl(...) called on TransactionState in ");
            a.append(this.state.toString());
            a.append(" state");
            agentLog2.warning(a.toString());
        }
    }

    public void setWanType(String str) {
        if (!isSent()) {
            this.wanType = str;
            TraceMachine.setCurrentTraceParam(HttpErrorMeasurementProducer.WAN_TYPE_PARAMS_KEY, str);
            return;
        }
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("setWanType(...) called on TransactionState in ");
        a.append(this.state.toString());
        a.append(" state");
        agentLog.warning(a.toString());
    }

    public String toString() {
        StringBuilder a = outline.m2937a("TransactionState{url='");
        outline.m2940a(a, this.url, '\'', ", httpMethod='");
        outline.m2940a(a, this.httpMethod, '\'', ", statusCode=");
        a.append(this.statusCode);
        a.append(", errorCode=");
        a.append(this.errorCode);
        a.append(", bytesSent=");
        a.append(this.bytesSent);
        a.append(", bytesReceived=");
        a.append(this.bytesReceived);
        a.append(", startTime=");
        a.append(this.startTime);
        a.append(", endTime=");
        a.append(this.endTime);
        a.append(", appData='");
        outline.m2940a(a, this.appData, '\'', ", carrier='");
        outline.m2940a(a, this.carrier, '\'', ", wanType='");
        outline.m2940a(a, this.wanType, '\'', ", state=");
        a.append(this.state);
        a.append(", contentType='");
        outline.m2940a(a, this.contentType, '\'', ", transactionData=");
        a.append(this.transactionData);
        a.append('}');
        return a.toString();
    }

    public TransactionData toTransactionData() {
        float f;
        if (!isComplete()) {
            log.warning("toTransactionData() called on incomplete TransactionState");
        }
        if (this.url == null) {
            log.error("Attempted to convert a TransactionState instance with no URL into a TransactionData");
            return null;
        }
        float f2 = ((float) (this.endTime - this.startTime)) / 1000.0f;
        if (f2 < 0.0f) {
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("Invalid response duration detected: start[");
            a.append(this.startTime);
            a.append("] end[");
            a.append(this.endTime);
            a.append("]");
            agentLog.error(a.toString());
            StatsEngine.get().inc(MetricNames.SUPPORTABILITY_RESPONSE_TIME_INVALID_DURATION);
            f = 0.0f;
        } else {
            f = f2;
        }
        if (this.transactionData == null) {
            this.transactionData = new TransactionData(this.url, this.httpMethod, this.carrier, f, this.statusCode, this.errorCode, this.bytesSent, this.bytesReceived, this.appData, this.wanType, this.catPayload);
        }
        return this.transactionData;
    }
}
