package com.newrelic.agent.android.instrumentation;

import com.newrelic.agent.android.Agent;
import com.newrelic.agent.android.Measurements;
import com.newrelic.agent.android.TaskQueue;
import com.newrelic.agent.android.api.common.TransactionData;
import com.newrelic.agent.android.connectivity.CatFacade;
import com.newrelic.agent.android.instrumentation.httpclient.ContentBufferingResponseEntityImpl;
import com.newrelic.agent.android.instrumentation.httpclient.HttpRequestEntityImpl;
import com.newrelic.agent.android.instrumentation.httpclient.HttpResponseEntityImpl;
import com.newrelic.agent.android.instrumentation.p225io.CountingInputStream;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.measurement.http.HttpTransactionMeasurement;
import com.newrelic.agent.android.tracing.TraceMachine;
import com.newrelic.agent.android.util.Constants;
import com.newrelic.agent.android.util.ExceptionHelper;
import java.io.IOException;
import java.io.InputStream;
import java.net.HttpURLConnection;
import java.text.MessageFormat;
import java.util.TreeMap;
import org.apache.http.Header;
import org.apache.http.HttpEntityEnclosingRequest;
import org.apache.http.HttpHost;
import org.apache.http.HttpRequest;
import org.apache.http.HttpResponse;
import org.apache.http.RequestLine;
import org.apache.http.client.methods.HttpUriRequest;
import p085c.p086a.p087a.p088a.outline;

public class TransactionStateUtil {
    public static final long CONTENTLENGTH_UNKNOWN = -1;
    public static final CatFacade catFacade = Agent.getCatFacade();
    public static final AgentLog log = AgentLogManager.getAgentLog();

    public static void addCatPayloadHeader(TransactionState transactionState, HttpRequest httpRequest) {
        if (transactionState.getCatPayload() != null) {
            httpRequest.setHeader(Constants.Network.CONNECTIVITY_TRACE_HEADER, transactionState.getCatPayload().asBase64Json());
        }
    }

    public static void addCrossProcessIdHeader(HttpRequest httpRequest) {
        String crossProcessId = Agent.getCrossProcessId();
        if (crossProcessId != null) {
            TraceMachine.setCurrentTraceParam("cross_process_data", crossProcessId);
            httpRequest.setHeader(Constants.Network.CROSS_PROCESS_ID_HEADER, crossProcessId);
        }
    }

    public static void addTransactionAndErrorData(TransactionState transactionState, HttpResponse httpResponse) {
        String str;
        Header[] headers;
        String str2;
        TransactionData end = transactionState.end();
        if (end != null) {
            if (transactionState.isErrorOrFailure()) {
                TreeMap treeMap = new TreeMap();
                if (httpResponse != null) {
                    try {
                        if (httpResponse.getEntity() != null) {
                            if (!(httpResponse.getEntity() instanceof HttpRequestEntityImpl)) {
                                httpResponse.setEntity(new ContentBufferingResponseEntityImpl(httpResponse.getEntity()));
                            }
                            InputStream content = httpResponse.getEntity().getContent();
                            if (content instanceof CountingInputStream) {
                                str = ((CountingInputStream) content).getBufferAsString();
                                headers = httpResponse.getHeaders(Constants.Network.CONTENT_TYPE_HEADER);
                                str2 = null;
                                if (headers != null && headers.length > 0 && !"".equals(headers[0].getValue())) {
                                    str2 = headers[0].getValue();
                                }
                                if (str2 != null && str2.length() > 0) {
                                    treeMap.put(Constants.Transactions.CONTENT_TYPE, str2);
                                }
                            } else {
                                log.error("Unable to wrap content stream for entity");
                            }
                        } else {
                            log.debug("null response entity. response-body will be reported empty");
                        }
                    } catch (IllegalStateException e) {
                        log.error(e.toString());
                    } catch (IOException e2) {
                        log.error(e2.toString());
                    }
                    str = "";
                    headers = httpResponse.getHeaders(Constants.Network.CONTENT_TYPE_HEADER);
                    str2 = null;
                    str2 = headers[0].getValue();
                    treeMap.put(Constants.Transactions.CONTENT_TYPE, str2);
                } else {
                    str = "";
                }
                treeMap.put(Constants.Transactions.CONTENT_LENGTH, transactionState.getBytesReceived() + "");
                end.setResponseBody(str);
                end.setParams(treeMap);
                Measurements.addHttpError(end);
            }
            TaskQueue.queue(new HttpTransactionMeasurement(end));
        }
    }

    public static void inspectAndInstrument(TransactionState transactionState, String str, String str2) {
        transactionState.setUrl(str);
        transactionState.setHttpMethod(str2);
        transactionState.setCarrier(Agent.getActiveNetworkCarrier());
        transactionState.setWanType(Agent.getActiveNetworkWanType());
    }

    public static void inspectAndInstrumentResponse(TransactionState transactionState, String str, int i, int i2) {
        if (str != null && !str.equals("")) {
            transactionState.setAppData(str);
        }
        if (i >= 0) {
            transactionState.setBytesReceived((long) i);
        }
        transactionState.setStatusCode(i2);
    }

    public static void setCatPayload(TransactionState transactionState) {
        if (transactionState.getCatPayload() == null) {
            transactionState.setCatPayload(catFacade.startTrip());
        }
    }

    public static void setCrossProcessHeader(HttpURLConnection httpURLConnection) {
        String crossProcessId = Agent.getCrossProcessId();
        if (crossProcessId != null) {
            httpURLConnection.setRequestProperty(Constants.Network.CROSS_PROCESS_ID_HEADER, crossProcessId);
        }
    }

    public static void setErrorCodeFromException(TransactionState transactionState, Exception exc) {
        int exceptionToErrorCode = ExceptionHelper.exceptionToErrorCode(exc);
        AgentLog agentLog = log;
        StringBuilder a = outline.m2937a("TransactionStateUtil: Attempting to convert network exception ");
        a.append(exc.getClass().getName());
        a.append(" to error code.");
        agentLog.error(a.toString());
        transactionState.setErrorCode(exceptionToErrorCode);
    }

    public static void wrapRequestEntity(TransactionState transactionState, HttpRequest httpRequest) {
        if (httpRequest instanceof HttpEntityEnclosingRequest) {
            HttpEntityEnclosingRequest httpEntityEnclosingRequest = (HttpEntityEnclosingRequest) httpRequest;
            if (httpEntityEnclosingRequest.getEntity() != null) {
                httpEntityEnclosingRequest.setEntity(new HttpRequestEntityImpl(httpEntityEnclosingRequest.getEntity(), transactionState));
            }
        }
    }

    public static void inspectAndInstrument(TransactionState transactionState, HttpURLConnection httpURLConnection) {
        inspectAndInstrument(transactionState, httpURLConnection.getURL().toString(), httpURLConnection.getRequestMethod());
    }

    public static void inspectAndInstrumentResponse(TransactionState transactionState, HttpURLConnection httpURLConnection) {
        int i;
        String headerField = httpURLConnection.getHeaderField(Constants.Network.APP_DATA_HEADER);
        int contentLength = httpURLConnection.getContentLength();
        try {
            i = httpURLConnection.getResponseCode();
        } catch (IOException e) {
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("Failed to retrieve response code due to an I/O exception: ");
            a.append(e.getMessage());
            agentLog.debug(a.toString());
            i = 0;
            inspectAndInstrumentResponse(transactionState, headerField, contentLength, i);
        } catch (NullPointerException e2) {
            log.error("Failed to retrieve response code due to underlying (Harmony?) NPE", e2);
            i = 0;
            inspectAndInstrumentResponse(transactionState, headerField, contentLength, i);
        }
        inspectAndInstrumentResponse(transactionState, headerField, contentLength, i);
    }

    public static HttpRequest inspectAndInstrument(TransactionState transactionState, HttpHost httpHost, HttpRequest httpRequest) {
        addCrossProcessIdHeader(httpRequest);
        RequestLine requestLine = httpRequest.getRequestLine();
        if (requestLine != null) {
            String uri = requestLine.getUri();
            boolean z = uri != null && uri.length() >= 10 && uri.substring(0, 10).indexOf("://") >= 0;
            if (!z && uri != null && httpHost != null) {
                String str = httpHost.toURI().toString();
                StringBuilder a = outline.m2937a(str);
                String str2 = "/";
                if (str.endsWith(str2) || uri.startsWith(str2)) {
                    str2 = "";
                }
                uri = outline.m2935a(a, str2, uri);
            } else if (!z) {
                uri = null;
            }
            inspectAndInstrument(transactionState, uri, requestLine.getMethod());
        }
        addCatPayloadHeader(transactionState, httpRequest);
        if (transactionState.getUrl() == null || transactionState.getHttpMethod() == null) {
            try {
                throw new Exception("TransactionData constructor was not provided with a valid URL, host or HTTP method");
            } catch (Exception e) {
                AgentLogManager.getAgentLog().error(MessageFormat.format("TransactionStateUtil.inspectAndInstrument(...) for {0} could not determine request URL or HTTP method [host={1}, requestLine={2}]", new Object[]{httpRequest.getClass().getCanonicalName(), httpHost, requestLine}), e);
                return httpRequest;
            }
        } else {
            wrapRequestEntity(transactionState, httpRequest);
            return httpRequest;
        }
    }

    public static HttpUriRequest inspectAndInstrument(TransactionState transactionState, HttpUriRequest httpUriRequest) {
        addCrossProcessIdHeader(httpUriRequest);
        inspectAndInstrument(transactionState, httpUriRequest.getURI().toString(), httpUriRequest.getMethod());
        addCatPayloadHeader(transactionState, httpUriRequest);
        wrapRequestEntity(transactionState, httpUriRequest);
        return httpUriRequest;
    }

    public static HttpResponse inspectAndInstrument(TransactionState transactionState, HttpResponse httpResponse) {
        transactionState.setStatusCode(httpResponse.getStatusLine().getStatusCode());
        Header[] headers = httpResponse.getHeaders(Constants.Network.APP_DATA_HEADER);
        if (headers != null && headers.length > 0 && !"".equals(headers[0].getValue())) {
            transactionState.setAppData(headers[0].getValue());
        }
        Header[] headers2 = httpResponse.getHeaders(Constants.Network.CONTENT_LENGTH_HEADER);
        if (headers2 != null && headers2.length > 0) {
            try {
                transactionState.setBytesReceived(Long.parseLong(headers2[0].getValue()));
                addTransactionAndErrorData(transactionState, httpResponse);
            } catch (NumberFormatException e) {
                AgentLog agentLog = log;
                StringBuilder a = outline.m2937a("Failed to parse content length: ");
                a.append(e.toString());
                agentLog.warning(a.toString());
            }
        } else if (httpResponse.getEntity() != null) {
            httpResponse.setEntity(new HttpResponseEntityImpl(httpResponse.getEntity(), transactionState, -1));
        } else {
            transactionState.setBytesReceived(0);
            addTransactionAndErrorData(transactionState, (HttpResponse) null);
        }
        return httpResponse;
    }
}
