package com.newrelic.agent.android.instrumentation;

import android.view.MotionEvent;
import android.view.View;
import android.widget.AdapterView;
import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.gestures.GestureReporter;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;

public class ViewListeners {
    public static final String AGENT_PACKAGE_NAME = "com.newrelic.agent.android";
    public static final String GESTURES_PACKAGE_NAME = "com.newrelic.agent.android.gestures";
    public static final String SET_ON_CLICK_LISTENER = "setOnClickListener";
    public static final String SET_ON_LONG_CLICK_LISTENER = "setOnLongClickListener";
    public static final String SET_ON_TOUCH_LISTENER = "setOnTouchListener";
    public static Map<Integer, ListenerElement> listenerCache = new HashMap();

    public static abstract class ListenerDelegate<T> {
        public ListenerElement listenerElement;
        public final Set<T> listeners = new HashSet();
        public final View view;

        public ListenerDelegate(View view2, T t) {
            this.view = view2;
            addListener(t);
        }

        public void addListener(T t) {
            if (t != null) {
                this.listeners.add(t);
                if (!t.getClass().getName().toLowerCase().startsWith(ViewListeners.GESTURES_PACKAGE_NAME)) {
                    Thread currentThread = Thread.currentThread();
                    int i = 3;
                    if (currentThread.getStackTrace().length > 3) {
                        while (i < currentThread.getStackTrace().length) {
                            StackTraceElement stackTraceElement = currentThread.getStackTrace()[i];
                            if (stackTraceElement.getClassName().startsWith("com.newrelic.agent.android") || stackTraceElement.getMethodName().equalsIgnoreCase(ViewListeners.SET_ON_CLICK_LISTENER) || stackTraceElement.getMethodName().equalsIgnoreCase(ViewListeners.SET_ON_TOUCH_LISTENER) || stackTraceElement.getMethodName().equalsIgnoreCase(ViewListeners.SET_ON_LONG_CLICK_LISTENER)) {
                                i++;
                            } else {
                                this.listenerElement = new ListenerElement(t.getClass().getName() + "#" + getListenerMethod(), stackTraceElement.getClassName() + "#" + stackTraceElement.getMethodName());
                                ViewListeners.listenerCache.put(Integer.valueOf(this.view.hashCode()), this.listenerElement);
                                return;
                            }
                        }
                    }
                }
            }
        }

        public Map<String, Object> createListenerAttributes() {
            HashMap hashMap = new HashMap();
            ListenerElement listenerElement2 = this.listenerElement;
            if (listenerElement2 != null) {
                hashMap.put(AnalyticAttribute.GESTURE_TARGET_OBJECT_ATTRIBUTE, listenerElement2.targetObject);
                hashMap.put(AnalyticAttribute.GESTURE_METHOD_EXECUTED_ATTRIBUTE, this.listenerElement.methodExecuted);
            }
            return hashMap;
        }

        public abstract String getListenerMethod();
    }

    public static class ListenerElement {
        public String methodExecuted;
        public String targetObject;

        public ListenerElement(String str, String str2) {
            this.targetObject = str;
            this.methodExecuted = str2;
        }
    }

    public static class OnClickListenerDelegate extends ListenerDelegate<View.OnClickListener> implements View.OnClickListener {
        public static final String ON_CLICK = "onClick";

        public OnClickListenerDelegate(View view, View.OnClickListener onClickListener) {
            super(view, onClickListener);
        }

        public String getListenerMethod() {
            return ON_CLICK;
        }

        public void onClick(View view) {
            GestureReporter.recordOnClick(view, createListenerAttributes());
            for (T t : this.listeners) {
                if (t != null) {
                    t.onClick(view);
                }
            }
        }
    }

    public static class OnItemClickListenerDelegate extends ListenerDelegate<AdapterView.OnItemClickListener> implements AdapterView.OnItemClickListener {
        public static final String ON_ITEM_CLICK = "onItemClick";

        public OnItemClickListenerDelegate(AdapterView adapterView, AdapterView.OnItemClickListener onItemClickListener) {
            super(adapterView, onItemClickListener);
        }

        public String getListenerMethod() {
            return ON_ITEM_CLICK;
        }

        public void onItemClick(AdapterView<?> adapterView, View view, int i, long j) {
            GestureReporter.recordOnClick(adapterView, createListenerAttributes());
            for (T onItemClick : this.listeners) {
                onItemClick.onItemClick(adapterView, view, i, j);
            }
        }
    }

    public static class OnLongClickListenerDelegate extends ListenerDelegate<View.OnLongClickListener> implements View.OnLongClickListener {
        public static final String ON_LONG_CLICK = "onLongClick";

        public OnLongClickListenerDelegate(View view, View.OnLongClickListener onLongClickListener) {
            super(view, onLongClickListener);
        }

        public String getListenerMethod() {
            return ON_LONG_CLICK;
        }

        public boolean onLongClick(View view) {
            GestureReporter.recordOnLongClick(view, createListenerAttributes());
            boolean z = false;
            for (T onLongClick : this.listeners) {
                z |= onLongClick.onLongClick(view);
            }
            return z;
        }
    }

    public static class OnTouchListenerDelegate extends ListenerDelegate<View.OnTouchListener> implements View.OnTouchListener {
        public static final String ON_TOUCH = "onTouch";

        public OnTouchListenerDelegate(View view, View.OnTouchListener onTouchListener) {
            super(view, onTouchListener);
        }

        public String getListenerMethod() {
            return ON_TOUCH;
        }

        public boolean onTouch(View view, MotionEvent motionEvent) {
            GestureReporter.recordOnTouch(view, motionEvent, createListenerAttributes());
            boolean z = false;
            for (T onTouch : this.listeners) {
                z |= onTouch.onTouch(view, motionEvent);
            }
            return z;
        }
    }

    public static ListenerElement getListenerElement(int i) {
        return listenerCache.get(Integer.valueOf(i));
    }

    public static void resetCaches() {
        resetTouchCache();
    }

    public static void resetTouchCache() {
        listenerCache = new HashMap();
    }
}
