package com.newrelic.agent.android.payload;

import com.newrelic.agent.android.Agent;
import com.newrelic.agent.android.AgentConfiguration;
import com.newrelic.agent.android.agentdata.AgentDataReporter;
import com.newrelic.agent.android.crash.CrashReporter;
import com.newrelic.agent.android.harvest.Harvest;
import com.newrelic.agent.android.harvest.HarvestLifecycleAware;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.metric.MetricNames;
import com.newrelic.agent.android.payload.PayloadSender;
import com.newrelic.agent.android.stats.StatsEngine;
import com.newrelic.agent.android.stats.TicToc;
import com.newrelic.agent.android.util.NamedThreadFactory;
import java.util.Map;
import java.util.concurrent.Callable;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentLinkedQueue;
import java.util.concurrent.Future;
import java.util.concurrent.ScheduledFuture;
import java.util.concurrent.ScheduledThreadPoolExecutor;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.TimeUnit;
import java.util.concurrent.atomic.AtomicReference;
import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;
import p085c.p086a.p087a.p088a.outline;

public class PayloadController implements HarvestLifecycleAware {
    public static final long PAYLOAD_COLLECTOR_TIMEOUT = 5000;
    public static final long PAYLOAD_REQUEUE_PERIOD_MS = 120000;
    public static final Runnable dequeueRunnable = new Runnable() {
        public void run() {
            if (PayloadController.isInitialized()) {
                PayloadController.instance.get().dequeuePayloadSenders();
            }
        }
    };
    public static AtomicReference<PayloadController> instance = new AtomicReference<>((Object) null);
    public static final AgentLog log = AgentLogManager.getAgentLog();
    public static boolean opportunisticUploads = false;
    public static Lock payloadQueueLock = new ReentrantLock(false);
    public static ConcurrentLinkedQueue<PayloadReaper> payloadReaperQueue = null;
    public static ConcurrentLinkedQueue<PayloadReaper> payloadReaperRetryQueue = null;
    public static ThrottledScheduledThreadPoolExecutor queueExecutor = null;
    public static Map<String, Future> reapersInFlight = null;
    public static ScheduledFuture<?> requeueFuture = null;
    public static final Runnable requeueRunnable = new Runnable() {
        public void run() {
            if (PayloadController.isInitialized()) {
                PayloadController.instance.get().requeuePayloadSenders();
            }
        }
    };
    public final AgentConfiguration agentConfiguration;

    public static class ThrottledScheduledThreadPoolExecutor extends ScheduledThreadPoolExecutor {
        public static final int THROTTLE_LIMIT = 16;
        public static final int THROTTLE_SLEEP = 50;

        public ThrottledScheduledThreadPoolExecutor(int i, ThreadFactory threadFactory) {
            super(i, threadFactory);
        }

        public <T> Future<T> submit(Callable<T> callable) {
            if (getQueue().size() >= 16) {
                StatsEngine.get().inc(MetricNames.SUPPORTABILITY_HEX_UPLOAD_THROTTLED);
            }
            return super.submit(callable);
        }
    }

    public PayloadController(AgentConfiguration agentConfiguration2) {
        this.agentConfiguration = agentConfiguration2;
    }

    /* access modifiers changed from: private */
    public final void dequeuePayloadSenders() {
        if (payloadQueueLock.tryLock()) {
            while (!payloadReaperQueue.isEmpty()) {
                try {
                    PayloadReaper poll = payloadReaperQueue.poll();
                    if (poll != null) {
                        submitPayload(poll);
                    }
                } catch (Exception e) {
                    AgentLog agentLog = log;
                    agentLog.error("PayloadController.dequeuePayloadSenders(): " + e);
                } catch (Throwable th) {
                    payloadQueueLock.unlock();
                    throw th;
                }
            }
            payloadQueueLock.unlock();
        }
    }

    public static PayloadController initialize(AgentConfiguration agentConfiguration2) {
        if (instance.compareAndSet((Object) null, new PayloadController(agentConfiguration2))) {
            payloadReaperQueue = new ConcurrentLinkedQueue<>();
            payloadReaperRetryQueue = new ConcurrentLinkedQueue<>();
            ThrottledScheduledThreadPoolExecutor throttledScheduledThreadPoolExecutor = new ThrottledScheduledThreadPoolExecutor(agentConfiguration2.getIOThreadSize(), new NamedThreadFactory("NR-PayloadWorker"));
            queueExecutor = throttledScheduledThreadPoolExecutor;
            requeueFuture = throttledScheduledThreadPoolExecutor.scheduleAtFixedRate(requeueRunnable, PAYLOAD_REQUEUE_PERIOD_MS, PAYLOAD_REQUEUE_PERIOD_MS, TimeUnit.MILLISECONDS);
            reapersInFlight = new ConcurrentHashMap();
            opportunisticUploads = false;
            CrashReporter initialize = CrashReporter.initialize(agentConfiguration2);
            if (initialize != null) {
                initialize.start();
            } else {
                log.warning("PayloadController.initialize: No crash reporter - crash reporting will be disabled");
            }
            AgentDataReporter initialize2 = AgentDataReporter.initialize(agentConfiguration2);
            if (initialize2 != null) {
                initialize2.start();
            } else {
                log.warning("PayloadController.initialize: No payload reporter - payload reporting will be disabled");
            }
            Harvest.addHarvestListener(instance.get());
        }
        return instance.get();
    }

    public static boolean isInitialized() {
        return instance.get() != null;
    }

    public static boolean payloadInFlight(Payload payload) {
        return reapersInFlight.containsKey(payload.getUuid());
    }

    /* access modifiers changed from: private */
    public void requeuePayloadSenders() {
        if (payloadQueueLock.tryLock()) {
            while (!payloadReaperRetryQueue.isEmpty()) {
                try {
                    PayloadReaper poll = payloadReaperRetryQueue.poll();
                    if (poll != null) {
                        if (!poll.sender.getPayload().isStale((long) this.agentConfiguration.getPayloadTTL())) {
                            submitPayload(poll);
                        } else {
                            log.warning("PayloadController.requeuePayloadSenders: Will not re-queue stale payload.");
                        }
                    }
                } finally {
                    payloadQueueLock.unlock();
                }
            }
        }
    }

    public static boolean shouldUploadOpportunistically() {
        return opportunisticUploads && Agent.hasReachableNetworkConnection((String) null);
    }

    public static void shutdown() {
        if (isInitialized()) {
            try {
                Harvest.removeHarvestListener(instance.get());
                if (requeueFuture != null) {
                    requeueFuture.cancel(true);
                    requeueFuture = null;
                }
                queueExecutor.shutdown();
                try {
                    CrashReporter.shutdown();
                    AgentDataReporter.shutdown();
                    if (!queueExecutor.awaitTermination(PAYLOAD_COLLECTOR_TIMEOUT, TimeUnit.MILLISECONDS)) {
                        log.warning("PayloadController.shutdown: upload thread(s) timed-out before handler");
                        queueExecutor.shutdownNow();
                    }
                } catch (InterruptedException unused) {
                }
            } finally {
                instance.set((Object) null);
            }
        }
    }

    public static Future submitCallable(Callable<?> callable) {
        return queueExecutor.submit(callable);
    }

    public static Future submitPayload(PayloadSender payloadSender) {
        return submitPayload(payloadSender, (PayloadSender.CompletionHandler) null);
    }

    public void onHarvest() {
        queueExecutor.submit(dequeueRunnable);
    }

    public void onHarvestBefore() {
    }

    public void onHarvestComplete() {
    }

    public void onHarvestConnected() {
    }

    public void onHarvestDisabled() {
    }

    public void onHarvestDisconnected() {
    }

    public void onHarvestError() {
    }

    public void onHarvestFinalize() {
    }

    public void onHarvestSendFailed() {
    }

    public void onHarvestStart() {
    }

    public void onHarvestStop() {
    }

    public boolean uploadOpportunistically() {
        return opportunisticUploads;
    }

    public static Future submitPayload(PayloadSender payloadSender, PayloadSender.CompletionHandler completionHandler) {
        TicToc ticToc = new TicToc();
        if (!isInitialized()) {
            return null;
        }
        ticToc.tic();
        C17443 r1 = new PayloadReaper(payloadSender, completionHandler) {
            public PayloadSender call() throws Exception {
                PayloadSender call = super.call();
                if (call != null && !call.isSuccessfulResponse() && call.shouldRetry()) {
                    PayloadController.payloadReaperRetryQueue.offer(this);
                }
                PayloadController.reapersInFlight.remove(getUuid());
                return call;
            }
        };
        payloadReaperQueue.remove(r1);
        payloadReaperRetryQueue.remove(r1);
        Future future = reapersInFlight.get(r1.getUuid());
        if (future != null) {
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("PayloadController.submitPayload: [");
            a.append(r1.getUuid());
            a.append("] is already in progress.");
            agentLog.warning(a.toString());
            return future;
        }
        if (payloadSender.shouldUploadOpportunistically()) {
            future = queueExecutor.submit(r1);
            reapersInFlight.put(r1.getUuid(), future);
        } else {
            payloadReaperQueue.offer(r1);
        }
        AgentLog agentLog2 = log;
        StringBuilder a2 = outline.m2937a("PayloadController.submitPayload: ");
        a2.append(String.valueOf(ticToc.toc()));
        a2.append("ms. waiting to submit payload [");
        a2.append(r1.getUuid());
        a2.append("].");
        agentLog2.debug(a2.toString());
        return future;
    }

    public static Future submitPayload(PayloadReaper payloadReaper) {
        if (!isInitialized()) {
            return null;
        }
        payloadReaperQueue.remove(payloadReaper);
        payloadReaperRetryQueue.remove(payloadReaper);
        Future future = reapersInFlight.get(payloadReaper.getUuid());
        if (future != null) {
            AgentLog agentLog = log;
            StringBuilder a = outline.m2937a("PayloadController.submitPayload: [");
            a.append(payloadReaper.getUuid());
            a.append("] is already in progress.");
            agentLog.warning(a.toString());
            return future;
        }
        Future submit = queueExecutor.submit(payloadReaper);
        reapersInFlight.put(payloadReaper.getUuid(), submit);
        return submit;
    }
}
