package com.newrelic.agent.android.tracing;

import com.newrelic.agent.android.Agent;
import com.newrelic.agent.android.Measurements;
import com.newrelic.agent.android.TaskQueue;
import com.newrelic.agent.android.activity.MeasuredActivity;
import com.newrelic.agent.android.activity.NamedActivity;
import com.newrelic.agent.android.analytics.AnalyticAttribute;
import com.newrelic.agent.android.harvest.ActivitySighting;
import com.newrelic.agent.android.harvest.ConnectInformation;
import com.newrelic.agent.android.harvest.type.BaseHarvestable;
import com.newrelic.agent.android.harvest.type.HarvestableArray;
import com.newrelic.agent.android.logging.AgentLog;
import com.newrelic.agent.android.logging.AgentLogManager;
import com.newrelic.agent.android.metric.Metric;
import com.newrelic.agent.android.metric.MetricNames;
import com.newrelic.agent.android.tracing.Sample;
import com.newrelic.agent.android.util.SafeJsonPrimitive;
import com.newrelic.com.google.gson.Gson;
import com.newrelic.com.google.gson.JsonArray;
import com.newrelic.com.google.gson.JsonObject;
import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.HashSet;
import java.util.Map;
import java.util.Set;
import java.util.UUID;
import java.util.concurrent.ConcurrentHashMap;
import p085c.p086a.p087a.p088a.outline;

public class ActivityTrace extends HarvestableArray {
    public static final HashMap<String, String> ACTIVITY_HISTORY_TYPE = new HashMap<String, String>() {
        {
            put(AnalyticAttribute.TYPE_ATTRIBUTE, "ACTIVITY_HISTORY");
        }
    };
    public static final HashMap<String, String> ENVIRONMENT_TYPE = new HashMap<String, String>() {
        {
            put(AnalyticAttribute.TYPE_ATTRIBUTE, "ENVIRONMENT");
        }
    };
    public static final int MAX_TRACES = 2000;
    public static final String SIZE_NORMAL = "NORMAL";
    public static final String TRACE_VERSION = "1.0";
    public static final HashMap<String, String> VITALS_TYPE = new HashMap<String, String>() {
        {
            put(AnalyticAttribute.TYPE_ATTRIBUTE, "VITALS");
        }
    };
    public boolean complete = false;
    public long lastUpdatedAt;
    public final AgentLog log = AgentLogManager.getAgentLog();
    public NamedActivity measuredActivity;
    public final Set<UUID> missingChildren = Collections.synchronizedSet(new HashSet());
    public final Metric networkCountMetric = new Metric(MetricNames.ACTIVITY_NETWORK_METRIC_COUNT_FORMAT);
    public final Metric networkTimeMetric = new Metric(MetricNames.ACTIVITY_NETWORK_METRIC_TIME_FORMAT);
    public final HashMap<String, String> params = new HashMap<>();
    public ActivitySighting previousActivity;
    public long reportAttemptCount = 0;
    public Trace rootTrace;
    public long startedAt;
    public int traceCount = 0;
    public final ConcurrentHashMap<UUID, Trace> traces = new ConcurrentHashMap<>();
    public Map<Sample.SampleType, Collection<Sample>> vitals;

    public ActivityTrace() {
    }

    private JsonArray getEnvironment() {
        JsonArray jsonArray = new JsonArray();
        jsonArray.add(new Gson().toJsonTree(ENVIRONMENT_TYPE, BaseHarvestable.GSON_STRING_MAP_TYPE));
        jsonArray.addAll(new ConnectInformation(Agent.getApplicationInformation(), Agent.getDeviceInformation()).asJsonArray());
        HashMap hashMap = new HashMap();
        hashMap.put("size", SIZE_NORMAL);
        jsonArray.add(new Gson().toJsonTree(hashMap, BaseHarvestable.GSON_STRING_MAP_TYPE));
        return jsonArray;
    }

    private JsonArray getPreviousActivityAsJson() {
        JsonArray jsonArray = new JsonArray();
        jsonArray.add(new Gson().toJsonTree(ACTIVITY_HISTORY_TYPE, BaseHarvestable.GSON_STRING_MAP_TYPE));
        jsonArray.addAll(this.previousActivity.asJsonArray());
        return jsonArray;
    }

    private JsonArray getVitalsAsJson() {
        JsonArray jsonArray = new JsonArray();
        jsonArray.add(new Gson().toJsonTree(VITALS_TYPE, BaseHarvestable.GSON_STRING_MAP_TYPE));
        JsonObject jsonObject = new JsonObject();
        Map<Sample.SampleType, Collection<Sample>> map = this.vitals;
        if (map != null) {
            for (Map.Entry next : map.entrySet()) {
                JsonArray jsonArray2 = new JsonArray();
                for (Sample sample : (Collection) next.getValue()) {
                    if (sample.getTimestamp() <= this.lastUpdatedAt) {
                        jsonArray2.add(sample.asJsonArray());
                    }
                }
                jsonObject.add(((Sample.SampleType) next.getKey()).toString(), jsonArray2);
            }
        }
        jsonArray.add(jsonObject);
        return jsonArray;
    }

    private JsonArray traceToTree(Trace trace) {
        JsonArray jsonArray = new JsonArray();
        trace.prepareForSerialization();
        jsonArray.add(new Gson().toJsonTree(trace.getParams(), BaseHarvestable.GSON_STRING_MAP_TYPE));
        jsonArray.add(SafeJsonPrimitive.factory((Number) Long.valueOf(trace.entryTimestamp)));
        jsonArray.add(SafeJsonPrimitive.factory((Number) Long.valueOf(trace.exitTimestamp)));
        jsonArray.add(SafeJsonPrimitive.factory(trace.displayName));
        JsonArray jsonArray2 = new JsonArray();
        jsonArray2.add(SafeJsonPrimitive.factory((Number) Long.valueOf(trace.threadId)));
        jsonArray2.add(SafeJsonPrimitive.factory(trace.threadName));
        jsonArray.add(jsonArray2);
        if (trace.getChildren().isEmpty()) {
            jsonArray.add(new JsonArray());
        } else {
            JsonArray jsonArray3 = new JsonArray();
            for (UUID uuid : trace.getChildren()) {
                Trace trace2 = this.traces.get(uuid);
                if (trace2 != null) {
                    jsonArray3.add(traceToTree(trace2));
                }
            }
            jsonArray.add(jsonArray3);
        }
        return jsonArray;
    }

    public void addCompletedTrace(Trace trace) {
        if (trace.getType() == TraceType.NETWORK) {
            this.networkCountMetric.sample(1.0d);
            this.networkTimeMetric.sample((double) trace.getDurationAsSeconds());
            Trace trace2 = this.rootTrace;
            if (trace2 != null) {
                trace2.childExclusiveTime = trace.getDurationAsMilliseconds() + trace2.childExclusiveTime;
            }
        }
        trace.traceMachine = null;
        this.missingChildren.remove(trace.myUUID);
        if (this.traceCount > 2000) {
            AgentLog agentLog = this.log;
            StringBuilder a = outline.m2937a("Maximum trace limit reached, discarding trace ");
            a.append(trace.myUUID);
            agentLog.verbose(a.toString());
            return;
        }
        this.traces.put(trace.myUUID, trace);
        this.traceCount++;
        long j = trace.exitTimestamp;
        Trace trace3 = this.rootTrace;
        if (j > trace3.exitTimestamp) {
            trace3.exitTimestamp = j;
        }
        AgentLog agentLog2 = this.log;
        StringBuilder a2 = outline.m2937a("Added trace ");
        a2.append(trace.myUUID.toString());
        a2.append(" missing children: ");
        a2.append(this.missingChildren.size());
        agentLog2.verbose(a2.toString());
        this.lastUpdatedAt = System.currentTimeMillis();
    }

    public void addTrace(Trace trace) {
        this.missingChildren.add(trace.myUUID);
        this.lastUpdatedAt = System.currentTimeMillis();
    }

    public JsonArray asJsonArray() {
        JsonArray jsonArray = new JsonArray();
        if (!this.complete) {
            AgentLog agentLog = this.log;
            StringBuilder a = outline.m2937a("Attempted to serialize trace ");
            a.append(this.rootTrace.myUUID.toString());
            a.append(" but it has yet to be finalized");
            agentLog.verbose(a.toString());
            return null;
        }
        jsonArray.add(new Gson().toJsonTree(this.params, BaseHarvestable.GSON_STRING_MAP_TYPE));
        jsonArray.add(SafeJsonPrimitive.factory((Number) Long.valueOf(this.rootTrace.entryTimestamp)));
        jsonArray.add(SafeJsonPrimitive.factory((Number) Long.valueOf(this.rootTrace.exitTimestamp)));
        jsonArray.add(SafeJsonPrimitive.factory(this.rootTrace.displayName));
        JsonArray jsonArray2 = new JsonArray();
        jsonArray2.add(getEnvironment());
        jsonArray2.add(traceToTree(this.rootTrace));
        jsonArray2.add(getVitalsAsJson());
        if (this.previousActivity != null) {
            jsonArray2.add(getPreviousActivityAsJson());
        }
        jsonArray.add(jsonArray2);
        return jsonArray;
    }

    public void complete() {
        AgentLog agentLog = this.log;
        StringBuilder a = outline.m2937a("Completing trace of ");
        a.append(this.rootTrace.displayName);
        a.append(":");
        a.append(this.rootTrace.myUUID.toString());
        a.append("(");
        a.append(this.traces.size());
        a.append(" traces)");
        agentLog.debug(a.toString());
        Trace trace = this.rootTrace;
        if (trace.exitTimestamp == 0) {
            trace.exitTimestamp = System.currentTimeMillis();
        }
        if (this.traces.isEmpty()) {
            this.rootTrace.traceMachine = null;
            this.complete = true;
            Measurements.endActivityWithoutMeasurement(this.measuredActivity);
            return;
        }
        this.measuredActivity.setEndTime(this.rootTrace.exitTimestamp);
        Measurements.endActivity((MeasuredActivity) this.measuredActivity);
        this.rootTrace.traceMachine = null;
        this.complete = true;
        TaskQueue.queue(this);
    }

    public void discard() {
        AgentLog agentLog = this.log;
        StringBuilder a = outline.m2937a("Discarding trace of ");
        a.append(this.rootTrace.displayName);
        a.append(":");
        a.append(this.rootTrace.myUUID.toString());
        a.append("(");
        a.append(this.traces.size());
        a.append(" traces)");
        agentLog.debug(a.toString());
        this.rootTrace.traceMachine = null;
        this.complete = true;
        Measurements.endActivityWithoutMeasurement(this.measuredActivity);
    }

    /* JADX WARNING: Code restructure failed: missing block: B:4:0x0008, code lost:
        r1 = r0.indexOf("#");
     */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public java.lang.String getActivityName() {
        /*
            r3 = this;
            com.newrelic.agent.android.tracing.Trace r0 = r3.rootTrace
            if (r0 == 0) goto L_0x0016
            java.lang.String r0 = r0.displayName
            if (r0 == 0) goto L_0x0018
            java.lang.String r1 = "#"
            int r1 = r0.indexOf(r1)
            if (r1 <= 0) goto L_0x0018
            r2 = 0
            java.lang.String r0 = r0.substring(r2, r1)
            goto L_0x0018
        L_0x0016:
            java.lang.String r0 = "<activity>"
        L_0x0018:
            return r0
        */
        throw new UnsupportedOperationException("Method not decompiled: com.newrelic.agent.android.tracing.ActivityTrace.getActivityName():java.lang.String");
    }

    public String getId() {
        Trace trace = this.rootTrace;
        if (trace == null) {
            return null;
        }
        return trace.myUUID.toString();
    }

    public long getLastUpdatedAt() {
        return this.lastUpdatedAt;
    }

    public long getReportAttemptCount() {
        return this.reportAttemptCount;
    }

    public Map<UUID, Trace> getTraces() {
        return this.traces;
    }

    public boolean hasMissingChildren() {
        return !this.missingChildren.isEmpty();
    }

    public void incrementReportAttemptCount() {
        this.reportAttemptCount++;
    }

    public boolean isComplete() {
        return this.complete;
    }

    public void setLastUpdatedAt(long j) {
        this.lastUpdatedAt = j;
    }

    public void setVitals(Map<Sample.SampleType, Collection<Sample>> map) {
        this.vitals = map;
    }

    public ActivityTrace(Trace trace) {
        this.rootTrace = trace;
        long j = trace.entryTimestamp;
        this.lastUpdatedAt = j;
        this.startedAt = j;
        this.params.put("traceVersion", "1.0");
        this.params.put(AnalyticAttribute.TYPE_ATTRIBUTE, "ACTIVITY");
        NamedActivity namedActivity = (NamedActivity) Measurements.startActivity(trace.displayName);
        this.measuredActivity = namedActivity;
        namedActivity.setStartTime(trace.entryTimestamp);
    }
}
