package okhttp3.internal.concurrent;

import java.util.ArrayList;
import java.util.List;
import java.util.concurrent.SynchronousQueue;
import java.util.concurrent.ThreadFactory;
import java.util.concurrent.ThreadPoolExecutor;
import java.util.concurrent.TimeUnit;
import java.util.logging.Logger;
import okhttp3.internal.Util;
import p085c.p086a.p087a.p088a.outline;
import p250f.p251i._Arrays;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;

/* compiled from: TaskRunner.kt */
public final class TaskRunner {
    public static final Companion Companion = new Companion((DefaultConstructorMarker) null);
    public static final TaskRunner INSTANCE = new TaskRunner(new RealBackend(Util.threadFactory(Util.okHttpName + " TaskRunner", true)));
    public static final Logger logger;
    public final Backend backend;
    public final List<TaskQueue> busyQueues;
    public boolean coordinatorWaiting;
    public long coordinatorWakeUpAt;
    public int nextQueueName;
    public final List<TaskQueue> readyQueues;
    public final Runnable runnable;

    /* compiled from: TaskRunner.kt */
    public interface Backend {
        void beforeTask(TaskRunner taskRunner);

        void coordinatorNotify(TaskRunner taskRunner);

        void coordinatorWait(TaskRunner taskRunner, long j);

        void execute(Runnable runnable);

        long nanoTime();
    }

    /* compiled from: TaskRunner.kt */
    public static final class Companion {
        public Companion() {
        }

        public final Logger getLogger() {
            return TaskRunner.logger;
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    /* compiled from: TaskRunner.kt */
    public static final class RealBackend implements Backend {
        public final ThreadPoolExecutor executor;

        public RealBackend(ThreadFactory threadFactory) {
            if (threadFactory != null) {
                this.executor = new ThreadPoolExecutor(0, Integer.MAX_VALUE, 60, TimeUnit.SECONDS, new SynchronousQueue(), threadFactory);
            } else {
                Intrinsics.m5822a("threadFactory");
                throw null;
            }
        }

        public void beforeTask(TaskRunner taskRunner) {
            if (taskRunner == null) {
                Intrinsics.m5822a("taskRunner");
                throw null;
            }
        }

        public void coordinatorNotify(TaskRunner taskRunner) {
            if (taskRunner != null) {
                taskRunner.notify();
            } else {
                Intrinsics.m5822a("taskRunner");
                throw null;
            }
        }

        public void coordinatorWait(TaskRunner taskRunner, long j) throws InterruptedException {
            if (taskRunner != null) {
                long j2 = j / 1000000;
                long j3 = j - (1000000 * j2);
                if (j2 > 0 || j > 0) {
                    taskRunner.wait(j2, (int) j3);
                    return;
                }
                return;
            }
            Intrinsics.m5822a("taskRunner");
            throw null;
        }

        public void execute(Runnable runnable) {
            if (runnable != null) {
                this.executor.execute(runnable);
            } else {
                Intrinsics.m5822a("runnable");
                throw null;
            }
        }

        public long nanoTime() {
            return System.nanoTime();
        }

        public final void shutdown() {
            this.executor.shutdown();
        }
    }

    static {
        Logger logger2 = Logger.getLogger(TaskRunner.class.getName());
        Intrinsics.m5821a((Object) logger2, "Logger.getLogger(TaskRunner::class.java.name)");
        logger = logger2;
    }

    public TaskRunner(Backend backend2) {
        if (backend2 != null) {
            this.backend = backend2;
            this.nextQueueName = 10000;
            this.busyQueues = new ArrayList();
            this.readyQueues = new ArrayList();
            this.runnable = new TaskRunner$runnable$1(this);
            return;
        }
        Intrinsics.m5822a("backend");
        throw null;
    }

    private final void afterRun(Task task, long j) {
        if (!Util.assertionsEnabled || Thread.holdsLock(this)) {
            TaskQueue queue$okhttp = task.getQueue$okhttp();
            if (queue$okhttp != null) {
                if (queue$okhttp.getActiveTask$okhttp() == task) {
                    boolean cancelActiveTask$okhttp = queue$okhttp.getCancelActiveTask$okhttp();
                    queue$okhttp.setCancelActiveTask$okhttp(false);
                    queue$okhttp.setActiveTask$okhttp((Task) null);
                    this.busyQueues.remove(queue$okhttp);
                    if (j != -1 && !cancelActiveTask$okhttp && !queue$okhttp.getShutdown$okhttp()) {
                        queue$okhttp.scheduleAndDecide$okhttp(task, j, true);
                    }
                    if (!queue$okhttp.getFutureTasks$okhttp().isEmpty()) {
                        this.readyQueues.add(queue$okhttp);
                        return;
                    }
                    return;
                }
                throw new IllegalStateException("Check failed.".toString());
            }
            Intrinsics.m5820a();
            throw null;
        }
        StringBuilder a = outline.m2937a("Thread ");
        Thread currentThread = Thread.currentThread();
        Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
        a.append(currentThread.getName());
        a.append(" MUST hold lock on ");
        a.append(this);
        throw new AssertionError(a.toString());
    }

    private final void beforeRun(Task task) {
        if (!Util.assertionsEnabled || Thread.holdsLock(this)) {
            task.setNextExecuteNanoTime$okhttp(-1);
            TaskQueue queue$okhttp = task.getQueue$okhttp();
            if (queue$okhttp != null) {
                queue$okhttp.getFutureTasks$okhttp().remove(task);
                this.readyQueues.remove(queue$okhttp);
                queue$okhttp.setActiveTask$okhttp(task);
                this.busyQueues.add(queue$okhttp);
                return;
            }
            Intrinsics.m5820a();
            throw null;
        }
        StringBuilder a = outline.m2937a("Thread ");
        Thread currentThread = Thread.currentThread();
        Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
        a.append(currentThread.getName());
        a.append(" MUST hold lock on ");
        a.append(this);
        throw new AssertionError(a.toString());
    }

    /* access modifiers changed from: private */
    public final void runTask(Task task) {
        if (!Util.assertionsEnabled || !Thread.holdsLock(this)) {
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "currentThread");
            String name = currentThread.getName();
            currentThread.setName(task.getName());
            try {
                long runOnce = task.runOnce();
                synchronized (this) {
                    afterRun(task, runOnce);
                }
                currentThread.setName(name);
            } catch (Throwable th) {
                synchronized (this) {
                    afterRun(task, -1);
                    currentThread.setName(name);
                    throw th;
                }
            }
        } else {
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread2 = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread2, "Thread.currentThread()");
            a.append(currentThread2.getName());
            a.append(" MUST NOT hold lock on ");
            a.append(this);
            throw new AssertionError(a.toString());
        }
    }

    public final List<TaskQueue> activeQueues() {
        List<TaskQueue> a;
        synchronized (this) {
            a = _Arrays.m5805a(this.busyQueues, this.readyQueues);
        }
        return a;
    }

    /* JADX WARNING: Can't wrap try/catch for region: R(7:34|35|36|38|39|46|40) */
    /* JADX WARNING: Code restructure failed: missing block: B:37:0x00ba, code lost:
        r0 = move-exception;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:41:0x00c3, code lost:
        r15.coordinatorWaiting = false;
     */
    /* JADX WARNING: Code restructure failed: missing block: B:42:0x00c5, code lost:
        throw r0;
     */
    /* JADX WARNING: Failed to process nested try/catch */
    /* JADX WARNING: Missing exception handler attribute for start block: B:38:0x00bc */
    /* Code decompiled incorrectly, please refer to instructions dump. */
    public final okhttp3.internal.concurrent.Task awaitTaskToRun() {
        /*
            r15 = this;
            boolean r0 = okhttp3.internal.Util.assertionsEnabled
            if (r0 == 0) goto L_0x0033
            boolean r0 = java.lang.Thread.holdsLock(r15)
            if (r0 == 0) goto L_0x000b
            goto L_0x0033
        L_0x000b:
            java.lang.AssertionError r0 = new java.lang.AssertionError
            java.lang.String r1 = "Thread "
            java.lang.StringBuilder r1 = p085c.p086a.p087a.p088a.outline.m2937a(r1)
            java.lang.Thread r2 = java.lang.Thread.currentThread()
            java.lang.String r3 = "Thread.currentThread()"
            p250f.p254l.p256c.Intrinsics.m5821a((java.lang.Object) r2, (java.lang.String) r3)
            java.lang.String r2 = r2.getName()
            r1.append(r2)
            java.lang.String r2 = " MUST hold lock on "
            r1.append(r2)
            r1.append(r15)
            java.lang.String r1 = r1.toString()
            r0.<init>(r1)
            throw r0
        L_0x0033:
            java.util.List<okhttp3.internal.concurrent.TaskQueue> r0 = r15.readyQueues
            boolean r0 = r0.isEmpty()
            r1 = 0
            if (r0 == 0) goto L_0x003d
            return r1
        L_0x003d:
            okhttp3.internal.concurrent.TaskRunner$Backend r0 = r15.backend
            long r2 = r0.nanoTime()
            r4 = 9223372036854775807(0x7fffffffffffffff, double:NaN)
            java.util.List<okhttp3.internal.concurrent.TaskQueue> r0 = r15.readyQueues
            java.util.Iterator r0 = r0.iterator()
            r6 = r1
        L_0x004f:
            boolean r7 = r0.hasNext()
            r8 = 1
            r9 = 0
            if (r7 == 0) goto L_0x0081
            java.lang.Object r7 = r0.next()
            okhttp3.internal.concurrent.TaskQueue r7 = (okhttp3.internal.concurrent.TaskQueue) r7
            java.util.List r7 = r7.getFutureTasks$okhttp()
            java.lang.Object r7 = r7.get(r9)
            okhttp3.internal.concurrent.Task r7 = (okhttp3.internal.concurrent.Task) r7
            long r10 = r7.getNextExecuteNanoTime$okhttp()
            long r10 = r10 - r2
            r12 = 0
            long r10 = java.lang.Math.max(r12, r10)
            int r14 = (r10 > r12 ? 1 : (r10 == r12 ? 0 : -1))
            if (r14 <= 0) goto L_0x007b
            long r4 = java.lang.Math.min(r10, r4)
            goto L_0x004f
        L_0x007b:
            if (r6 == 0) goto L_0x007f
            r0 = 1
            goto L_0x0082
        L_0x007f:
            r6 = r7
            goto L_0x004f
        L_0x0081:
            r0 = 0
        L_0x0082:
            if (r6 == 0) goto L_0x009e
            r15.beforeRun(r6)
            if (r0 != 0) goto L_0x0096
            boolean r0 = r15.coordinatorWaiting
            if (r0 != 0) goto L_0x009d
            java.util.List<okhttp3.internal.concurrent.TaskQueue> r0 = r15.readyQueues
            boolean r0 = r0.isEmpty()
            r0 = r0 ^ r8
            if (r0 == 0) goto L_0x009d
        L_0x0096:
            okhttp3.internal.concurrent.TaskRunner$Backend r0 = r15.backend
            java.lang.Runnable r1 = r15.runnable
            r0.execute(r1)
        L_0x009d:
            return r6
        L_0x009e:
            boolean r0 = r15.coordinatorWaiting
            if (r0 == 0) goto L_0x00af
            long r6 = r15.coordinatorWakeUpAt
            long r6 = r6 - r2
            int r0 = (r4 > r6 ? 1 : (r4 == r6 ? 0 : -1))
            if (r0 >= 0) goto L_0x00ae
            okhttp3.internal.concurrent.TaskRunner$Backend r0 = r15.backend
            r0.coordinatorNotify(r15)
        L_0x00ae:
            return r1
        L_0x00af:
            r15.coordinatorWaiting = r8
            long r2 = r2 + r4
            r15.coordinatorWakeUpAt = r2
            okhttp3.internal.concurrent.TaskRunner$Backend r0 = r15.backend     // Catch:{ InterruptedException -> 0x00bc }
            r0.coordinatorWait(r15, r4)     // Catch:{ InterruptedException -> 0x00bc }
            goto L_0x00bf
        L_0x00ba:
            r0 = move-exception
            goto L_0x00c3
        L_0x00bc:
            r15.cancelAll()     // Catch:{ all -> 0x00ba }
        L_0x00bf:
            r15.coordinatorWaiting = r9
            goto L_0x0033
        L_0x00c3:
            r15.coordinatorWaiting = r9
            throw r0
        */
        throw new UnsupportedOperationException("Method not decompiled: okhttp3.internal.concurrent.TaskRunner.awaitTaskToRun():okhttp3.internal.concurrent.Task");
    }

    public final void cancelAll() {
        for (int size = this.busyQueues.size() - 1; size >= 0; size--) {
            this.busyQueues.get(size).cancelAllAndDecide$okhttp();
        }
        for (int size2 = this.readyQueues.size() - 1; size2 >= 0; size2--) {
            TaskQueue taskQueue = this.readyQueues.get(size2);
            taskQueue.cancelAllAndDecide$okhttp();
            if (taskQueue.getFutureTasks$okhttp().isEmpty()) {
                this.readyQueues.remove(size2);
            }
        }
    }

    public final Backend getBackend() {
        return this.backend;
    }

    public final void kickCoordinator$okhttp(TaskQueue taskQueue) {
        if (taskQueue == null) {
            Intrinsics.m5822a("taskQueue");
            throw null;
        } else if (!Util.assertionsEnabled || Thread.holdsLock(this)) {
            if (taskQueue.getActiveTask$okhttp() == null) {
                if (!taskQueue.getFutureTasks$okhttp().isEmpty()) {
                    Util.addIfAbsent(this.readyQueues, taskQueue);
                } else {
                    this.readyQueues.remove(taskQueue);
                }
            }
            if (this.coordinatorWaiting) {
                this.backend.coordinatorNotify(this);
            } else {
                this.backend.execute(this.runnable);
            }
        } else {
            StringBuilder a = outline.m2937a("Thread ");
            Thread currentThread = Thread.currentThread();
            Intrinsics.m5821a((Object) currentThread, "Thread.currentThread()");
            a.append(currentThread.getName());
            a.append(" MUST hold lock on ");
            a.append(this);
            throw new AssertionError(a.toString());
        }
    }

    public final TaskQueue newQueue() {
        int i;
        synchronized (this) {
            i = this.nextQueueName;
            this.nextQueueName = i + 1;
        }
        StringBuilder sb = new StringBuilder();
        sb.append('Q');
        sb.append(i);
        return new TaskQueue(this, sb.toString());
    }
}
