package okhttp3.internal.platform;

import com.newrelic.agent.android.agentdata.HexAttributes;
import com.newrelic.agent.android.analytics.AnalyticAttribute;
import java.io.IOException;
import java.net.InetSocketAddress;
import java.net.Socket;
import java.security.KeyStore;
import java.security.Provider;
import java.security.Security;
import java.security.cert.X509Certificate;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.net.ssl.SSLContext;
import javax.net.ssl.SSLSocket;
import javax.net.ssl.SSLSocketFactory;
import javax.net.ssl.TrustManager;
import javax.net.ssl.TrustManagerFactory;
import javax.net.ssl.X509TrustManager;
import okhttp3.OkHttpClient;
import okhttp3.Protocol;
import okhttp3.internal.Util;
import okhttp3.internal.tls.BasicCertificateChainCleaner;
import okhttp3.internal.tls.BasicTrustRootIndex;
import okhttp3.internal.tls.CertificateChainCleaner;
import okhttp3.internal.tls.TrustRootIndex;
import p085c.p086a.p087a.p088a.outline;
import p085c.p132d.p133a.p134a.p140c.p143n.C1050v;
import p250f.TypeCastException;
import p250f.p254l.p256c.DefaultConstructorMarker;
import p250f.p254l.p256c.Intrinsics;
import p262g.C1948d;

/* compiled from: Platform.kt */
public class Platform {
    public static final Companion Companion;
    public static final int INFO = 4;
    public static final int WARN = 5;
    public static final Logger logger = Logger.getLogger(OkHttpClient.class.getName());
    public static volatile Platform platform;

    /* compiled from: Platform.kt */
    public static final class Companion {
        public Companion() {
        }

        /* access modifiers changed from: private */
        public final Platform findPlatform() {
            OpenJSSEPlatform buildIfSupported;
            BouncyCastlePlatform buildIfSupported2;
            ConscryptPlatform buildIfSupported3;
            Platform buildIfSupported4 = Android10Platform.Companion.buildIfSupported();
            if (buildIfSupported4 != null) {
                return buildIfSupported4;
            }
            Platform buildIfSupported5 = AndroidPlatform.Companion.buildIfSupported();
            if (buildIfSupported5 != null) {
                return buildIfSupported5;
            }
            if (isConscryptPreferred() && (buildIfSupported3 = ConscryptPlatform.Companion.buildIfSupported()) != null) {
                return buildIfSupported3;
            }
            if (isBouncyCastlePreferred() && (buildIfSupported2 = BouncyCastlePlatform.Companion.buildIfSupported()) != null) {
                return buildIfSupported2;
            }
            if (isOpenJSSEPreferred() && (buildIfSupported = OpenJSSEPlatform.Companion.buildIfSupported()) != null) {
                return buildIfSupported;
            }
            Jdk9Platform buildIfSupported6 = Jdk9Platform.Companion.buildIfSupported();
            if (buildIfSupported6 != null) {
                return buildIfSupported6;
            }
            Platform buildIfSupported7 = Jdk8WithJettyBootPlatform.Companion.buildIfSupported();
            return buildIfSupported7 != null ? buildIfSupported7 : new Platform();
        }

        private final boolean isBouncyCastlePreferred() {
            return Intrinsics.m5823a((Object) System.getProperty("okhttp.platform"), (Object) "bouncycastle");
        }

        private final boolean isConscryptPreferred() {
            Provider provider = Security.getProviders()[0];
            Intrinsics.m5821a((Object) provider, "Security.getProviders()[0]");
            return Intrinsics.m5823a((Object) "Conscrypt", (Object) provider.getName());
        }

        private final boolean isOpenJSSEPreferred() {
            Provider provider = Security.getProviders()[0];
            Intrinsics.m5821a((Object) provider, "Security.getProviders()[0]");
            return Intrinsics.m5823a((Object) "OpenJSSE", (Object) provider.getName());
        }

        public static /* synthetic */ void resetForTests$default(Companion companion, Platform platform, int i, Object obj) {
            if ((i & 1) != 0) {
                platform = companion.findPlatform();
            }
            companion.resetForTests(platform);
        }

        public final List<String> alpnProtocolNames(List<? extends Protocol> list) {
            if (list != null) {
                ArrayList<Protocol> arrayList = new ArrayList<>();
                for (T next : list) {
                    if (((Protocol) next) != Protocol.HTTP_1_0) {
                        arrayList.add(next);
                    }
                }
                ArrayList arrayList2 = new ArrayList(C1050v.m4134a(arrayList, 10));
                for (Protocol protocol : arrayList) {
                    arrayList2.add(protocol.toString());
                }
                return arrayList2;
            }
            Intrinsics.m5822a("protocols");
            throw null;
        }

        public final byte[] concatLengthPrefixed(List<? extends Protocol> list) {
            if (list != null) {
                C1948d dVar = new C1948d();
                for (String next : alpnProtocolNames(list)) {
                    dVar.writeByte(next.length());
                    dVar.mo9468a(next);
                }
                return dVar.mo9500j();
            }
            Intrinsics.m5822a("protocols");
            throw null;
        }

        public final Platform get() {
            return Platform.platform;
        }

        public final void resetForTests(Platform platform) {
            if (platform != null) {
                Platform.platform = platform;
            } else {
                Intrinsics.m5822a(AnalyticAttribute.APPLICATION_PLATFORM_ATTRIBUTE);
                throw null;
            }
        }

        public /* synthetic */ Companion(DefaultConstructorMarker fVar) {
            this();
        }
    }

    static {
        Companion companion = new Companion((DefaultConstructorMarker) null);
        Companion = companion;
        platform = companion.findPlatform();
    }

    public static final Platform get() {
        return Companion.get();
    }

    public static /* synthetic */ void log$default(Platform platform2, String str, int i, Throwable th, int i2, Object obj) {
        if (obj == null) {
            if ((i2 & 2) != 0) {
                i = 4;
            }
            if ((i2 & 4) != 0) {
                th = null;
            }
            platform2.log(str, i, th);
            return;
        }
        throw new UnsupportedOperationException("Super calls with default arguments not supported in this target, function: log");
    }

    public void afterHandshake(SSLSocket sSLSocket) {
        if (sSLSocket == null) {
            Intrinsics.m5822a("sslSocket");
            throw null;
        }
    }

    public CertificateChainCleaner buildCertificateChainCleaner(X509TrustManager x509TrustManager) {
        if (x509TrustManager != null) {
            return new BasicCertificateChainCleaner(buildTrustRootIndex(x509TrustManager));
        }
        Intrinsics.m5822a("trustManager");
        throw null;
    }

    public TrustRootIndex buildTrustRootIndex(X509TrustManager x509TrustManager) {
        if (x509TrustManager != null) {
            X509Certificate[] acceptedIssuers = x509TrustManager.getAcceptedIssuers();
            Intrinsics.m5821a((Object) acceptedIssuers, "trustManager.acceptedIssuers");
            return new BasicTrustRootIndex((X509Certificate[]) Arrays.copyOf(acceptedIssuers, acceptedIssuers.length));
        }
        Intrinsics.m5822a("trustManager");
        throw null;
    }

    public void configureSslSocketFactory(SSLSocketFactory sSLSocketFactory) {
        if (sSLSocketFactory == null) {
            Intrinsics.m5822a("socketFactory");
            throw null;
        }
    }

    public void configureTlsExtensions(SSLSocket sSLSocket, String str, List<Protocol> list) {
        if (sSLSocket == null) {
            Intrinsics.m5822a("sslSocket");
            throw null;
        } else if (list == null) {
            Intrinsics.m5822a("protocols");
            throw null;
        }
    }

    public void configureTrustManager(X509TrustManager x509TrustManager) {
    }

    public void connectSocket(Socket socket, InetSocketAddress inetSocketAddress, int i) throws IOException {
        if (socket == null) {
            Intrinsics.m5822a("socket");
            throw null;
        } else if (inetSocketAddress != null) {
            socket.connect(inetSocketAddress, i);
        } else {
            Intrinsics.m5822a("address");
            throw null;
        }
    }

    public final String getPrefix() {
        return "OkHttp";
    }

    public String getSelectedProtocol(SSLSocket sSLSocket) {
        if (sSLSocket != null) {
            return null;
        }
        Intrinsics.m5822a("sslSocket");
        throw null;
    }

    public Object getStackTraceForCloseable(String str) {
        if (str == null) {
            Intrinsics.m5822a("closer");
            throw null;
        } else if (logger.isLoggable(Level.FINE)) {
            return new Throwable(str);
        } else {
            return null;
        }
    }

    public boolean isCleartextTrafficPermitted(String str) {
        if (str != null) {
            return true;
        }
        Intrinsics.m5822a("hostname");
        throw null;
    }

    public void log(String str, int i, Throwable th) {
        if (str != null) {
            logger.log(i == 5 ? Level.WARNING : Level.INFO, str, th);
        } else {
            Intrinsics.m5822a(HexAttributes.HEX_ATTR_MESSAGE);
            throw null;
        }
    }

    public void logCloseableLeak(String str, Object obj) {
        if (str != null) {
            if (obj == null) {
                str = outline.m2941b(str, " To see where this was allocated, set the OkHttpClient logger level to FINE: Logger.getLogger(OkHttpClient.class.getName()).setLevel(Level.FINE);");
            }
            log(str, 5, (Throwable) obj);
            return;
        }
        Intrinsics.m5822a(HexAttributes.HEX_ATTR_MESSAGE);
        throw null;
    }

    public SSLContext newSSLContext() {
        SSLContext instance = SSLContext.getInstance("TLS");
        Intrinsics.m5821a((Object) instance, "SSLContext.getInstance(\"TLS\")");
        return instance;
    }

    public X509TrustManager platformTrustManager() {
        TrustManagerFactory instance = TrustManagerFactory.getInstance(TrustManagerFactory.getDefaultAlgorithm());
        instance.init((KeyStore) null);
        Intrinsics.m5821a((Object) instance, "factory");
        TrustManager[] trustManagers = instance.getTrustManagers();
        if (trustManagers != null) {
            boolean z = true;
            if (trustManagers.length != 1 || !(trustManagers[0] instanceof X509TrustManager)) {
                z = false;
            }
            if (z) {
                TrustManager trustManager = trustManagers[0];
                if (trustManager != null) {
                    return (X509TrustManager) trustManager;
                }
                throw new TypeCastException("null cannot be cast to non-null type javax.net.ssl.X509TrustManager");
            }
            StringBuilder a = outline.m2937a("Unexpected default trust managers: ");
            String arrays = Arrays.toString(trustManagers);
            Intrinsics.m5821a((Object) arrays, "java.util.Arrays.toString(this)");
            a.append(arrays);
            throw new IllegalStateException(a.toString().toString());
        }
        Intrinsics.m5820a();
        throw null;
    }

    public String toString() {
        String simpleName = getClass().getSimpleName();
        Intrinsics.m5821a((Object) simpleName, "javaClass.simpleName");
        return simpleName;
    }

    public X509TrustManager trustManager(SSLSocketFactory sSLSocketFactory) {
        if (sSLSocketFactory != null) {
            try {
                Class<?> cls = Class.forName("sun.security.ssl.SSLContextImpl");
                Intrinsics.m5821a((Object) cls, "sslContextClass");
                Object readFieldOrNull = Util.readFieldOrNull(sSLSocketFactory, cls, "context");
                if (readFieldOrNull != null) {
                    return (X509TrustManager) Util.readFieldOrNull(readFieldOrNull, X509TrustManager.class, "trustManager");
                }
                return null;
            } catch (ClassNotFoundException unused) {
                return null;
            }
        } else {
            Intrinsics.m5822a("sslSocketFactory");
            throw null;
        }
    }

    public final CertificateChainCleaner buildCertificateChainCleaner(SSLSocketFactory sSLSocketFactory) {
        if (sSLSocketFactory != null) {
            X509TrustManager trustManager = trustManager(sSLSocketFactory);
            if (trustManager != null) {
                return buildCertificateChainCleaner(trustManager);
            }
            StringBuilder a = outline.m2937a("Unable to extract the trust manager on ");
            a.append(Companion.get());
            a.append(", ");
            a.append("sslSocketFactory is ");
            a.append(sSLSocketFactory.getClass());
            throw new IllegalStateException(a.toString());
        }
        Intrinsics.m5822a("sslSocketFactory");
        throw null;
    }
}
